<?php

namespace Mpdf\Fonts;

class FontFileFinder
{

	private $directories;

	public function __construct($directories)
	{
		$this->setDirectories($directories);
	}

	public function setDirectories($directories)
	{
		if (!is_array($directories)) {
			$directories = [$directories];
		}

		$this->directories = $directories;
	}

	public function findFontFile($name)
	{
		global $arformspdfcreator;
		$default_dir = '';
		foreach ($this->directories as $directory) {

			if( $directory != ARFPDFCREATOR_FONT_DIR ){
				$default_dir = $directory;
			}

			$filename = $directory . '/' . $name;
			
			if (file_exists($filename)) {
				return $filename;
			} else {
				$fonts_arr = $arformspdfcreator->arforms_pdf_get_fonts_arr();

				$font_name = array();

				foreach( $fonts_arr as $k => $font_arr ){
					foreach( $font_arr as $k1 => $font_file ){
						if( is_array( $font_file ) && in_array( $name, $font_file ) ){
							$font_name[ $k ] = $k1;
							break;
						}
					}
				}
			}
		}

		if( !empty( $font_name ) ){

			$data = json_encode( array( 'important_extra_fonts' => 'Import', 'arf_pdf_extra_fonts' => $font_name, 'return_message' => false ) );

			$_REQUEST['data'] = $data;

			if( is_writable( ARFPDFCREATOR_FONT_DIR ) ){
				$response = $arformspdfcreator->arf_pdf_import_font();
				if( $response['state'] == 'success' ){
					return ARFPDFCREATOR_FONT_DIR . '/' . $name;
				} else {
					if( file_exists( ARFPDFCREATOR_FONT_DIR . '/arial.ttf' ) ){
						return ARFPDFCREATOR_FONT_DIR . '/arial.ttf';
					} else if( file_exists( $default_dir . '/arial.ttf' ) ){
						return $default_dir . '/arial.ttf';
					}
				}
			} else {
				if( file_exists( ARFPDFCREATOR_FONT_DIR . '/arial.ttf' ) ){
					return ARFPDFCREATOR_FONT_DIR . '/arial.ttf';
				} else if( file_exists( $default_dir . '/arial.ttf' ) ){
					return $default_dir . '/arial.ttf';
				}
			}
		}

		throw new \Mpdf\MpdfException(sprintf('Cannot find TTF TrueType font file "%s" in configured font directories.', $name));
	}
}
