<?php
/**
  Plugin Name: ARForms - SMS Add-on
  Description: Extension For ARForms Plugin To Send SMS Notifications with Twilio, Nexmo, Clickatell and SMSGlobal.
  Version: 1.8
  Plugin URI: http://www.arformsplugin.com/
  Author: Repute InfoSystems
  Author URI: http://reputeinfosystems.com/
  Text Domain: ARForms-SMS
 */

if ( ! isset( $_SESSION ) ) {
	session_start();
}


if ( ! defined( 'ARF_SMS_DIR' ) ) {
	define( 'ARF_SMS_DIR', WP_PLUGIN_DIR . '/arformssms' );
}

if( ! isset($arfsiteurl) ){
	$arfsiteurl = home_url();
}

if ( is_ssl() && ( ! preg_match( '/^https:\/\/.*\..*$/', $arfsiteurl ) || ! preg_match( '/^https:\/\/.*\..*$/', WP_PLUGIN_URL ) ) ) {
	$arfsiteurl = str_replace( 'http://', 'https://', $arfsiteurl );
	if ( ! defined( 'ARF_SMS_URL' ) ) {
		define( 'ARF_SMS_URL', str_replace( 'http://', 'https://', WP_PLUGIN_URL . '/arformssms' ) );
	}
} else {
	if ( ! defined( 'ARF_SMS_URL' ) ) {
		define( 'ARF_SMS_URL', WP_PLUGIN_URL . '/arformssms' );
	}
}

global $arformssms;
$arformssms = new ARF_SMS();

global $arformssms_version;
$arformssms_version = '1.8';

global $arformssms_assets_version;
$arformssms_assets_version = $arformssms_version . '_' . rand( 1, 100 );

global $arformssms_shortname;
$arformssms_shortname = 'ARFSMS';

global $arf_forms_tbl,$arf_paypal_forms,$wpdb;
$arf_forms_tbl    = $wpdb->prefix . 'arf_forms';
$arf_paypal_forms = $wpdb->prefix . 'arf_paypal_forms';

load_plugin_textdomain( 'ARForms-SMS', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

class ARF_SMS {
	function __construct() {

		global $is_version_compatible,$arf_version;
		$is_version_compatible = $this->is_arforms_version();
		$arf_version = $this->get_arforms_version();

		add_action( 'init', array( $this, 'arformssms_db_check' ) );

		register_activation_hook( __FILE__, array( 'ARF_SMS', 'install' ) );

		register_activation_hook( __FILE__, array( 'ARF_SMS', 'arf_arformssms_check_network_activation' ) );

		register_uninstall_hook( __FILE__, array( 'ARF_SMS', 'uninstall' ) );

		add_action( 'admin_notices', array( $this, 'arformssms_admin_notices' ) );

		add_action( 'admin_enqueue_scripts', array( $this, 'arf_set_js' ), 11 );

		add_action( 'admin_enqueue_scripts', array( $this, 'arf_set_css' ), 10 );

		add_filter( 'upgrader_pre_install', array( $this, 'arformssms_backup' ), 10, 2 );

		add_action( 'admin_init', array( $this, 'upgrade_arformssms_data' ) );

		add_action( 'arf_after_allsetting_menu', array( $this, 'arf_sms_setting_menu' ), 10, 3 );

		add_action( 'arf_after_onsubmit_settings_container', array( $this, 'arf_sms_setting_content_v3' ), 10, 2 );
		
		add_filter( 'arf_update_form_option_outside', array( $this, 'arf_update_sms_opt_form' ), 10, 4 );

		add_filter( 'arf_update_form_return_json_outside', array( $this, 'arf_update_sms_opt_return_json_outside' ), 10, 2 );

		add_filter( 'arfformoptionsbeforeupdateform', array( $this, 'arf_sms_save_opt' ), 10, 2 );

		add_action( 'arfaftercreateentry', array( $this, 'ARF_SMS_Submission' ), 100, 2 );

		add_action( 'arf_after_paypal_successful_paymnet', array( $this, 'arf_sms_submission_after_payment' ), 30, 3 );

		add_action( 'admin_menu', array( $this, 'arf_sms_menu' ), 27 );

		add_action( 'wp_ajax_arf_send_test_sms', array( $this, 'arf_send_test_sms' ) );

		add_action( 'user_register', array( $this, 'arf_add_capabilities_to_new_user' ) );

		add_action( 'wp_ajax_arf_save_sms_config', array( $this, 'arf_save_sms_config_callback' ) );

		add_action( 'admin_footer', array( $this, 'arfsms_add_new_version_release_note'), 1);

		add_action( 'wp_ajax_arfsms_dont_show_upgrade_notice', array( $this, 'arfsms_dont_show_upgrade_notice') );

		$this->request_timeout = 30;
	}

	function arfsms_add_new_version_release_note(){
		global $wp, $wpdb, $arformssms_version;

		if( isset( $_GET['page'] ) && 'ARForms-SMS' == $_GET['page'] ){

			$arfsms_show_doc_popup = get_option('arf_sms_show_whats_new_popup', 0);

			if( '0' == $arfsms_show_doc_popup ){
				return;
			}

			$popupData = '
			<div class="arf_modal_overlay arfactive">
                <div class="arf_whatsnew_popup_container_wrapper">
                    <div class="arf_popup_container arf_popup_container_whatnew_model arfsms_view_whatsnew_modal arfactive arf_whatsnew_model_larger">
                        <div class="arf_popup_container_header">'.esc_html__("What's New in ARForms - SMS Add-on", "ARForms-SMS"). ' '.$arformssms_version.'</div>
                        <div class="arfwhatsnew_modal_content arf_whatsnew_popup_content_container">
                            <div class="arf_whatsnew_popup_row">
                                <div class="arf_whatsnew_popup_inner_content">
                                    You can always refer our online documentation for all the features <a href="https://www.arformsplugin.com/documentation/sms/" target="_blank">here</a><br>
                                        <ul style="list-style-type: disc;">
                                            <li>Added new pre-defined SMS gateways</li>
                                            <ol class="small-box">
							                    <li><a href="https://www.alcodes.com/api-documentation" target="_blank" title="ALCodes">ALCodes</a></li>
							                    <li><a href="https://www.bearsms.com/1-q-a/" target="_blank" title="">Bear SMS</a></li>
							                    <li><a href="https://www.bulksms.com/developer/eapi/code-samples/php/send_sms" target="_blank" title="Bulk SMS">Bulk SMS</a></li>
							                    <li><a href="https://cheapglobalsms.com/gateway_api#section_10" target="_blank" title="Cheap Global SMS">Cheap Global SMS</a></li>
							                    <li><a href="" target="_blank" title="ClickSend">ClickSend</a></li>
							                    <li><a href="" target="_blank" title="D7 SMS">D7 SMS</a></li>
							                    <li><a href="https://www.easysendsms.com/http-api" target="_blank" title="Easy Send Sms">Easy Send Sms</a></li>
							                    <li><a href="https://www.engagespark.com/support/send-sms-to-phone-number-api" target="_blank" title="EngageSPARK">EngageSPARK</a></li>
							                    <li><a href="https://developer.exotel.com/api/#send-sms" target="_blank" title="Exotel">Exotel</a></li>
							                    <li><a href="https://www.experttexting.com/appv2/Documentation/Send" target="_blank" title="Experttexting">Experttexting</a></li>
							                    <li><a href="https://www.eztexting.com/developers/sms-api-documentation/rest#Sending" target="_blank" title="EZTexting">EZTexting</a></li>
							                    <li><a href="https://www.fast2sms.com/free-sms-api-gateway" target="_blank" title="Fast 2 SMS">Fast 2 SMS</a></li>
							                    <li><a href="https://1s2u.com/sms/API-V2.0.pdf" target="_blank" title="Is2u">1s2u</a></li>
							                    <li><a href="https://developers.messagebird.com/docs/sms-messaging/send-outbound-sms-curl" target="_blank" title="Message Bird">Message Bird</a></li>
							                    <li><a href="https://messente.com/documentation/getting-started" target="_blank" title="Messente">Messente</a></li>
							                    <li><a href="http://doc-messaging.movile.com/?php#api-https" target="_blank" title="Movile">Movile</a></li>
							                    <li><a href="https://api.msg91.com/apidoc/samplecode/php-sample-code-send-sms.php" target="_blank" title="MSG91">MSG91</a></li>
							                    <li><a href="http://www.msgclub.net/sms-api/php-api.aspx" target="_blank" title="MSG Club">MSG Club</a></li>
							                    <li><a href="https://redoxygen.com/developers/sms-api-php" target="_blank" title="Redoxygen">Redoxygen</a></li>
							                    <li><a href="https://my.ringcaptcha.com/docs/api" target="_blank" title="RingCaptcha">RingCaptcha</a></li>
							                    <li><a href="https://docs.routee.net/docs/send-a-campaign-with-callback" target="_blank" title="Routee">Routee</a></li>
							                    <li><a href="https://api.smsapi.com/sms.do" target="_blank" title="SMS API">SMS API</a></li>
							                    <li><a href="http://enterprise.smsgatewaycenter.com/docs/api/send-sms-php" target="_blank" title="SMS Gateway Center">SMS Gateway Center</a></li>
							                    <li><a href="" target="_blank" title="Spirius">Spirius</a></li>
							                    <li><a href="https://telerivet.com/api/rest/curl" target="_blank" title="Telerivet">Telerivet</a></li>
							                    <li><a href="https://developers.telnyx.com/docs/v1/messaging/quickstarts/sending-sms-and-mms?lang=curl" target="_blank" title="Telnyx">Telnyx</a></li>
							                    <li><a href="http://api.textlocal.in/docs" target="_blank" title="Text Local">Text Local</a></li>
							                    <li><a href="https://textbelt.com" target="_blank" title="Textbelt">Textbelt</a></li>
							                    <li><a href="https://wiki.textmarketer.co.uk/display/DevDoc/Text+Marketer+Developer+Documentation+-+Wiki+Home" target="_blank" title="Text Marketer">Text Marketer</a></li>
							                    <li><a href="http://www.vianett.com/en/developers/api-documentation/http-get-post-api" target="_blank" title="Vianett">Vianett</a></li>
							                    <li><a href="https://developer.wavecell.com/v1/tutorials/api-send-sms-single" target="_blank" title="Wavecell">Wavecell</a></li>
							                  </ol>
							                  <li>Added support of non-listed SMS gateways under the "OTHER" section.</li>
                                        </ul>
                                </div>
                            </div>
                        </div>
                        <div class="arf_popup_footer arf_view_whatsnew_modal_footer">
                            <button class="rounded_button arf_btn_dark_blue" style="margin-right:7px;" name="arf_update_whatsnew_button" onclick="arfsms_hide_update_notice();">'. esc_html__('OK','ARForms-SMS').'</button>
                        </div>
                    </div>
                </div>
            </div>';

            $arfajaxurl = admin_url('admin-ajax.php');

            $popupData .= '<style type="text/css">';
            	$popupData .= 'ol.small-box{width:100%%;float:left;}';
            	$popupData .= 'ol.small-box li{width:33%;float:left;}';
            	$popupData .= 'ol.small-box li a{text-decoration:none;}';
            	$popupData .= '.arfsms_view_whatsnew_modal .arf_whatsnew_popup_row{float:left;width:100%;max-height:370px;overflow:auto;}';
            	$popupData .= '.arf_whatsnew_popup_container_wrapper .arfsms_view_whatsnew_modal.arfactive{position:relative;width:50%;max-height:82%;overflow:hidden;}';
            	$popupData .= '.arfsms_view_whatsnew_modal .arf_whatsnew_popup_content_container{overflow:hidden;height:450px;}';
            $popupData .= '</style>';

            $popupData .= '<script type="text/javascript">';
            $popupData .= 'jQuery(document).ready(function(){ jQuery("html").css("overflow","hidden");  });';
            $popupData .= 'function arfsms_hide_update_notice(){
                var ishide = 1;
                jQuery.ajax({
                type: "POST",
                url: "'.$arfajaxurl.'",
                data: "action=arfsms_dont_show_upgrade_notice&is_hide=" + ishide,
                success: function (res) {
                        jQuery(".arfsms_view_whatsnew_modal.arfactive").parents(".arf_modal_overlay.arfactive").removeClass("arfactive");
                        jQuery(".arfsms_view_whatsnew_modal.arfactive").removeClass("arfactive");
                        jQuery("html").css("overflow","");
                        return false;
                    }
                });
                return false;
            }';
            $popupData .= '</script>';
            echo $popupData;
		}
	}

	function arfsms_dont_show_upgrade_notice(){
		delete_option( 'arf_sms_show_whats_new_popup' );
		die();
	}

	public static function arf_arformssms_check_network_activation( $network_wide ) {
		if ( ! $network_wide ) {
			return;
		}

		deactivate_plugins( plugin_basename( __FILE__ ), true, true );

		header( 'Location: ' . network_admin_url( 'plugins.php?deactivate=true' ) );
		exit;
	}

	function arf_add_capabilities_to_new_user( $user_id ) {
		if ( '' == $user_id ) {
			return;
		}
		if ( user_can( $user_id, 'administrator' ) ) {

			$authorizenetcapabilities = array(
				'arfsmsconfiguration' => esc_html__( 'Configure SMS Forms', 'ARForms-SMS' ),
			);

			$arfroles = $authorizenetcapabilities;

			$userObj = new WP_User( $user_id );
			foreach ( $arfroles as $arfrole => $arfroledescription ) {
				$userObj->add_cap( $arfrole );
			}
			unset( $arfrole );
			unset( $arfroles );
			unset( $arfroledescription );
		}
	}

	function arf_sms_menu() {
		global $arformssms;

		if ( $arformssms->check_arforms_support() ) {
			return;
		}

		global $arfsettings;

		add_submenu_page( 'ARForms', 'ARForms | ' . esc_html__( 'SMS Settings', 'ARForms-SMS' ), esc_html__( 'SMS Settings', 'ARForms-SMS' ), 'arfsmsconfiguration', 'ARForms-SMS', array( $this, 'route' ) );
	}

	function route() {
		global $arformssms;
		if ( $arformssms->check_arforms_support() ) {
			return;
		}
		$message = '';

		if ( isset( $_REQUEST['page'] ) && 'ARForms-SMS' == $_REQUEST['page'] ) {

			if ( file_exists( ARF_SMS_DIR . '/core/arf_sms_setting_3.0.php' ) ) {
				require ARF_SMS_DIR . '/core/arf_sms_setting_3.0.php';
			}
		}
	}

	public static function arformssms_db_check() {
		global $arformssms;
		$arformssms_version = get_option( 'arformssms_version' );

		if ( ! isset( $arformssms_version ) || '' == $arformssms_version ) {
			$arformssms->install();}
	}

	public static function install() {
		global $arformssms;
		$arformssms_version = get_option( 'arformssms_version' );

		if ( ! isset( $arformssms_version ) || '' == $arformssms_version ) {

			global $wpdb, $arformssms_version;

			update_option( 'arformssms_version', $arformssms_version );

			$arformssms->getwpversion();
		}

		$args  = array(
			'role'   => 'administrator',
			'fields' => 'id',
		);
		$users = get_users( $args );
		if ( count( $users ) > 0 ) {
			foreach ( $users as $key => $user_id ) {

				$authorizenetcapabilities = array(
					'arfsmsconfiguration' => esc_html__( 'Configure SMS Forms', 'ARForms-SMS' ),
				);

				$arfroles = $authorizenetcapabilities;

				$userObj = new WP_User( $user_id );
				foreach ( $arfroles as $arfrole => $arfroledescription ) {
					$userObj->add_cap( $arfrole );
				}
				unset( $arfrole );
				unset( $arfroles );
				unset( $arfroledescription );
			}
		}

	}

	public static function uninstall() {
		global $wpdb;
		if ( is_multisite() ) {
			$blogs = $wpdb->get_results( "SELECT blog_id FROM {$wpdb->blogs}", ARRAY_A );
			if ( $blogs ) {
				foreach ( $blogs as $blog ) {
					switch_to_blog( $blog['blog_id'] );

					delete_option( 'arformssms_version' );
				}
				restore_current_blog();
			}
		} else {
			delete_option( 'arformssms_version' );
		}
	}

	function arformssms_admin_notices() {
		global $arformssms, $wp_version;

		if ( version_compare( $wp_version, '4.5.0', '<' ) ) {
			deactivate_plugins( plugin_basename( __FILE__ ), true, false );
			echo "<div class='error arf_error'><p>Please meet the minimum requirement of WordPress version 4.5 to activate ARForms - SMS Add-on</p></div>";
		}

		if ( ! $arformssms->is_arforms_support() ) {
			echo "<div class='updated'><p>" . esc_html__( 'SMS with ARForms plugin requires ARForms Plugin installed and active.', 'ARForms-SMS' ) . '</p></div>';

		} elseif ( ! version_compare( $arformssms->get_arforms_version(), '3.0', '>=' ) ) {
			echo "<div class='updated'><p>" . esc_html__( 'SMS with ARForms plugin requires ARForms plugin installed with version 3.0 or higher.', 'ARForms-SMS' ) . '</p></div>';
		}
	}

	function is_arforms_support() {
		if ( file_exists( ABSPATH . 'wp-admin/includes/plugin.php' ) ) {
			include_once ABSPATH . 'wp-admin/includes/plugin.php';
		}
		return is_plugin_active( 'arforms/arforms.php' );
	}

	function get_arforms_version() {

		$arf_db_version = get_option( 'arf_db_version' );

		return ( isset( $arf_db_version ) ) ? $arf_db_version : 0;
	}

	function check_arforms_support() {
		global $arformssms;
		if ( ! version_compare( $arformssms->get_arforms_version(), '3.0', '>=' ) ) {
			return true;
		} else {
			return false;
		}
	}

	function arf_set_js() {
		global $arformssms_version, $arformssms_assets_version;
		wp_register_script( 'arformssms-js', ARF_SMS_URL . '/js/arformssms.js', array( 'jquery' ), $arformssms_assets_version );
		if ( isset( $_REQUEST['page'] ) && '' != $_REQUEST['page'] && ( 'ARForms' == $_REQUEST['page'] || 'ARForms-SMS' == $_REQUEST['page'] ) ) {
			wp_enqueue_script( 'arformssms-js' );
		}
	}

	function arf_set_css( $hook ) {
		global $arformssms_assets_version;
		wp_register_style( 'arformsms-css', ARF_SMS_URL . '/css/arformssms.css', array(), $arformssms_assets_version );

		if ( isset( $_REQUEST['page'] ) && '' != $_REQUEST['page'] && ( 'ARForms-SMS' == $_REQUEST['page'] || 'ARForms' == $_REQUEST['page'] ) ) {
			wp_enqueue_style( 'arformsms-css' );
		}

		if ( isset( $hook ) && 'plugins.php' == $hook ) {
			global $wp_version;

			if ( version_compare( $wp_version, '4.5.0', '<' ) ) {
				wp_print_styles( 'arformssms-css' );
				deactivate_plugins( plugin_basename( __FILE__ ), true, false );
				$redirect_url = network_admin_url( 'plugins.php?deactivate=true' );
				wp_die( '<div class="arf_sms_wp_notice"><p class="arf_sms_wp_notice_text" >Please meet the minimum requirement of WordPress version 4.5 to activate ARForms - SMS Add-on<p class="arf_sms_wp_notice_continue">Please <a href="javascript:void(0)" onclick="window.location.href=\'' . $redirect_url . '\'">Click Here</a> to continue.</p></div>' );
			}
		}
	}

	function getwpversion() {
		global $arformssms_version,$arformssms;
		$bloginformation = array();
		$str             = $arformssms->get_rand_alphanumeric( 10 );

		$bloginformation[] = get_bloginfo( 'name' );

		$bloginformation[] = get_bloginfo( 'description' );
		$bloginformation[] = home_url();
		$bloginformation[] = get_bloginfo( 'admin_email' );
		$bloginformation[] = get_bloginfo( 'version' );
		$bloginformation[] = get_bloginfo( 'language' );
		$bloginformation[] = $arformssms_version;
		$bloginformation[] = $_SERVER['SERVER_ADDR'];
		$bloginformation[] = $str;

		update_option( 'wp_arformssms_get_version', $str );

		$valstring  = implode( '||', $bloginformation );
		$encodedval = base64_encode( $valstring );

		$urltopost = 'http://reputeinfosystems.net/arforms/wpinfo_sms.php';
		$response  = wp_remote_post(
			$urltopost,
			array(
				'method'      => 'POST',
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => array(),
				'body'        => array( 'wpversion' => $encodedval ),
				'cookies'     => array(),
			)
		);
	}

	function assign_rand_value( $num ) {

		switch ( $num ) {
			case '1':
				$rand_value = 'a';
				break;
			case '2':
				$rand_value = 'b';
				break;
			case '3':
				$rand_value = 'c';
				break;
			case '4':
				$rand_value = 'd';
				break;
			case '5':
				$rand_value = 'e';
				break;
			case '6':
				$rand_value = 'f';
				break;
			case '7':
				$rand_value = 'g';
				break;
			case '8':
				$rand_value = 'h';
				break;
			case '9':
				$rand_value = 'i';
				break;
			case '10':
				$rand_value = 'j';
				break;
			case '11':
				$rand_value = 'k';
				break;
			case '12':
				$rand_value = 'l';
				break;
			case '13':
				$rand_value = 'm';
				break;
			case '14':
				$rand_value = 'n';
				break;
			case '15':
				$rand_value = 'o';
				break;
			case '16':
				$rand_value = 'p';
				break;
			case '17':
				$rand_value = 'q';
				break;
			case '18':
				$rand_value = 'r';
				break;
			case '19':
				$rand_value = 's';
				break;
			case '20':
				$rand_value = 't';
				break;
			case '21':
				$rand_value = 'u';
				break;
			case '22':
				$rand_value = 'v';
				break;
			case '23':
				$rand_value = 'w';
				break;
			case '24':
				$rand_value = 'x';
				break;
			case '25':
				$rand_value = 'y';
				break;
			case '26':
				$rand_value = 'z';
				break;
			case '27':
				$rand_value = '0';
				break;
			case '28':
				$rand_value = '1';
				break;
			case '29':
				$rand_value = '2';
				break;
			case '30':
				$rand_value = '3';
				break;
			case '31':
				$rand_value = '4';
				break;
			case '32':
				$rand_value = '5';
				break;
			case '33':
				$rand_value = '6';
				break;
			case '34':
				$rand_value = '7';
				break;
			case '35':
				$rand_value = '8';
				break;
			case '36':
				$rand_value = '9';
				break;
		}
		return $rand_value;
	}

	function get_rand_alphanumeric( $length ) {
		global $arformssms;
		if ( $length > 0 ) {
			$rand_id = '';
			for ( $i = 1; $i <= $length; $i++ ) {
				mt_srand( (float) microtime() * 1000000 );
				$num      = mt_rand( 1, 36 );
				$rand_id .= $arformssms->assign_rand_value( $num );
			}
		}
		return $rand_id;
	}

	function arformssms_backup() {
		$databaseversion = get_option( 'arformssms_version' );
		update_option( 'old_arformssms_version', $databaseversion );
	}

	function upgrade_arformssms_data() {

		global $newarformssms_version;

		if ( ! isset( $newarformssms_version ) || '' == $newarformssms_version ) {
			$newarformssms_version = get_option( 'arformssms_version' );
		}

		if ( version_compare( $newarformssms_version, '1.8', '<' ) ) {
			$path = ARF_SMS_DIR . '/core/upgrade_arformssms_latest_data.php';
			if ( file_exists( $path ) ) {
				include $path;
			}
		}
	}
	
	function arf_update_sms_opt_return_json_outside( $return_json_data, $options ) {
		if ( isset( $options['arf_twilio_to_number'] ) && '' != $options['arf_twilio_to_number'] ) {
			$return_json_data['arf_twilio_to_number'] = $options['arf_twilio_to_number'];
		}
		if ( isset( $options['arf_twilio_to_countrycode'] ) && '' != $options['arf_twilio_to_countrycode'] ) {
			$return_json_data['arf_twilio_to_countrycode'] = $options['arf_twilio_to_countrycode'];
		}
		return $return_json_data;

	}
	function arf_update_sms_opt_form( $options, $return_json_data, $value_old_id, $value_new_id ) {
		if ( isset( $options['arf_twilio_to_number'] ) && '' != $options['arf_twilio_to_number'] ) {
			if ( $options['arf_twilio_to_number'] == $value_old_id ) {
				$options['arf_twilio_to_number'] = $value_new_id;
			}
		}
		if ( isset( $options['arf_twilio_to_countrycode'] ) && '' != $options['arf_twilio_to_countrycode'] ) {
			if ( $options['arf_twilio_to_countrycode'] == $value_old_id ) {
				$options['arf_twilio_to_countrycode'] = $value_new_id;
			}
		}

		return $options;

	}
	function arf_sms_save_opt( $options, $values ) {

		$options['arf_sms_type'] = isset( $values['options']['arf_sms_type'] ) ? $values['options']['arf_sms_type'] : '';

		$options['arf_twilio_smstext']                = isset( $values['options']['arf_twilio_smstext'] ) ? sanitize_textarea_field( $values['options']['arf_twilio_smstext'] ) : '';
		$options['arf_twilio_user_smstext']           = isset( $values['options']['arf_twilio_user_smstext'] ) ? sanitize_textarea_field( $values['options']['arf_twilio_user_smstext'] ) : '';
		$options['arf_twilio_enable_admin_sms']       = isset( $values['options']['arf_twilio_enable_admin_sms'] ) ? sanitize_text_field( $values['options']['arf_twilio_enable_admin_sms'] ) : '';
		$options['arf_twilio_admin_number']           = isset( $values['options']['arf_twilio_admin_number'] ) ? esc_html( $values['options']['arf_twilio_admin_number'] ) : '';
		$options['arf_twilio_enable_user_sms']        = isset( $values['options']['arf_twilio_enable_user_sms'] ) ? sanitize_text_field( $values['options']['arf_twilio_enable_user_sms'] ) : '';
		$options['arf_twilio_to_number']              = isset( $values['options']['arf_twilio_to_number'] ) ? esc_html( $values['options']['arf_twilio_to_number'] ) : '';
		$options['arf_twilio_to_default_countrycode'] = isset( $values['options']['arf_twilio_to_default_countrycode'] ) ? esc_html( $values['options']['arf_twilio_to_default_countrycode'] ) : '';
		$options['arf_twilio_to_countrycode']         = isset( $values['options']['arf_twilio_to_countrycode'] ) ? esc_html( $values['options']['arf_twilio_to_countrycode'] ) : '';
		$options['arfsms_request_type'] = isset($values['options']['arfsms_request_type']) ? $values['options']['arfsms_request_type'] : '';
		$options['arf_sms_gateway_url'] = isset($values['options']['arf_sms_gateway_url']) ? $values['options']['arf_sms_gateway_url'] : '';
		$options['arf_admin_msg_text'] = isset($values['options']['arf_admin_msg_text']) ? $values['options']['arf_admin_msg_text'] : '';
		$options['arf_sms_lbl'] = isset($values['options']['arf_sms_lbl']) ? $values['options']['arf_sms_lbl'] : '';
 		$options['arf_other_sms_to_lbl'] = isset($values['options']['arf_other_sms_to_lbl']) ? $values['options']['arf_other_sms_to_lbl'] : '';
 		$options['arf_other_sms_msg_label'] = isset($values['options']['arf_other_sms_msg_label']) ? $values['options']['arf_other_sms_msg_label'] : '';

 		return $options;
	}
	function arf_sms_setting_menu( $id, $is_ref_form, $values ) {
		global $arformssms;
		if ( $arformssms->check_arforms_support() ) {
			return;
		}
		echo '<div id="arfsetting_twiliosetting" onclick="arfselectsetting(\'twiliosetting\');" class="arfsettingli">' . esc_html_e( 'SMS Configuration', 'ARForms-SMS' ) . '</div>';
	}
	function arf_sms_setting_content_v3( $id, $values ) {
		global $arformssms;
		if ( $arformssms->check_arforms_support() ) {
			return;
		}

		global $armainhelper, $arformcontroller;

		$twilio_smstext = ( isset( $values['arf_twilio_smstext'] ) ) ? stripslashes_deep( $armainhelper->esc_textarea( $arformcontroller->br2nl( $values['arf_twilio_smstext'] ) ) ) : '';

		$arf_sms_type = ( isset( $values['arf_sms_type'] ) ) ? esc_attr( $values['arf_sms_type'] ) : '';

		$arf_other_sms_to_lbl = (isset($values['arf_other_sms_to_lbl'])) ? $values['arf_other_sms_to_lbl'] : '';

		$arf_other_sms_msg_label = (isset($values['arf_other_sms_msg_label'])) ? $values['arf_other_sms_msg_label'] : '';

		$twilio_user_smstext = ( isset( $values['arf_twilio_user_smstext'] ) ) ? stripslashes_deep( $armainhelper->esc_textarea( $arformcontroller->br2nl( $values['arf_twilio_user_smstext'] ) ) ) : '';

		$twilio_from_number = ( isset( $values['arf_twilio_admin_number'] ) ) ? esc_attr( $values['arf_twilio_admin_number'] ) : '';

		$is_admin_from_number_checked      = checked( isset( $values['arf_twilio_enable_admin_sms'] ) ? $values['arf_twilio_enable_admin_sms'] : '', 1, 0 );
		$show_text_box_from_number         = '';
		$show_text_box_from_number_checked = '';
		if ( ! $is_admin_from_number_checked ) {
			$show_text_box_from_number = ' arf_display_none ';
		} else {
			$show_text_box_from_number_checked = 'checked="checked"';
		}

		$twilio_to_number              = ( isset( $values['arf_twilio_to_number'] ) ) ? esc_attr( $values['arf_twilio_to_number'] ) : '';
		$twilio_to_countrycode         = ( isset( $values['arf_twilio_to_countrycode'] ) ) ? esc_attr( $values['arf_twilio_to_countrycode'] ) : '';
		$twilio_to_default_countrycode = ( isset( $values['arf_twilio_to_default_countrycode'] ) ) ? esc_attr( $values['arf_twilio_to_default_countrycode'] ) : '';

		$is_admin_to_number_checked      = checked( isset( $values['arf_twilio_enable_user_sms'] ) ? $values['arf_twilio_enable_user_sms'] : '', 1, 0 );
		$show_text_box_to_number         = '';
		$show_text_box_to_number_checked = '';
		if ( ! $is_admin_to_number_checked ) {
			$show_text_box_to_number = 'arf_display_none';
		} else {
			$show_text_box_to_number_checked = 'checked="checked"';
		}

		$fields_name_select_options             = '';
		$fields_name_country_codeselect_options = '';

		$selectbox_field_options             = '';
		$selectbox_field_value_label         = '';
		$country_selectbox_field_value_label = '';
		if ( isset( $values['fields'] ) and count( $values['fields'] ) > 0 ) {
			foreach ( $values['fields'] as $field1 ) {
				$exclude_fields = array( 'divider', 'section', 'arf_repeater', 'break', 'captcha', 'html', 'file', 'confirm_email' );
				if( isset( $field1['parent_field_type'] ) && $field1['parent_field_type'] == 'arf_repeater' ){
					continue;
				}
				if ( ! in_array( $field1['type'], $exclude_fields ) ) {

					$get_ref_form_id    = isset( $field1['ref_field_id'] ) ? $field1['ref_field_id'] : '';
					$field_ref_field_id = ( $get_ref_form_id > 0 ) ? $get_ref_form_id : $field1['id'];
					$current_field_id   = ( $get_ref_form_id > 0 ) ? $get_ref_form_id : $field1['id'];

					$selected = '';
					if ( ( $field1['id'] == $twilio_to_number ) ) {
						$selected                    = 'selected="selected"';
						$selectbox_field_value_label = $field1['name'];
					}
					$fields_name_select_options .= '<option value="' . $field_ref_field_id . '" ' . $selected . '>' . $field1['name'] . '</option>';
					$selectbox_field_options    .= '<li class="arf_selectbox_option" data-value="' . $current_field_id . '" data-label="' . $field1['name'] . '">' . $field1['name'] . '</li>';

					$country_code_selected = '';
					if ( ( $field1['id'] == $twilio_to_countrycode ) ) {
						$country_code_selected               = 'selected="selected"';
						$country_selectbox_field_value_label = $field1['name'];
					}
					$fields_name_country_codeselect_options .= '<option value="' . $field_ref_field_id . '" ' . $country_code_selected . '>' . $field1['name'] . '</option>';
				}
			}
		}

		$twilio_fromnumber = ( isset( $values['arf_twilio_fromnumber'] ) ) ? esc_attr( $values['arf_twilio_fromnumber'] ) : '';

		$twilio_smstext_len = ( '' != $twilio_smstext ) ? strlen( $twilio_smstext ) : 0;

		$twilio_user_smstext_len = ( '' != $twilio_user_smstext ) ? strlen( $twilio_user_smstext ) : 0;

		$arf_twilio_remaining_text      = 160 - $twilio_smstext_len;
		$arf_twilio_remaining_user_text = 160 - $twilio_user_smstext_len;

		if ( file_exists( ARF_SMS_DIR . '/core/arf_sms_configuration_3.0.php' ) ) {
			require ARF_SMS_DIR . '/core/arf_sms_configuration_3.0.php';
		}

	}

	function ARF_SMS_Submission( $entry_id, $form_id ) {
		global $arformssms, $wpdb, $armainhelper, $arformcontroller, $arfrecordmeta, $arfsettings, $arfform, $arf_version, $MdlDb;
		if ( $arformssms->check_arforms_support() ) {
			return;
		}
		if ( $arformssms->is_arforms_paypal_support() && version_compare( $arformssms->get_arforms_paypal_version(), '1.2', '>=' ) ) {
			global $arf_paypal,$arf_paypal_forms,$paypal_fields;
			
			if( version_compare( $arf_version, '4.3', '<' ) ){

				$paypal_form = $wpdb->get_row( $wpdb->prepare( 'SELECT * FROM ' . $arf_paypal_forms . ' WHERE form_id = %d', $form_id ) );
			
			}else{

				$tblnm = $arf_paypal_forms . ' ppl LEFT JOIN ' . $MdlDb->forms . ' frm ON ppl.form_id = frm.id'; 
				$paypal_form = $arfform->arf_select_db_data( true, '', $tblnm, 'ppl.*', 'WHERE ppl.form_id = %d', array($form_id), '', '', '', false, true);

			}

			if ( $paypal_form ) {
				$options = maybe_unserialize( $paypal_form->options );

				if ( empty( $paypal_fields ) ) {
					$paypal_fields = array(
						'first_name' => $options['first_name'],
						'last_name'  => $options['last_name'],
						'email'      => $options['email'],
						'address1'   => $options['address'],
						'address2'   => $options['address_2'],
						'city'       => $options['city'],
						'state'      => $options['state'],
						'zip'        => $options['zip'],
						'country'    => $options['country'],
					);
				}

				if ( $options['paypal_condition'] && 1 == $options['paypal_condition'] ) {
					global $arfrecordmeta, $wpdb;
					$entry_ids = array( $entry_id );
					$values    = $arfrecordmeta->getAll( 'it.field_id != 0 and it.entry_id in (' . implode( ',', $entry_ids ) . ')', ' ORDER BY fi.id' );

					$mapped_conditional_field = array();
					$rules                    = $options['conditional_logic']['rules'] ? $options['conditional_logic']['rules'] : array();
					if ( $rules ) {
						foreach ( $rules as $rule ) {
							if ( '' != $rule['field_id'] ) {
								$mapped_conditional_field[] = $rule['field_id'];
							}
						}
					}

					$mapped_field_values = array();
					if ( count( $values ) > 0 ) {
						foreach ( $values as $value ) {

							if ( $mapped_conditional_field ) {
								foreach ( $mapped_conditional_field as $rule_field ) {
									if ( $rule_field == $value->field_id ) {
										$mapped_field_values[ $value->field_id ] = $value->entry_value;
									}
								}
							}

							foreach ( $paypal_fields as $paypal_field_key => $paypal_field_id ) {
								if ( $value->field_id == $paypal_field_id ) {
									$paypal_values[ $paypal_field_key ] = $value->entry_value;
								}
							}
						}
					}

					$mapped_conditional_field = array();

					$rules = $options['conditional_logic']['rules'] ? $options['conditional_logic']['rules'] : array();

					if ( $rules ) {
						$matched     = 0;
						$total_rules = 0;

						foreach ( $rules as $rule ) {
							if ( '' != $rule['field_id'] ) {
								$total_rules++;

								$value1 = isset( $mapped_field_values[ $rule['field_id'] ] ) ? $mapped_field_values[ $rule['field_id'] ] : '';

								$value1 = trim( strtolower( $value1 ) );

								$value2 = trim( strtolower( $rule['value'] ) );

								$operator = $rule['operator'];

								if ( $arf_paypal->calculate_rule( $value1, $value2, $operator, $rule['field_type'] ) ) {
									$matched++;
								}
							}
						}
						if ( ( 'all' == $options['conditional_logic']['if_cond'] && $total_rules == $matched ) || ( 'any' == $options['conditional_logic']['if_cond'] && $matched > 0 ) ) {
							return;
						}
					} else {
						return;
					}
				} else {

					return;
				}
			}
		}

		$arformssms->ARF_SMS_Send_SMS( $form_id, $entry_id );
	}

	function arf_sms_submission_after_payment( $form_id, $entry_id, $txn_id ) {
		global $arformssms;
		if ( $arformssms->check_arforms_support() ) {
			return;
		}

		if ( ! $entry_id || ! $form_id ) {
			return;
		}

		global $wpdb, $arfrecordmeta, $arfsettings;

		$arformssms->ARF_SMS_Send_SMS( $form_id, $entry_id );
	}
	function ARF_SMS_Send_SMS( $form_id, $entry_id ) {

		global $arformssms, $wpdb, $armainhelper, $arformcontroller,$arf_forms_tbl, $arfrecordmeta, $arfform, $arf_version;

		if ( $arformssms->check_arforms_support() ) {
			return;
		}

		if( version_compare( $arf_version, '4.3', '<' ) ){

			$form_data = $wpdb->get_row( $wpdb->prepare( 'SELECT options FROM  ' . $arf_forms_tbl . ' WHERE id = %d', $form_id ), ARRAY_A );

		}else{

			$form_data = $arfform->arf_select_db_data( true, '', $arf_forms_tbl, 'options', 'WHERE id = %d', array($form_id), '', '', '', false, true, 'ARRAY_A');
		
		}

		$is_twilio_configured = '';
		if ( is_array($form_data) && count( $form_data ) > 0 ) {

			$form_options              = maybe_unserialize( $form_data['options'] );
			$arf_twilio_enable_disable = isset( $form_options['arf_twilio_enable_disable'] ) ? $form_options['arf_twilio_enable_disable'] : '';

			$arf_twilio_smstext      = stripslashes_deep( $armainhelper->esc_textarea( $arformcontroller->br2nl( $form_options['arf_twilio_smstext'] ) ) );
			$arf_twilio_user_smstext = stripslashes_deep( $armainhelper->esc_textarea( $arformcontroller->br2nl( $form_options['arf_twilio_user_smstext'] ) ) );

			$arf_twilio_enable_admin_sms       = $form_options['arf_twilio_enable_admin_sms'];
			$arf_twilio_admin_number           = $form_options['arf_twilio_admin_number'];
			$arf_twilio_enable_user_sms        = $form_options['arf_twilio_enable_user_sms'];
			$arf_twilio_to_number              = $form_options['arf_twilio_to_number'];
			$arf_twilio_to_default_countrycode = $form_options['arf_twilio_to_default_countrycode'];
			$arf_twilio_to_countrycode         = $form_options['arf_twilio_to_countrycode'];
			$arf_sms_configuration = get_option( 'arf_sms_configuration' );
			$arf_sms_type          = $form_options['arf_sms_type'];
			$entry_ids = array( $entry_id );
			$values    = $arfrecordmeta->getAll( 'it.field_id != 0 and it.entry_id in (' . implode( ',', $entry_ids ) . ')', ' ORDER BY fi.id' );

			$arf_twilio_to_number_entry_values      = '';
			$arf_twilio_to_countrycode_entry_values = '';
			if ( count( $values ) > 0 ) {
				foreach ( $values as $value ) {
					if ( $value->field_id == $arf_twilio_to_number ) {
						$arf_twilio_to_number_entry_values = $value->entry_value;
					}

					if ( $value->field_id == $arf_twilio_to_countrycode ) {
						$arf_twilio_to_countrycode_entry_values = $value->entry_value;
					}
				}
			}

			if ( ! $arf_twilio_to_countrycode_entry_values ) {
				$arf_twilio_to_countrycode_entry_values = $arf_twilio_to_default_countrycode;
			}
			if ($arf_twilio_to_countrycode_entry_values != '') {
				$arf_twilio_to_number_entry_values = $arf_twilio_to_countrycode_entry_values . $arf_twilio_to_number_entry_values;
			}

			if (isset($arf_sms_type) && $arf_sms_type != '' ) {
				$this->arf_send_sms_to_user($arf_sms_type, '', '', $arf_twilio_to_number_entry_values, '', $arf_twilio_user_smstext, $arf_sms_configuration, $form_options);
			}else{
				return;
			}
		}	
	}
	
	function arf_send_sms_to_user($arf_sms_type, $arf_msg_slug , $arf_phno_slug ,$arf_twilio_to_number_entry_values, $notification_type , $arf_twilio_user_smstext, $arf_sms_configuration, $form_options ){

		global $arformssms, $wpdb, $armainhelper, $arformcontroller, $arf_forms_tbl, $arfrecordmeta, $ARFTwilioService, $arfrecordmeta;
		if (empty($arf_sms_configuration)) {
			$arf_sms_configuration = get_option( 'arf_sms_configuration' );
		}
		$arf_twilio_smstext      = isset($form_options['arf_twilio_smstext']) ? stripslashes_deep( $armainhelper->esc_textarea( $arformcontroller->br2nl( $form_options['arf_twilio_smstext'] ) ) ) : '';
		$arf_twilio_enable_admin_sms       = isset($form_options['arf_twilio_enable_admin_sms']) ? $form_options['arf_twilio_enable_admin_sms'] : '';
		$arf_twilio_admin_number           = isset($form_options['arf_twilio_admin_number']) ? $form_options['arf_twilio_admin_number'] : '';
		$arf_twilio_enable_user_sms        = isset($form_options['arf_twilio_enable_user_sms']) ? $form_options['arf_twilio_enable_user_sms'] : '';
		$arf_twilio_to_default_countrycode = isset($form_options['arf_twilio_to_default_countrycode']) ? $form_options['arf_twilio_to_default_countrycode'] : '';
		$arf_twilio_to_countrycode         = isset($form_options['arf_twilio_to_countrycode']) ? $form_options['arf_twilio_to_countrycode'] : '';
		$arf_sms_enable_log                = isset($arf_sms_configuration['arf_sms_enable_log']) && !empty($arf_sms_configuration['arf_sms_enable_log']) ? $arf_sms_configuration['arf_sms_enable_log'] : 0;
		
		if ($arf_sms_type != 'arf_other') {
			$arf_sms_gateways_list = $arformssms->arf_sms_gateways_list();
			$arf_sms_gateway_url = $arf_sms_gateways_list[$arf_sms_type]['url'];
            $arf_sms_gateways_settings = $arf_sms_configuration['arf_sms_gateways_settings'][$arf_sms_type];
			$arf_sms_gateway_url = $arformssms->arf_sms_filter_api_url($arf_sms_gateway_url, $arf_sms_gateways_settings, $arf_twilio_to_number_entry_values);
			$arf_sms_to_label  = $arf_sms_gateways_list[$arf_sms_type]['options']['to']['slug'];
            $arf_sms_msg_label = $arf_sms_gateways_list[$arf_sms_type]['options']['message']['slug'];
            $arf_sms_request_type = $arf_sms_gateways_list[$arf_sms_type]['group'];
            $arf_sms_lang_type = !empty( $arf_sms_gateways_list[$arf_sms_type]['options']['lang_type'] ) ? $arf_sms_gateways_list[$arf_sms_type]['options']['lang_type'] : array();
		}else{
			$arf_sms_gateway_url = isset($arf_sms_configuration['other_sms_url']) && !empty($arf_sms_configuration['other_sms_url']) ? $arf_sms_configuration['other_sms_url'] : '';
            $arf_sms_request_type = isset($arf_sms_configuration['other_request_type']) && !empty($arf_sms_configuration['other_request_type']) ? $arf_sms_configuration['other_request_type'] : '';
           	$arf_sms_parameters = isset($arf_sms_configuration['arf_sms_parameters']) && !empty($arf_sms_configuration['arf_sms_parameters']) ? $arf_sms_configuration['arf_sms_parameters'] : array();
           	$arf_sms_to_label = isset($form_options['arf_other_sms_to_lbl']) ? $form_options['arf_other_sms_to_lbl'] : '';
           	$arf_sms_msg_label = isset($form_options['arf_other_sms_msg_label']) ? $form_options['arf_other_sms_msg_label'] : '';

           	$arf_sms_enable_header_parameter = isset($arf_sms_configuration['arf_sms_enable_header_parameter']) && !empty($arf_sms_configuration['arf_sms_enable_header_parameter']) ? $arf_sms_configuration['arf_sms_enable_header_parameter'] : 0 ;

           	$arf_sms_header_parameters = isset($arf_sms_configuration['arf_sms_header_parameters']) && !empty($arf_sms_configuration['arf_sms_header_parameters']) ? $arf_sms_configuration['arf_sms_header_parameters'] : array();
           	
           	if ($notification_type == 'test_sms' && $arf_msg_slug != '' && $arf_phno_slug != '') {
           		$arf_sms_msg_label = $arf_msg_slug;
           		$arf_sms_to_label = $arf_phno_slug;
           	}
           	
            if (empty($arf_sms_gateway_url) || empty($arf_sms_request_type) || empty($arf_sms_to_label) || empty($arf_sms_msg_label) || empty($arf_sms_parameters)) {
                return json_encode(array("status" => "error", "msg" => __("Missing required fields...", "ARForms-SMS")));
            }
            if (!empty($arf_sms_parameters)) {
                foreach ($arf_sms_parameters as $param => $parameters) {
                    $arf_sms_gateways_settings[$parameters['parameter_name']] = $parameters['parameter_value'];
                }
            }
		}
		
		$parameter = '';
		$url = $arf_sms_gateway_url;

		switch ($arf_sms_request_type) {
			case "get":
			    if (!empty($arf_sms_gateways_settings)) {
			    	$parameter = array();
                    foreach ($arf_sms_gateways_settings as $key => $value) {
                        if (!empty($value)) {
                            $parameter[] = "{$key}={$value}";
                        }
                    }
                    $parameter = !empty($parameter) ? implode("&", $parameter) : "";
                }
                if( !empty( $arf_sms_lang_type ) ){
                	$parameter .= '&' . $arf_sms_lang_type['slug'] .'=' . $arf_sms_lang_type['value'];
                }
                if (!empty($parameter)) {
                    if (strpos($arf_sms_gateway_url, "?") === false) {
                        $arf_sms_gateway_url .= "?{$parameter}";
                    } else {
                        $arf_sms_gateway_url .= "&{$parameter}";
                    }
                }
                
                $new_arf_sms_header_parameters = array();
                if($arf_sms_type=='arf_other' && !empty($arf_sms_header_parameters) && $arf_sms_enable_header_parameter != '' && $arf_sms_enable_header_parameter == 1){

                        foreach ($arf_sms_header_parameters as $param => $parameters) {
                            
                            $new_arf_sms_header_parameters[$parameters['header_parameter_name']] = $parameters['header_parameter_value'];
                        }
                }

                $arf_sms_response = '';
                if ($arf_twilio_to_number_entry_values != '' && $arf_twilio_user_smstext != ''){
                	if (strpos($arf_sms_gateway_url, "?") === false) {
                        $arf_sms_gateway_url .= "?{$arf_sms_to_label}={$arf_twilio_to_number_entry_values}&{$arf_sms_msg_label}={$arf_twilio_user_smstext}";
                    } else {
                        $arf_sms_gateway_url .= "&{$arf_sms_to_label}={$arf_twilio_to_number_entry_values}&{$arf_sms_msg_label}={$arf_twilio_user_smstext}";
                    }
                    $arf_sms_response = wp_remote_get(
                        $arf_sms_gateway_url,
                        array(
                            'timeout' => '5000',
                            'headers' => $new_arf_sms_header_parameters
                        )
                    );
	            }
                if ($arf_twilio_enable_admin_sms == 1 && !empty($arf_twilio_admin_number) && $notification_type != 'test_sms') {
                	if (strpos($arf_sms_gateway_url, "?") === false) {
                        $arf_sms_gateway_url .= "?{$arf_sms_to_label}={$arf_twilio_admin_number}&{$arf_sms_msg_label}={$arf_twilio_smstext}";
                    } else {
                        $arf_sms_gateway_url .= "&{$arf_sms_to_label}={$arf_twilio_admin_number}&{$arf_sms_msg_label}={$arf_twilio_smstext}";
                    }

                    $arf_sms_admin_response = wp_remote_get(
                        $arf_sms_gateway_url,
                        array(
                            'timeout' => '5000',
                            'headers' => $new_arf_sms_header_parameters
                        )
                    );
                }
                if ((isset($arf_sms_response) && !is_wp_error($arf_sms_response)) || (isset($arf_sms_admin_response) && !is_wp_error($arf_sms_admin_response))  ) {
                	if (isset($arf_sms_admin_response['body']) && !empty($arf_sms_admin_response['body'])) {
                		if ($arf_sms_enable_log == 1) {
	                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
	                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
	                        $request = array(
	                            "url"                => $url,
	                            "Request Type"       => $arf_sms_request_type,
	                            "Parameters"         => json_encode(explode("&", $parameter)),
	                            $arf_sms_to_label    => $arf_twilio_admin_number,
	                            $arf_sms_msg_label   => $arf_twilio_smstext
	                        );
	                        $this->arf_sms_write_response($request, $arf_sms_admin_esponse['body']);
	                    }
	                    $sms_gatway_response = $arf_sms_admin_response['body'];
                	}
                	if (isset($arf_sms_response['body']) && !empty($arf_sms_response['body'])) {
                		if ($arf_sms_enable_log == 1) {
	                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
	                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
	                        $request = array(
	                            "url"                => $url,
	                            "Request Type"       => $arf_sms_request_type,
	                            "Parameters"         => json_encode(explode("&", $parameter)),
	                            $arf_sms_to_label    => $arf_twilio_to_number_entry_values,
	                            $arf_sms_msg_label   => $arf_twilio_user_smstext
	                        );
	                        $this->arf_sms_write_response($request, $arf_sms_response['body']);
	                    }
	                    $sms_gatway_response = $arf_sms_response['body'];
                    }
                    return $sms_gatway_response;
                }
            	break;
			case "post":
            case "get_post":
                $remote_args = array(
                    'timeout' => '5000'
                );
                $new_arf_sms_header_parameters = array();
                if($arf_sms_type =='arf_other' && !empty($arf_sms_header_parameters) && !empty($arf_sms_enable_header_parameter) && $arf_sms_enable_header_parameter == 1){
                		foreach ($arf_sms_header_parameters as $param => $parameters) {
                            
                            $new_arf_sms_header_parameters[$parameters['header_parameter_name']] = $parameters['header_parameter_value'];
                        }
                        
                    $remote_args['headers'] = $new_arf_sms_header_parameters;
                }
                if ($arf_twilio_to_number_entry_values != '' && $arf_twilio_user_smstext != '') {
                	
                	$arf_sms_gateways_settings[$arf_sms_to_label]  = $arf_twilio_to_number_entry_values;
                    $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_user_smstext;
                    if( !empty( $arf_sms_lang_type ) ){
                    	$arf_sms_gateways_settings[ $arf_sms_lang_type['slug'] ] = $arf_sms_lang_type['value'];
                    }
	                if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "json") {
	                	$arf_sms_gateways_settings = json_encode($arf_sms_gateways_settings);
	                    $remote_args['headers']['Content-Type'] = "application/json";
	                }
	                $remote_args['body'] = $arf_sms_gateways_settings;
	                
	                $arf_sms_response = wp_remote_post(
	                    $arf_sms_gateway_url,
	                    $remote_args
	                );
                }
                if ($arf_twilio_enable_admin_sms == 1 && !empty($arf_twilio_admin_number) && $notification_type != 'test_sms') {
                	$arf_sms_gateways_settings = arf_json_decode( $arf_sms_gateways_settings, true );
                	$arf_sms_gateways_settings[$arf_sms_to_label] = $arf_twilio_admin_number;
                    $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_smstext;
                    if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "json") {
                    	$arf_sms_gateways_settings = json_encode($arf_sms_gateways_settings);
                        $remote_args['headers']['Content-Type'] = "application/json";
                    }
                    $remote_args['body'] = $arf_sms_gateways_settings;
                    
                    $arf_sms_admin_response = wp_remote_post(
                        $arf_sms_gateway_url,
                        $remote_args
                    );
	            }
                if ((isset($arf_sms_response) && !is_wp_error($arf_sms_response)) || (isset($arf_sms_admin_response) && !is_wp_error($arf_sms_admin_response))  ) {
                    if (isset($arf_sms_response['body']) && !empty($arf_sms_response['body'])) {
                		if ($arf_sms_enable_log == 1) {
	                		if (!is_array($arf_sms_gateways_settings)) {
	                            $arf_sms_gateways_settings = json_decode($arf_sms_gateways_settings, true);
	                        }
	                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
	                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
	                        $request = array(
	                            "url"                => $url,
	                            "Request Type"       => $arf_sms_request_type,
	                            "Parameters"         => json_encode($arf_sms_gateways_settings),
	                            $arf_sms_to_label    => $arf_twilio_to_number_entry_values,
	                            $arf_sms_msg_label   => $arf_twilio_user_smstext
	                        );
	                        $this->arf_sms_write_response($request, $arf_sms_response['body']);
	                    }
	                    $sms_gatway_response = $arf_sms_response['body'];
                    }
                    if (isset($arf_sms_admin_response['body']) && !empty($arf_sms_admin_response['body'])) {
                		if ($arf_sms_enable_log == 1) {
	                		if (!is_array($arf_sms_gateways_settings)) {
	                            $arf_sms_gateways_settings = json_decode($arf_sms_gateways_settings, true);
	                        }
	                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
	                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
	                        $request = array(
	                            "url"                => $url,
	                            "Request Type"       => $arf_sms_request_type,
	                            "Parameters"         => json_encode($arf_sms_gateways_settings),
	                            $arf_sms_to_label    => $arf_twilio_admin_number,
	                            $arf_sms_msg_label   => $arf_twilio_smstext
	                        );
	                        $this->arf_sms_write_response($request, $arf_sms_admin_response['body']);
	                    }
                        $sms_gatway_response = $arf_sms_admin_response['body'];
                    }
                    return json_encode($sms_gatway_response);
                }
            	break;
			case "post_usdpwd":
                $header = "";
                if (isset($arf_sms_gateways_settings['header']) && !empty($arf_sms_gateways_settings['header'])) {
                    $header = $arf_sms_gateways_settings['header'];
                }
                unset($arf_sms_gateways_settings['header']);

                $usdpwd  = isset($header['account_sid']) ? $header['account_sid'].":" : "";
                $usdpwd .= isset($header['auth_token'])  ? $header['auth_token']  : "";

                if ("clicksend" == $arf_sms_type) {
                    $arf_sms_gateways_settings['messages'][] = $arf_sms_gateways_settings;
                } else {
                    $arf_sms_gateways_settings = $arf_sms_gateways_settings;
                }

                if ($arf_twilio_to_number_entry_values != '' && $arf_twilio_user_smstext != '') {
                	$arf_sms_gateways_settings[$arf_sms_to_label]  = $arf_twilio_to_number_entry_values;
                    $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_user_smstext;
	                if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "json") {
	                    $arf_sms_gateways_settings = json_encode($arf_sms_gateways_settings);
	                }
	                $ch = curl_init();
	                curl_setopt($ch, CURLOPT_URL,$arf_sms_gateway_url);
	                curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);
	                curl_setopt($ch, CURLOPT_USERPWD, "{$usdpwd}");
	                curl_setopt($ch, CURLOPT_HEADER, 1);
	                if (isset($arf_sms_gateways_list[$arf_sms_type]['content_type'])) {
	                    curl_setopt($ch, CURLOPT_HTTPHEADER, array("Content-Type: {$arf_sms_gateways_list[$arf_sms_type]['content_type']}"));
	                }
	                if ("clicksend" == $arf_sms_type) {
	                    curl_setopt($ch, CURLOPT_POSTFIELDS , $arf_sms_gateways_settings);
	                } else {
	                    curl_setopt($ch, CURLOPT_POSTFIELDS , http_build_query($arf_sms_gateways_settings));
	                }
	                $result = curl_exec($ch);
	                curl_close($ch);
                }

                if ($arf_twilio_enable_admin_sms == 1 && !empty($arf_twilio_admin_number) && $notification_type != 'test_sms') {
                	if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "json") {
                		$arf_sms_gateways_settings[$arf_sms_to_label] = $arf_twilio_admin_number;
                        $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_smstext;
	                    $arf_sms_gateways_settings = json_encode($arf_sms_gateways_settings);
	                } else {
                        $arf_sms_gateways_settings[$arf_sms_to_label] = $arf_twilio_admin_number;
                        $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_smstext;
                    }
                    $ch = curl_init();
                    curl_setopt($ch, CURLOPT_URL,$arf_sms_gateway_url);
                    curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);
                    curl_setopt($ch, CURLOPT_USERPWD, "{$usdpwd}");
                    curl_setopt($ch, CURLOPT_HEADER, 1);
                    if (isset($arf_sms_gateways_list[$arf_sms_type]['content_type'])) {
                        curl_setopt($ch, CURLOPT_HTTPHEADER, array("Content-Type: {$arf_sms_gateways_list[$arf_sms_type]['content_type']}"));
                    }
                    if ("clicksend" == $arf_sms_type) {
                        curl_setopt($ch, CURLOPT_POSTFIELDS , $arf_sms_gateways_settings);
                    } else {
                        curl_setopt($ch, CURLOPT_POSTFIELDS , http_build_query($arf_sms_gateways_settings));
                    }
                    $result = curl_exec($ch);
                    curl_close($ch);
                }
                if (!empty($result)) {	
                	if ($arf_sms_enable_log == 1) {
                		if (!is_array($arf_sms_gateways_settings)) {
                            $arf_sms_gateways_settings = json_decode($arf_sms_gateways_settings, true);
                        }
                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
                        $request = array(
                            "url"                => $url,
                            "Request Type"       => $arf_sms_request_type,
                            "Parameters"         => json_encode($arf_sms_gateways_settings),
                            $arf_sms_to_label    => $arf_twilio_to_number_entry_values,
                            $arf_sms_msg_label   => $arf_twilio_user_smstext
                        );
                        $this->arf_sms_write_response($request, $result);
                    }
                    return json_encode($result);
                }
            	break;
            case "get_post_header":
            case "post_header":
                $header = "";
                if( !empty( $arf_sms_lang_type ) ){
                	if( !empty( $arf_sms_lang_type ) ){
                    	$arf_sms_gateways_settings[ $arf_sms_lang_type['slug'] ] = $arf_sms_lang_type['value'];
                    }
                }
                if (isset($arf_sms_gateways_settings['header']) && !empty($arf_sms_gateways_settings['header'])) {
                    $header = $arf_sms_gateways_settings['header'];
                }

                $authorization      = $arf_sms_gateways_list[$arf_sms_type]['auth_key'];
                $authorization_type = $arf_sms_gateways_list[$arf_sms_type]['auth_type'];
                $auth_value         = $header['account_sid'];
                $content_type       = isset($arf_sms_gateways_list[$arf_sms_type]['content_type']) ? $arf_sms_gateways_list[$arf_sms_type]['content_type'] : "";
                unset($arf_sms_gateways_settings['header']);
                if ($arf_twilio_to_number_entry_values != '' && $arf_twilio_user_smstext != '') {
                	$arf_sms_gateways_settings[$arf_sms_to_label]  = $arf_twilio_to_number_entry_values;
                    $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_user_smstext;
	                if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "json") {
	                    $arf_sms_gateways_settings = json_encode($arf_sms_gateways_settings);
	                } else if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "string")  {
	                	$arf_sms_gateway_body_str = '';
		                foreach( $arf_sms_gateways_settings as $k => $val ){
		                	$arf_sms_gateway_body_str .= $k.'=' . $val.'&';
		                }
		                $arf_sms_gateway_body_str = rtrim($arf_sms_gateway_body_str, '&');

		                $arf_sms_gateways_settings = $arf_sms_gateway_body_str;
	                }
	                
	                $remote_args = array(
	                    "timeout"   => 5000,
	                    "body"      => $arf_sms_gateways_settings,
	                    "headers"   => array(
	                        "{$authorization}" => trim("{$authorization_type} {$auth_value}")
	                    )
	                );
	                
	                if (!empty($content_type)) {
	                    $remote_args['headers']['Content-Type'] = $content_type;
	                }
	                $arf_sms_response = wp_remote_post(
	                    $arf_sms_gateway_url,
	                    $remote_args
	                );
				}

                if ($arf_twilio_enable_admin_sms == 1 && !empty($arf_twilio_admin_number) && $notification_type != "test_sms") {

            		$arf_sms_gateways_settings[$arf_sms_to_label] = $arf_twilio_admin_number;
                    $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_smstext;
                	if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "json") {
	                    $arf_sms_gateways_settings = json_encode($arf_sms_gateways_settings);
	                } else if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "string")  {
	                	$arf_sms_gateway_body_str = '';
		                foreach( $arf_sms_gateways_settings as $k => $val ){
		                	$arf_sms_gateway_body_str .= $k.'=' . $val.'&';
		                }
		                $arf_sms_gateway_body_str = rtrim($arf_sms_gateway_body_str, '&');

		                $arf_sms_gateways_settings = $arf_sms_gateway_body_str;
	                }



	                $remote_args = array(
	                    "timeout"   => 5000,
	                    "body"      => $arf_sms_gateways_settings,
	                    "headers"   => array(
	                        "{$authorization}" => trim("{$authorization_type} {$auth_value}")
	                    )
	                );
	                
	                if (!empty($content_type)) {
	                    $remote_args['headers']['Content-Type'] = $content_type;
	                }

                    $arf_sms_admin_response = wp_remote_post(
                        $arf_sms_gateway_url,
                        $remote_args
                    );
                }

                if ((isset($arf_sms_response) && !is_wp_error($arf_sms_response)) || (isset($arf_sms_admin_response) && !is_wp_error($arf_sms_admin_response))  ) {
                    if (isset($arf_sms_admin_response['body']) && !empty($arf_sms_admin_response['body'])) {
                    	if ($arf_sms_enable_log == 1) {
	                		if (!is_array($arf_sms_gateways_settings)) {
	                            $arf_sms_gateways_settings = json_decode($arf_sms_gateways_settings, true);
	                        }
	                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
	                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
	                        $request = array(
	                            "url"                => $url,
	                            "Request Type"       => $arf_sms_request_type,
	                            "remote_args"		 => $remote_args,
	                            "Parameters"         => json_encode($arf_sms_gateways_settings),
	                            $arf_sms_to_label    => $arf_twilio_admin_number,
	                            $arf_sms_msg_label   => $arf_twilio_smstext
	                        );
	                        $this->arf_sms_write_response($request, $arf_sms_admin_response['body']);
	                    }
	                    $sms_gatway_response = $arf_sms_admin_response['body'];
                    }
                    if (isset($arf_sms_response['body']) && !empty($arf_sms_response['body'])) {
                    	if ($arf_sms_enable_log == 1) {
	                		if (!is_array($arf_sms_gateways_settings)) {
	                            $arf_sms_gateways_settings = json_decode($arf_sms_gateways_settings, true);
	                        }
	                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
	                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
	                        $request = array(
	                            "url"                => $url,
	                            "Request Type"       => $arf_sms_request_type,
	                            "remote_args"		 => $remote_args,
	                            "Parameters"         => json_encode($arf_sms_gateways_settings),
	                            $arf_sms_to_label    => $arf_twilio_to_number_entry_values,
	                            $arf_sms_msg_label   => $arf_twilio_user_smstext
	                        );
	                        $this->arf_sms_write_response($request, $arf_sms_response['body']);
	                    }
	                    $sms_gatway_response = $arf_sms_response['body'];
                    }
                    return json_encode($sms_gatway_response);
                }
            	break;
            case "post_header_user":
                $header = "";
                if (isset($arf_sms_gateways_settings['header']) && !empty($arf_sms_gateways_settings['header'])) {
                    $header = $arf_sms_gateways_settings['header'];
                    foreach ($header as $key => $value) {
                        $headers[$key] = "{$value}";
                    }
                }

                $authorization      = $arf_sms_gateways_list[$arf_sms_type]['auth_key'];
                $authorization_type = $arf_sms_gateways_list[$arf_sms_type]['auth_type'];
                $content_type       = isset($arf_sms_gateways_list[$arf_sms_type]['content_type']) ? $arf_sms_gateways_list[$arf_sms_type]['content_type'] : "";
                unset($arf_sms_gateways_settings['header']);

                if ($arf_twilio_to_number_entry_values != '' && $arf_twilio_user_smstext != '') {
                	$arf_sms_gateways_settings[$arf_sms_to_label]  = $arf_twilio_to_number_entry_values;
                    $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_user_smstext;
	                if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "json") {
	                    $arf_sms_gateways_settings = json_encode($arf_sms_gateways_settings);
	                }
	                $remote_args = array(
	                    "timeout"   => 5000,
	                    "body"      => $arf_sms_gateways_settings,
	                    "headers"   => $headers
	                );
	                if (!empty($content_type)) {
	                    $remote_args['headers']['Content-Type'] = $content_type;
	                }

	                $arf_sms_response = wp_remote_post(
	                    $arf_sms_gateway_url,
	                    $remote_args
	                );
	            }

	            if ($arf_twilio_enable_admin_sms == 1 && !empty($arf_twilio_admin_number) && $notification_type != 'test_sms') {
                	$arf_sms_gateways_settings[$arf_sms_to_label] = $arf_twilio_admin_number;
                    $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_smstext;
                    if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "json") {
                        $arf_sms_gateways_settings = json_encode($arf_sms_gateways_settings);
                    }
                    $remote_args = array(
	                    "timeout"   => 5000,
	                    "body"      => $arf_sms_gateways_settings,
	                    "headers"   => $headers
	                );
	                if (!empty($content_type)) {
	                    $remote_args['headers']['Content-Type'] = $content_type;
	                }
                    $arf_sms_admin_response = wp_remote_post(
                        $arf_sms_gateway_url,
                        $remote_args
                    );
                }

                if ((isset($arf_sms_response) && !is_wp_error($arf_sms_response)) || (isset($arf_sms_admin_response) && !is_wp_error($arf_sms_admin_response))  ) {
                    if (isset($arf_sms_response['body']) && !empty($arf_sms_response['body'])) {
                    	if ($arf_sms_enable_log == 1) {
	                		if (!is_array($arf_sms_gateways_settings)) {
	                            $arf_sms_gateways_settings = json_decode($arf_sms_gateways_settings, true);
	                        }
	                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
	                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
	                        $request = array(
	                            "url"                => $url,
	                            "Request Type"       => $arf_sms_request_type,
	                            "Parameters"         => json_encode($arf_sms_gateways_settings),
	                            $arf_sms_to_label    => $arf_twilio_to_number_entry_values,
	                            $arf_sms_msg_label   => $arf_twilio_user_smstext
	                        );
	                        $this->arf_sms_write_response($request, $arf_sms_response['body']);
	                    }
	                    $sms_gatway_response = $arf_sms_response['body'];
                    }
                    if (isset($arf_sms_admin_response['body']) && !empty($arf_sms_admin_response['body'])) {
                    	if ($arf_sms_enable_log == 1) {
	                		if (!is_array($arf_sms_gateways_settings)) {
	                            $arf_sms_gateways_settings = json_decode($arf_sms_gateways_settings, true);
	                        }
	                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
	                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
	                        $request = array(
	                            "url"                => $url,
	                            "Request Type"       => $arf_sms_request_type,
	                            "Parameters"         => json_encode($arf_sms_gateways_settings),
	                            $arf_sms_to_label    => $arf_twilio_admin_number,
	                            $arf_sms_msg_label   => $arf_twilio_smstext
	                        );
	                        $this->arf_sms_write_response($request, $arf_sms_admin_response['body']);
	                    }
                        $sms_gatway_response = $arf_sms_admin_response['body'];
                    }
	                return json_encode($sms_gatway_response);
                }
            	break;
            default :
                $remote_args = array(
                    'timeout' => '5000'
                );
            	if ($arf_twilio_to_number_entry_values != '' && $arf_twilio_user_smstext != ''){
	                $arf_sms_gateways_settings[$arf_sms_to_label]  = $arf_twilio_to_number_entry_values;
	                $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_user_smstext;
	                if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "json") {
	                    $arf_sms_gateways_settings = json_encode($arf_sms_gateways_settings);
	                    $remote_args['headers']['Content-Type'] = "application/json";
	                }
	                $remote_args['body'] = $arf_sms_gateways_settings;
	                $arf_sms_response = wp_remote_post(
	                    $arf_sms_gateway_url,
	                    $remote_args
	                );
            	}
                if ($arf_twilio_enable_admin_sms == 1 && !empty($arf_twilio_admin_number) && $notification_type != 'test_sms') {

                	$arf_sms_gateways_settings[$arf_sms_to_label]  = $arf_twilio_admin_number;
	                $arf_sms_gateways_settings[$arf_sms_msg_label] = $arf_twilio_smstext;
	                if (isset($arf_sms_gateways_list[$arf_sms_type]['data_type']) && $arf_sms_gateways_list[$arf_sms_type]['data_type'] == "json") {
	                    $arf_sms_gateways_settings = json_encode($arf_sms_gateways_settings);
	                    $remote_args['headers']['Content-Type'] = "application/json";
	                }
	                $remote_args['body'] = $arf_sms_gateways_settings;

                    $arf_sms_admin_response = wp_remote_post(
                        $arf_sms_gateway_url,
                        $remote_args
                    );
	            }
                if ((isset($arf_sms_response) && !is_wp_error($arf_sms_response)) || (isset($arf_sms_admin_response) && !is_wp_error($arf_sms_admin_response))  ) {
                    if (isset($arf_sms_response['body']) && !empty($arf_sms_response['body'])) {
                    	if ($arf_sms_enable_log == 1) {
	                		if (!is_array($arf_sms_gateways_settings)) {
	                            $arf_sms_gateways_settings = json_decode($arf_sms_gateways_settings, true);
	                        }
	                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
	                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
	                        $request = array(
	                            "url"                => $url,
	                            "Request Type"       => $arf_sms_request_type,
	                            "Parameters"         => json_encode($arf_sms_gateways_settings),
	                            $arf_sms_to_label    => $arf_twilio_to_number_entry_values,
	                            $arf_sms_msg_label   => $arf_twilio_user_smstext
	                        );
	                        $this->arf_sms_write_response($request, $arf_sms_response['body']);
	                    }
	                    $sms_gatway_response = $arf_sms_response['body'];
                    }
                    if (isset($arf_sms_admin_response['body']) && !empty($arf_sms_admin_response['body'])) {
                    	if ($arf_sms_enable_log == 1) {
	                		if (!is_array($arf_sms_gateways_settings)) {
	                            $arf_sms_gateways_settings = json_decode($arf_sms_gateways_settings, true);
	                        }
	                        unset($arf_sms_gateways_settings[$arf_sms_to_label]);
	                        unset($arf_sms_gateways_settings[$arf_sms_msg_label]);
	                        $request = array(
	                            "url"                => $url,
	                            "Request Type"       => $arf_sms_request_type,
	                            "Parameters"         => json_encode($arf_sms_gateways_settings),
	                            $arf_sms_to_label    => $arf_twilio_admin_number,
	                            $arf_sms_msg_label   => $arf_twilio_smstext
	                        );
	                        $this->arf_sms_write_response($request, $arf_sms_admin_response['body']);
	                    }
                        $sms_gatway_response = $arf_sms_admin_response['body'];
                    }
                    return json_encode($sms_gatway_response);
                }
            break;
		}
	}

	function arf_sms_filter_api_url($url, $settings, $user_phone=""){

        $format      = isset($settings['format']) && !empty($settings['format']) ? $settings['format'] : "json";
        $project_id  = isset($settings['project_id']) && !empty($settings['project_id']) ? $settings['project_id'] : "";
        $account_key = isset($settings['account_key']) && !empty($settings['account_key']) ? $settings['account_key'] : "";
        $sub_account = isset($settings['sub_account']) && !empty($settings['sub_account']) ? $settings['sub_account'] : "";
        $account     = isset($settings['header']['account_sid']) && !empty($settings['header']['account_sid']) ? $settings['header']['account_sid'] : "";
        $url = str_replace('{ARF_SMS_FORMAT}', $format, $url);
        $url = str_replace('{ARF_ACCOUNT_NUMNER}', $account, $url);
        $url = str_replace('{ARF_SUBACCOUNT_ID}', $sub_account, $url);
        $url = str_replace('{ARF_ACCOUNT_KEY}', $account_key, $url);
        $url = str_replace('{ARF_DESTINATION}', $user_phone, $url);
        $url = str_replace('{ARF_PROJECT_ID}', $project_id, $url);
        return $url;
    }

    function arf_sms_write_response($request, $response){

        global $arformssms, $wp, $wpdb, $wp_filesystem;
        $now       = current_time('timestamp');
        $log_file  = "arf_sms_log.txt";
        $log_data  = '';
        $log_data .= "***** Date :: ".date("Y-M-d h:i:s", $now)." ***** \r\n";
        $log_data .= "***** Gateway Information ***** \r\n";
        $log_data .= json_encode($request);
        $log_data .= "\r\n";
        $log_data .= "***** Message Response *****\r\n";
        $log_data .= is_array($response) ? json_encode($response) : $response;
        
        $file_path = ARF_SMS_DIR . '/log/' . $log_file;
        
        if (file_exists(ABSPATH . 'wp-admin/includes/file.php')) {
            require_once(ABSPATH . 'wp-admin/includes/file.php');
            if (false === ($creds = request_filesystem_credentials($file_path, '', false, false) )) {
                return true; 
            }
            if (!WP_Filesystem($creds)) {
                request_filesystem_credentials($file_path, $method, true, false);
                return true;
            }
            $file_data = $wp_filesystem->get_contents($file_path);
            $file_data .= $log_data;
            $file_data .= "\r\n===========================================================================\r\n";
            $breaks = array("<br />", "<br>", "<br/>");
            $file_data = str_ireplace($breaks, "\r\n", $file_data);
            
            @$write_file = $wp_filesystem->put_contents($file_path, $file_data, 0755);
            if (!$write_file) {
                /* _e('Error Saving Log.', 'ARForms-SMS'); */
            }
        }
        return;
    }

	function is_arforms_paypal_support() {
		if ( file_exists( ABSPATH . 'wp-admin/includes/plugin.php' ) ) {
			include_once ABSPATH . 'wp-admin/includes/plugin.php';
		}

		return is_plugin_active( 'arformspaypal/arformspaypal.php' );
	}

	function get_arforms_paypal_version() {

		$arf_paypal_db_version = get_option( 'arf_paypal_version' );

		return ( isset( $arf_paypal_db_version ) ) ? $arf_paypal_db_version : 0;
	}
	function arf_send_test_sms() {

		global $arformssms;
		$arf_no       = ( isset( $_POST['ph_no'] ) && ! empty( $_POST['msg'] ) ) ? $_POST['ph_no'] : '';
		$arf_msg      = ( isset( $_POST['msg'] ) && ! empty( $_POST['msg'] ) ) ? $_POST['msg'] : '';
		$arf_sms_type = ( isset( $_POST['type'] ) && ! empty( $_POST['msg'] ) ) ? $_POST['type'] : '';
		$arf_msg_slug = ( isset( $_POST['msg_slug'] ) && !empty( $_POST['msg_slug'] ) ) ? $_POST['msg_slug']: '';
		$arf_phno_slug = ( isset( $_POST['ph_no_slug'] ) && !empty( $_POST['ph_no_slug'] ) ) ? $_POST['ph_no_slug']: '';

		if ( empty( $arf_msg ) || empty( $arf_no ) || empty( $arf_sms_type ) ) {
			return;
		}
		global $arformssms, $wpdb, $armainhelper, $arformcontroller;
		$arf_sms_configuration = get_option( 'arf_sms_configuration' );
		
        if (empty($arf_sms_configuration)) {
            echo json_encode(array("status" => "error", "msg" => "Missing required fields..."));
            die();
        }
        
        $response = $arformssms->arf_send_sms_to_user($arf_sms_type, $arf_msg_slug, $arf_phno_slug, $arf_no, "test_sms", $arf_msg, $arf_sms_configuration, array());
        $response = str_replace('\n', "", $response);
        $smsresponse = stripslashes($response);
        if ( !empty($smsresponse)) {
			echo json_encode(
				array(
					'status' => '1',
					'msg'    => '(' . $smsresponse . ')',
				)
			);
		}else{
			echo json_encode(
				array(
					'status' => '0',
					'msg'    => esc_html__(
						'Message not sent successfully',
						'ARForms-SMS'
					),
				)
			);
		}
        die();
	}

	function is_arforms_version() {
		if ( version_compare( $this->get_arforms_version(), '3.0', '>=' ) ) {
			return 1;
		} else {
			return 0;
		}
	}

	function arf_save_sms_config_callback() {
		global $wpdb;

		$check_cap = $this->arf_sms_check_user_capability( 'arfsmsconfiguration', true );

		if ( 'success' != $check_cap ) {
			$error = json_decode( $check_cap, true );
			echo json_encode(
				array(
					'success' => false,
					'message' => $error['msg'],
				)
			);
			die;
		}
		$message = '';

		$arf_sms_configuration = get_option( 'arf_sms_configuration' );
		if ( isset( $_POST['arf_sms_configuration'] ) && ! empty( $_POST['arf_sms_configuration'] ) ) {
			$_POST['arf_sms_configuration'] = apply_filters( 'arf_trim_values', $_POST['arf_sms_configuration'] );
			update_option( 'arf_sms_configuration', $_POST['arf_sms_configuration'] );
			$arf_sms_configuration = $_POST['arf_sms_configuration'];
			$message               = esc_html__( 'SMS setting saved successfully.', 'ARForms-SMS' );
		}

		echo json_encode(
			array(
				'success' => true,
				'message' => $message,
			)
		);
		die;

	}

	function arf_sms_check_user_capability( $capability = '', $is_ajax_call = false ) {

		if ( true == $is_ajax_call ) {

			if ( ! current_user_can( $capability ) ) {
				return json_encode(
					array(
						'msg' => esc_html__( 'Sorry, you do not have permission to perform this action', 'ARForms-SMS' ),
					)
				);

				die;
			}
		}

		$nonce = isset( $_POST['_wpnonce_arfsms'] ) ? $_POST['_wpnonce_arfsms'] : '';
		if ( '' == $nonce ) {
			$nonce = isset( $_REQUEST['_wpnonce_arfsms'] ) ? $_REQUEST['_wpnonce_arfsms'] : '';
		}

		$arfsms_nonce_flag = false;

		$arfsms_nonce_flag = wp_verify_nonce( $nonce, 'arforms_sms' );

		if ( ! $arfsms_nonce_flag ) {
			return json_encode(
				array(
					'msg' => esc_html__( 'Sorry, your request could not be processed due to security reason', 'ARForms-SMS' ),
				)
			);

			die;
		}

		return 'success';

	}

	function arf_sms_getapiurl() {
		$api_url = 'https://www.arpluginshop.com/';
		return $api_url;
	}

	function arf_sms_get_remote_post_params( $plugin_info = '' ) {
		global $wpdb, $arfversion;

		$action = '';
		$action = $plugin_info;

		if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}

		$plugin_list = get_plugins();
		$site_url    = home_url();
		$plugins     = array();

		$active_plugins = get_option( 'active_plugins' );

		foreach ( $plugin_list as $key => $plugin ) {
			$is_active = in_array( $key, $active_plugins );

			if ( strpos( strtolower( $plugin['Title'] ), 'arformssms' ) !== false ) {
				$name      = substr( $key, 0, strpos( $key, '/' ) );
				$plugins[] = array(
					'name'      => $name,
					'version'   => $plugin['Version'],
					'is_active' => $is_active,
				);
			}
		}

		$plugins = json_encode( $plugins );

		$theme            = wp_get_theme();
		$theme_name       = $theme->get( 'Name' );
		$theme_uri        = $theme->get( 'ThemeURI' );
		$theme_version    = $theme->get( 'Version' );
		$theme_author     = $theme->get( 'Author' );
		$theme_author_uri = $theme->get( 'AuthorURI' );

		$im        = is_multisite();
		$sortorder = get_option( 'arfSortOrder' );

		$post = array(
			'wp'        => get_bloginfo( 'version' ),
			'php'       => phpversion(),
			'mysql'     => $wpdb->db_version(),
			'plugins'   => $plugins,
			'tn'        => $theme_name,
			'tu'        => $theme_uri,
			'tv'        => $theme_version,
			'ta'        => $theme_author,
			'tau'       => $theme_author_uri,
			'im'        => $im,
			'sortorder' => $sortorder,
		);

		return $post;

	}

	function arf_sms_gateways_list(){
	    $arfsms_gateway_list = array(
	        /******** get ********/
	        "arf_clickatell"  	   => array(
	        	"name"         => "Clickatell",
	            "gatewaylabel" => "Clickatell ". esc_html__("Settings", 'ARForms-SMS'),
	            "data_value"   => "arf_clickatell",
	            "url"          => "https://platform.clickatell.com/messages/http/send",
	            "group"        => "get",
	            "options"      => array(
	                "apiKey" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "apiKey",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_clickatell_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "clickatell_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "content",
                        "show_in_settings" => 0,
                    ),
                    "from"                 => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 0,
                        "id"			   => "arf_clickatell_from",
                        "type"             => "text",
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'unicode',
                    	"value"			   => '1',
                    	"show_in_settings" => 0
                    )
	            )
	        ),
	        "arf_redoxygen"  => array(
	            "name"    => "Redoxygen",
	            "gatewaylabel" => "Redoxygen " . esc_html__("Settings", 'ARForms-SMS'),
	            "data_value"   => "arf_redoxygen",
	            "url"     => "http://sms1.redoxygen.net/sms.dll?Action=SendSMS",
	            "group"   => "get",
	            "options" => array(
	                "AccountID" => array(
	                    "label"            => esc_html__("AccountID", 'ARForms-SMS'),
	                    "slug"             => "AccountID",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_redoxygen_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "redoxygen_accountid",
	                    "empty_msg"        => esc_html__("Account ID can not be left blank", 'ARForms-SMS'),
	                ),
	                "Email" => array(
	                    "label"            => esc_html__("Email", 'ARForms-SMS'),
	                    "slug"             => "Email",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_redoxygen_email",
	                    "type"             => "text",
	                    "field_name"	   => "redoxygen_email",
	                    "empty_msg"        => esc_html__("Email can not be left blank", 'ARForms-SMS'),
	                ),
	                "Password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "Password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_redoxygen_password",
	                    "type"             => "text",
	                    "field_name"	   => "redoxygen_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "Recipient",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "Message",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        "arf_1s2u"  => array(
	            "name"    => "1s2u Settings",
	            "gatewaylabel" => "1s2u " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://api.1s2u.io/bulksms",
	            "data_value"   => "arf_1s2u",
	            "group"   => "get",
	            "options" => array(
	                "username" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "username",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_1s2u_username",
	                    "type"             => "text",
	                    "field_name"	   => "1s2u_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_1s2u_password",
	                    "type"             => "text",
	                    "field_name"	   => "1s2u_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "mno",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "msg",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        "arf_experttexting"  => array(
	            "name"    => "Experttexting",
	            "gatewaylabel"    => "Experttexting " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://www.experttexting.com/ExptRestApi/sms/json/Message/Send",
	            "group"   => "get",
	            "data_value"   => "arf_experttexting",
	            "options" => array(
	                "username" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "username",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_experttexting_username",
	                    "type"             => "text",
	                    "field_name"	   => "experttexting_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_experttexting_password",
	                    "type"             => "text",
	                    "field_name"	   => "experttexting_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
	                "api_key" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "api_key",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_experttexting_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "experttexting_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                ),
					"from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 1,
                        "id"               => "arf_experttexting_from",
                        "type"             => "text",
                        "empty_msg"        => __("From can not be left blank", 'ARForms-SMS'),
                    ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "text",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'type',
                    	"value"			   => 'unicode',
                    	"show_in_settings" => 0
                    )
	            )
	        ),
	        "arf_bearsms"  => array(
	            "name"    => "BearSMS",
	            "gatewaylabel"    => "BearSMS " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "http://app.bearsms.com/index.php?app=ws&op=pv",
	            "data_value"   => "arf_bearsms",
	            "group"   => "get",
	            "options" => array(
	                "u" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "u",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_bearsms_username",
	                    "type"             => "text",
	                    "field_name"	   => "bearsms_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "p" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "p",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_bearsms_password",
	                    "type"             => "text",
	                    "field_name"	   => "bearsms_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 0,
                        "id"               => "arf_bearsms_from",
                        "type"             => "text",
                    ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "text",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'unicode',
                    	"value"			   => '1',
                    	"show_in_settings" => 0
                    )
	            )
	        ),
	        "arf_spirius"  => array(
	            "name"    => "Spirius",
	            "gatewaylabel"    => "Spirius " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://get.spiricom.spirius.com:55001/cgi-bin/sendsms",
	            "group"   => "get",
	            "data_value"   => "arf_spirius",
	            "options" => array(
	                "User" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "User",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_spirius_user",
	                    "type"             => "text",
	                    "field_name"	   => "spirius_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "Pass" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "Pass",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_spirius_password",
	                    "type"             => "text",
	                    "field_name"	   => "spirius_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "From" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "From",
                        "show_in_settings" => 1,
                        "required"         => 0,
                        "id"               => "arf_spirius_From",
                        "type"             => "text",
                    ),
                    "to"                   => array(
                        "slug"             => "TO",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "Msg",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        "arf_d7sms"  => array(
	            "name"    => "D7 SMS",
	            "gatewaylabel"    => "D7 SMS " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "http://smsc.d7networks.com:1401/send",
	            "group"   => "get",
	            "data_value"   => "arf_d7sms",
	            "options" => array(
	                "username" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "username",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_d7sms_user",
	                    "type"             => "text",
	                    "field_name"	   => "d7sms_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_d7sms_password",
	                    "type"             => "text",
	                    "field_name"	   => "d7sms_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 0,
                        "id"               => "arf_d7sms_From",
                        "type"             => "text",
                    ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "content",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        /******** post ********/
	        "arf_eztexting"  => array(
	            "name"    => "EZTexting",
	            "gatewaylabel"    => "EZTexting " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://app.eztexting.com/sending/messages?format={ARF_SMS_FORMAT}",
	            "data_value"   => "arf_eztexting",
	            "data_type" => "json",
	            "group"   => "post",
	            "options" => array(
	                "format" => array(
	                    "label"            => esc_html__("Format", 'ARForms-SMS'),
	                    "slug"             => "format",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "id"               => "arf_eztexting_format",
	                    "type"             => "hidden",
	                    "value"            => "json",
	                    "default"          => "json",
	                    "field_name"	   => "eztexting_format",
	                    "empty_msg"        => esc_html__("User can not be left blank", 'ARForms-SMS'),
	                ),
	                "user" => array(
	                    "label"            => esc_html__("User", 'ARForms-SMS'),
	                    "slug"             => "User",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_eztexting_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "eztexting_username",
	                    "empty_msg"        => esc_html__("User can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "Password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_eztexting_password",
	                    "type"             => "text",
	                    "field_name"	   => "eztexting_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "PhoneNumbers",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "Message",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        "arf_ringcaptcha"  => array(
	            "name"    => "RingCaptcha",
	            "gatewaylabel"    => "RingCaptcha " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://api.ringcaptcha.com/{ARF_APP_KEY}/sms",
	            "group"   => "post",
	            "data_value"   => "arf_ringcaptcha",
	            "options" => array(
	                "app_key" => array(
	                    "label"            => esc_html__("App Key", 'ARForms-SMS'),
	                    "slug"             => "app_key",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_ringcaptcha_app_key",
	                    "type"             => "text",
	                    "field_name"	   => "ringcaptcha_app_key",
	                    "empty_msg"        => esc_html__("APP Key can not be left blank", 'ARForms-SMS'),
	                ),
	                "api_key" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "api_key",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_ringcaptcha_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "ringcaptcha_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "phone",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        "arf_bulksms"  => array(
	            "name"    => "Bulksms",
	            "gatewaylabel"    => "Bulksms " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "http://bulksms.2way.co.za/eapi/submission/send_sms/2/2.0",
	            "data_value"   => "arf_bulksms",
	            "group"   => "post",
	            "options" => array(
	                "username" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "username",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_bulksms_username",
	                    "type"             => "text",
	                    "field_name"	   => "bulksms_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_bulksms_password",
	                    "type"             => "text",
	                    "field_name"	   => "bulksms_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "msisdn",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        "arf_exotel"  => array(
	            "name"    => "Exotel",
	            "gatewaylabel"    => "Exotel " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://{ARF_APP_KEY}:{ARF_API_TOKEN}{ARF_SUB_DOMAIN}/v1/Accounts/{ARF_ACCOUNT_SID}/Sms/send",
	            "data_value"   => "arf_exotel",
	            "group"   => "post",
	            "options" => array(
	                "api_key" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "api_key",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_exotel_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "exotel_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                ),
	                "api_token" => array(
	                    "label"            => esc_html__("API Token", 'ARForms-SMS'),
	                    "slug"             => "api_token",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_exotel_api_token",
	                    "type"             => "text",
	                    "field_name"	   => "exotel_api_token",
	                    "empty_msg"        => esc_html__("API Token can not be left blank", 'ARForms-SMS'),
	                ),
	                "subdomain" => array(
	                    "label"            => esc_html__("Sub Domain", 'ARForms-SMS'),
	                    "slug"             => "subdomain",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_exotel_subdomain",
	                    "type"             => "text",
	                    "default"          => "api.exotel.com",
	                    "field_name"	   => "exotel_sub_domain",
	                    "empty_msg"        => esc_html__("Sub Domain can not be left blank. Ex: api.exotel.com", 'ARForms-SMS'),
	                ),
	                "account_sid" => array(
	                    "label"            => esc_html__("Account SID", 'ARForms-SMS'),
	                    "slug"             => "account_sid",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_exotel_account_sid",
	                    "type"             => "text",
	                    "field_name"	   => "exotel_accountsid",
	                    "empty_msg"        => esc_html__("Account SID can not be left blank", 'ARForms-SMS'),
	                ),
		    		"from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 1,
                        "id"               => "arf_exotel_from",
                        "type"             => "text",
                        "empty_msg"        => __("From No. can not be left blank", 'ARForms-SMS'),
                    ),
                    "to"                   => array(
                        "slug"             => "To",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "Body",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        /******** get_post ********/
	        "arf_text_local"  => array(
	            "name"    => "TextLocal",
	            "gatewaylabel"    => "TextLocal " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://api.textlocal.in/send",
	            "group"   => "get_post",
	            "data_value"   => "arf_text_local",
	            "options" => array(
	                "apikey" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "apikey",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_textlocal_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "textlocal_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                ),
	                "sender" => array(
	                    "label"            => esc_html__("Sender", 'ARForms-SMS'),
	                    "slug"             => "sender",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "id"               => "arf_text_local_sender",
	                    "type"             => "text",
                    ),
                    "to"                   => array(
                        "slug"             => "numbers",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'unicode',
                    	"value"			   => 'true',
                    	"show_in_settings" => 0
                    )
	            )
	        ),
	        "arf_nexmo"  => array(
	            "name"    => "Nexmo",
	            "gatewaylabel"    => "Nexmo " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://rest.nexmo.com/sms/{ARF_SMS_FORMAT}",
	            "group"   => "get_post",
	            "data_type" => "json",
	            "data_value"   => "arf_nexmo",
	            "options" => array(
	                "format" => array(
	                    "label"            => esc_html__("Format", 'ARForms-SMS'),
	                    "slug"             => "format",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "id"               => "arf_nexmo_format",
	                    "value"            => "json",
	                    "type"             => "hidden",
	                    "default"          => "json",
	                    "field_name"	   => "nexmo_format",
	                ),
	                "api_key" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "api_key",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_nexmo_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "nexmo_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                ),
	                "api_secret" => array(
	                    "label"            => esc_html__("API Secret", 'ARForms-SMS'),
	                    "slug"             => "api_secret",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_nexmo_api_secret",
	                    "type"             => "text",
	                    "field_name"	   => "nexmo_api_secret",
	                    "empty_msg"        => esc_html__("API Secret can not be left blank", 'ARForms-SMS'),
	                ),
		    		"from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 1,
                        "id"               => "arf_nexmo_from",
                        "type"             => "text",
                        "empty_msg"        => __("From can not be left blank", 'ARForms-SMS'),
                    ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "text",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'type',
                    	"value"			   => 'unicode',
                    	"show_in_settings" => 0
                    )
	            )
	        ),
	        "arf_msg91"  => array(
	            "name"    => "MSG91",
	            "gatewaylabel"    => "MSG91 " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "http://api.msg91.com/api/sendhttp.php",
	            "group"   => "get_post",
	            "data_value"   => "arf_msg91",
	            "options" => array(
	                "authkey" => array(
	                    "label"            => esc_html__("Auth Key", 'ARForms-SMS'),
	                    "slug"             => "authkey",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_msg91_auth_key",
	                    "type"             => "text",
	                    "field_name"	   => "msg91_auth_key",
	                    "empty_msg"        => esc_html__("Auth Key can not be left blank", 'ARForms-SMS'),
	                ),
	                "sender" => array(
	                    "label"            => esc_html__("Sender", 'ARForms-SMS'),
	                    "slug"             => "sender",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_msg91_sender",
	                    "type"             => "text",
	                    "field_name"	   => "msg91_sender",
	                    "empty_msg"        => esc_html__("Sender can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "mobiles",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'unicode',
                    	"value"			   => '1',
                    	"show_in_settings" => 0
                    )
	            )
	        ),
	        "arf_textbelt"  => array(
	            "name"    => "Textbelt",
	            "gatewaylabel"    => "Textbelt " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://textbelt.com/text",
	            "group"   => "get_post",
	            "data_value"   => "arf_textbelt",
	            "options" => array(
	                "key" => array(
	                    "label"            => esc_html__("Key", 'ARForms-SMS'),
	                    "slug"             => "key",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_textbelt_key",
	                    "type"             => "text",
	                    "field_name"	   => "textbelt_key",
	                    "empty_msg"        => esc_html__("Key can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "phone",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        "arf_vianett"  => array(
	            "name"    => "Vianett",
	            "gatewaylabel"    => "Vianett " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://smsc.vianett.no/v3/send",
	            "group"   => "get_post",
	            "data_value"   => "arf_vianett",
	            "options" => array(
	                "username" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "username",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_vianett_username",
	                    "type"             => "text",
	                    "field_name"	   => "vianett_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_vianett_password",
	                    "type"             => "text",
	                    "field_name"	   => "vianett_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "tel",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "msg",
                        "show_in_settings" => 0,
                    ),
	            )
	        ), 
	        "arf_smsglobal"  => array(
	            "name"    => "SMSGlobal",
	            "gatewaylabel"    => "SMSGlobal " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://api.smsglobal.com/http-api.php",
	            "group"   => "get_post",
	            "data_value"   => "arf_smsglobal",
	            "options" => array(
	                "action" => array(
	                    "label"            => esc_html__("Action", 'ARForms-SMS'),
	                    "slug"             => "action",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_smsglobal_action",
	                    "value"            => "sendsms",
	                    "type"             => "hidden",
	                    "field_name"	   => "smsglobal_action",
	                    "empty_msg"        => esc_html__("Action can not be left blank", 'ARForms-SMS'),
	                ),
	                "user" => array(
	                    "label"            => esc_html__("User", 'ARForms-SMS'),
	                    "slug"             => "user",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_smsglobal_user",
	                    "type"             => "text",
	                    "field_name"	   => "smsglobal_api_username",
	                    "empty_msg"        => esc_html__("User can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_smsglobal_password",
	                    "type"             => "text",
	                    "field_name"	   => "smsglobal_api_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
					"from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 1,
                        "id"               => "arf_smsglobal_from",
                        "type"             => "text",
                        "empty_msg"        => __("From can not be left blank", 'ARForms-SMS'),
                    ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "text",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        "arf_textmarketer"  => array(
	            "name"    => "TextMarketer",
	            "gatewaylabel"    => "TextMarketer " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://api.textmarketer.co.uk/gateway",
	            "group"   => "get_post",
	            "data_value"   => "arf_textmarketer",
	            "options" => array(
	                "username" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "username",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_textmarketer_username",
	                    "type"             => "text",
	                    "field_name"	   => "textmarketer_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_textmarketer_password",
	                    "type"             => "text",
	                    "field_name"	   => "textmarketer_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "orig" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "orig",
                        "show_in_settings" => 1,
                        "required"         => 0,
                        "id"               => "arf_textmarketer_orig",
                        "type"             => "text",
                    ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        "arf_swiftsmsgateway"  => array(
	            "name"      => "Swift SMS Gateway",
	            "gatewaylabel" => "SwiftSMSGateway " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"       => "http://smsgateway.ca/services/message.svc/{ARF_ACCOUNT_KEY}/{ARF_DESTINATION}/Unicode",
	            "group"     => "get_post",
	            "data_value"   => "arf_swiftsmsgateway",
	            "data_type" => "json",
	            "options"   => array(
	                "account_key" => array(
	                    "label"            => esc_html__("Account Key", 'ARForms-SMS'),
	                    "slug"             => "account_key",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_swiftsmsgateway_account_key",
	                    "type"             => "text",
	                    "field_name"	   => "swiftsmsgateway_accountkey",
	                    "empty_msg"        => esc_html__("Account Key can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "CellNumber",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "MessageBody",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        "arf_msgclub"  => array(
	            "name"    => "MSG Club",
	            "gatewaylabel"    => "MSGClub " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "http://msg.msgclub.net/rest/services/sendSMS/sendGroupSms",
	            "group"   => "get_post",
	            "data_value"   => "arf_msgclub",
	            "options" => array(
	                "auth_key" => array(
	                    "label"            => esc_html__("Auth Key", 'ARForms-SMS'),
	                    "slug"             => "AUTH_KEY",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_msgclub_auth_key",
	                    "type"             => "text",
	                    "field_name"	   => "msgclub_auth_key",
	                    "empty_msg"        => esc_html__("Auth Key can not be left blank", 'ARForms-SMS'),
	                ),
	                "senderId" => array(
	                    "label"            => esc_html__("Sender Id", 'ARForms-SMS'),
	                    "slug"             => "senderId",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "id"               => "arf_msgclub_senderId",
	                    "field_name"	   => "msgclub_senderid",
	                    "type"             => "text",
	                ),
                    "to"                   => array(
                        "slug"             => "mobileNos",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'smsContentType',
                    	"value"			   => 'Unicode',
                    	"show_in_settings" => 0
                    )
	            )
	        ),
	        "arf_easysendsms"  => array(
	            "name"    => "Easy Send SMS",
	            "gatewaylabel"    => "EasySendSMS " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://www.easysendsms.com/sms/bulksms-api/bulksms-api",
	            "group"   => "get_post",
	            "data_value"   => "arf_easysendsms",
	            "options" => array(
	                "username" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "username",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_easysendsms_username",
	                    "type"             => "text",
	                    "field_name"	   => "easysendsms_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_easysendsms_password",
	                    "type"             => "text",
	                    "field_name"	   => "easysendsms_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 0,
                        "id"               => "arf_easysendsms_from",
                        "type"             => "text",
                    ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "text",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'Type',
                    	"value"			   => '1',
                    	"show_in_settings" => 0
                    )
	            )
	        ),
	        "arf_cheapglobalsms"  => array(
	            "name"    => "Cheap Global SMS",
	            "gatewaylabel"    => "CheapGlobalSMS " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "http://cheapglobalsms.com/api_v1?action=send_sms",
	            "group"   => "get_post",
	            "data_value"   => "arf_cheapglobalsms",
	            "options" => array(
	                "sub_account" => array(
	                    "label"            => esc_html__("Account No", 'ARForms-SMS'),
	                    "slug"             => "sub_account",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_cheapglobalsms_sub_account",
	                    "type"             => "text",
	                    "field_name"	   => "cheapglobalsms_accountno",
	                    "empty_msg"        => esc_html__("Account No can not be left blank", 'ARForms-SMS'),
	                ),
	                "sub_account_pass" => array(
	                    "label"            => esc_html__("Account Password", 'ARForms-SMS'),
	                    "slug"             => "sub_account_pass",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_cheapglobalsms_sub_account_pass",
	                    "type"             => "text",
	                    "field_name"	   => "cheapglobalsms_account_password",
	                    "empty_msg"        => esc_html__("Account Password can not be left blank", 'ARForms-SMS'),
	                ),
                    "sender_id" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "sender_id",
                        "show_in_settings" => 1,
                        "required"         => 0,
                        "id"               => "arf_cheapglobalsms_sender_id",
                        "type"             => "text",
                    ),
                    "to"                   => array(
                        "slug"             => "recipients",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'unicode',
                    	"value"			   => '1',
                    	"show_in_settings" => 0
                    )
	            )
	        ),
	        "arf_messente"  => array(
	            "name"         => "Messente",
	            "gatewaylabel"         => "Messente " . esc_html__("Messente Settings", 'ARForms-SMS'),
	            "url"          => "https://api2.messente.com/send_sms",
	            "group"        => "get_post",
	            "data_value"   => "arf_messente",
	            "options" => array(
	                "username" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "username",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_messente_username",
	                    "type"             => "text",
	                    "field_name"	   => "messente_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_messente_password",
	                    "type"             => "text",
	                    "field_name"	   => "messente_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
					"from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 1,
                        "id"               => "arf_messente_from",
                        "type"             => "text",
                        "empty_msg"        => __("From can not be left blank", 'ARForms-SMS'),
                    ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "text",
                        "show_in_settings" => 0,
                    ),
	            )
	        ),
	        /******** post_header ********/
	        "arf_messagebird"   => array(
	            "name"         => "Message Bird",
	            "gatewaylabel"         => "MessageBird " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"          => "https://rest.messagebird.com/messages",
	            "group"        => "post_header",
	            "auth_key"     => "Authorization",
	            "auth_type"    => "AccessKey",
	            "data_value"   => "arf_messagebird",
	            "encode"       => 0,
	            "header"       => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("Authorization Key", 'ARForms-SMS'),
	                    "slug"             => "authorization",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_messagebird_authorization",
	                    "type"             => "text",
	                    "field_name"	   => "messagebird_auth_key",
	                    "empty_msg"        => esc_html__("Authorization key can not be left blank", 'ARForms-SMS'),
	                )
	            ),
	            "options" => array(
	                "originator" => array(
	                    "label"            => esc_html__("Originator", 'ARForms-SMS'),
	                    "slug"             => "originator",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_messagebird_originator",
	                    "type"             => "text",
	                    "field_name"	   => "messagebird_origi",
	                    "empty_msg"        => esc_html__("Originator can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "recipients",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "body",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'typeDetails',
                    	"value"			   => 'unicode',
                    	"show_in_settings" => 0
                    )
                ),
	       	),
	        "arf_telnyx"  => array(
	            "name"    => "Telnyx",
	            "gatewaylabel"    => "Telnyx " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://sms.telnyx.com/messages",
	            "group"   => "post_header",
	            "auth_key"     => "x-profile-secret",
	            "auth_type"    => "",
	            "encode"       => 0,
	            "data_value"   => "arf_telnyx",
	            "header"  => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("Profile Secret", 'ARForms-SMS'),
	                    "slug"             => "x-profile-secret",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_telnyx_profile-secret",
	                    "type"             => "text",
	                    "field_name"	   => "telnyx_profile_secret",
	                    "empty_msg"        => esc_html__("Profile Secret can not be left blank", 'ARForms-SMS'),
	                )
	            ),
                "options" => array(
                    "from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 1,
                        "id"               => "arf_telnyx_from",
                        "type"             => "text",
                        "empty_msg"        => __("From can not be left blank", 'ARForms-SMS'),
                    ),
	                "to"                   => array(
	                    "slug"             => "to",
	                    "show_in_settings" => 0,
	                ),
	                "message"              => array(
	                    "slug"             => "body",
	                    "show_in_settings" => 0,
	                ),
	            ),
        	),
	        "arf_routee"  => array(
	            "name"      => "Routee",
	            "gatewaylabel"      => "Routee " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"       => "https://connect.routee.net/sms",
	            "group"     => "post_header",
	            "data_type" => "json",
	            "auth_key"  => "authorization",
	            "auth_type" => "Bearer",
	            "data_value"   => "arf_routee",
	            "encode"    => 0,
	            "header"    => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("Authorization", 'ARForms-SMS'),
	                    "slug"             => "authorization",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_routee_authorization",
	                    "type"             => "text",
	                    "field_name"	   => "routee_autho",
	                    "empty_msg"        => esc_html__("Authorization can not be left blank", 'ARForms-SMS'),
	                )
	            ),
                "options" => array(
                    "from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 1,
                        "id"               => "arf_routee_from",
                        "type"             => "text",
                        "empty_msg"        => __("From can not be left blank", 'ARForms-SMS'),
                    ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "body",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'transcode',
                    	"value"			   => 'true',
                    	"show_in_settings" => 0
                    )
                ),
            ),
	        "arf_wavecell"  => array(
	            "name"         => "Wavecell",
	            "gatewaylabel"         => "Wavecell " . esc_html__("Settings", 'ARForms-SMS'),		
	            "url"          => "https://api.wavecell.com/sms/v1/{ARF_SUBACCOUNT_ID}/single",
	            "group"        => "post_header",
	            "data_type"    => "json",
	            "content_type" => "application/json",
	            "auth_key"     => "authorization",
	            "auth_type"    => "Bearer",
	            "data_value"   => "arf_wavecell",
	            "encode"       => 0,
	            "header"       => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("Authorization", 'ARForms-SMS'),
	                    "slug"             => "authorization",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_wavecell_authorization",
	                    "type"             => "text",
	                    "field_name"	   => "wavecell_autho",
	                    "empty_msg"        => esc_html__("Authorization can not be left blank", 'ARForms-SMS'),
	                )
	            ),
	            "options" => array(
	                "sub_account" => array(
	                    "label"            => esc_html__("Sub Account ID", 'ARForms-SMS'),
	                    "slug"             => "sub_account",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_wavecell_sub_account",
	                    "type"             => "text",
	                    "field_name"	   => "wavecell_sub_account",
	                    "empty_msg"        => esc_html__("Sub Account ID can not be left blank", 'ARForms-SMS'),
	                ),
	                "source" => array(
	                    "label"            => esc_html__("Source", 'ARForms-SMS'),
	                    "slug"             => "source",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_wavecell_source",
	                    "type"             => "text",
	                    "field_name"	   => "wavecell_source",
	                    "empty_msg"        => esc_html__("Source can not be left blank", 'ARForms-SMS'),
	                ),
                    "to"                   => array(
                        "slug"             => "destination",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "text",
                        "show_in_settings" => 0,
                    ),
                    "lang_type"			   => array(
                    	"slug"			   => "encoding",
                    	"value"			   => "AUTO",
                    	"show_in_settings" => 0
                    )
                ),
            ),

	        "arf_engagespark"  => array(
	            "name"      => "EngageSPARK",
	            "gatewaylabel"      => "EngageSPARK " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"       => "https://api.engagespark.com/v1/sms/phonenumber",
	            "group"     => "post_header",
	            "data_type" => "json",
	            "auth_key"  => "Authorization",
	            "auth_type" => "Token",
	            "data_value"   => "arf_engagespark",
	            "encode"    => 0,
	            "header"    => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("Authorization", 'ARForms-SMS'),
	                    "slug"             => "Authorization",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_engagespark_authorization",
	                    "type"             => "text",
	                    "field_name"	   => "engagespark_autho",
	                    "empty_msg"        => esc_html__("Authorization can not be left blank", 'ARForms-SMS'),
	                )
	            ),
	            "options" => array(
	                "orgId" => array(
	                    "label"            => esc_html__("OrgId", 'ARForms-SMS'),
	                    "slug"             => "orgId",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_engagespark_orgId",
	                    "type"             => "text",
	                    "field_name"	   => "engagespark_orgid",
	                    "empty_msg"        => esc_html__("OrgId can not be left blank", 'ARForms-SMS'),
	                ),
                        "from" => array(
                            "label"            => __("From", 'ARForms-SMS'),
                            "slug"             => "from",
                            "show_in_settings" => 1,
                            "required"         => 0,
                            "id"               => "arf_engagespark_from",
                            "type"             => "text",
                        ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
                ),
            ),
	        /******** get_post_header ********/
	        "arf_smsgatewaycenter"  => array(
	            "name"      => "SMS Gateway Center",
	            "gatewaylabel"      => "SMSGatewayCenter " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"       => "http://enterprise.smsgatewaycenter.com/SMSApi/rest/send",
	            "group"     => "get_post_header",
	            "auth_key"  => "apiKey",
	            "auth_type" => "",
	            "data_value"   => "arf_smsgatewaycenter",
	            "encode"    => 0,
	            "header"    => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "apiKey",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_smsgatewaycenter_apikey",
	                    "type"             => "text",
	                    "field_name"	   => "smsgatewaycenter_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                )
	            ),
	            "options" => array(
	                "userId" => array(
	                    "label"            => esc_html__("User Id", 'ARForms-SMS'),
	                    "slug"             => "userId",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_smsgatewaycenter_userId",
	                    "type"             => "text",
	                    "field_name"	   => "smsgatewaycenter_userid",
	                    "empty_msg"        => esc_html__("User Id can not be left blank", 'ARForms-SMS'),
	                ),
	                "password" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "password",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_smsgatewaycenter_password",
	                    "type"             => "text",
	                    "field_name"	   => "smsgatewaycenter_password",
	                    "empty_msg"        => esc_html__("Password can not be left blank", 'ARForms-SMS'),
	                ),
	                "sendMethod" => array(
	                    "label"            => esc_html__("Method Type", 'ARForms-SMS'),
	                    "slug"             => "sendMethod",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "id"               => "arf_smsgatewaycenter_sendmethod",
	                    "value"            => "simpleMsg",
	                    "type"             => "hidden",
	                    "field_name"	   => "smsgatewaycenter_method",
	                ),
	                "senderId" => array(
	                    "label"            => esc_html__("Sender Id", 'ARForms-SMS'),
	                    "slug"             => "senderId",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_smsgatewaycenter_senderId",
	                    "type"             => "text",
	                    "field_name"	   => "smsgatewaycenter_senderid",
	                    "empty_msg"        => esc_html__("Sender ID can not be left blank", 'ARForms-SMS'),
	                ),
	                "msgType" => array(
	                    "label"            => esc_html__("Message Type", 'ARForms-SMS'),
	                    "slug"             => "msgType",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "id"               => "arf_smsgatewaycenter_msgType",
	                    "type"             => "hidden",
	                    "value"            => "unicode",
	                    "field_name"	   => "smsgatewaycenter_msgtype",
	                ),
	            ),
	        ),
	        "arf_smsapi"  => array(
	            "name"      => "SMS API",
	            "gatewaylabel"      => "SMSAPI " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"       => "https://api.smsapi.com/sms.do",
	            "group"     => "get_post_header",
	            "auth_key"  => "Authorization",
	            "auth_type" => "Bearer",
	            "data_value"   => "arf_smsapi",
	            "data_type" => "json",
	            "encode"    => 0,
	            "header"    => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("Access Token", 'ARForms-SMS'),
	                    "slug"             => "access_token",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_smsapi_apikey",
	                    "type"             => "text",
	                    "field_name"	   => "smsapi_access_token",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                )
	            ),
                "options" => array(
                    "from" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "from",
                        "show_in_settings" => 1,
                        "required"         => 0,
                        "id"               => "arf_smsapi_from",
                        "type"             => "text",
                    ),
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
                ),
            ),
	        "arf_fast2sms"  => array(
	            "name"      => "Fast2SMS",
	            "gatewaylabel"      => "Fast2SMS " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"       => "https://www.fast2sms.com/dev/bulk",
	            "group"     => "get_post_header",
	            "auth_key"  => "authorization",
	            "auth_type" => "",
	            "data_type" => "",
	            "data_value"   => "arf_fast2sms",
	            "encode"    => 0,
	            "header"    => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "api_key",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_fast2sms_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "fast2sms_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                )
	            ),
	            "options" => array(
	                "sender_id" => array(
	                    "label"            => esc_html__("Sender Id", 'ARForms-SMS'),
	                    "slug"             => "sender_id",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_fast2sms_sender_id",
	                    "type"             => "text",
	                    "field_name"	   => "fast2sms_sender_id",
	                    "empty_msg"        => esc_html__("Sender ID can not be left blank", 'ARForms-SMS'),
	                ),
	                "route" => array(
	                    "label"            => esc_html__("route", 'ARForms-SMS'),
	                    "slug"             => "route",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "value"            => "p",
	                    "id"               => "arf_fast2sms_route",
	                    "field_name"	   => "fast2sms_route",
	                    "type"             => "hidden",
	                ),
	                "language" => array(
	                    "label"            => esc_html__("language", 'ARForms-SMS'),
	                    "slug"             => "language",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "value"            => "unicode",
	                    "id"               => "arf_fast2sms_language",
	                    "field_name"	   => "fast2sms_lang",
	                    "type"             => "hidden",
	                ),
                    "to"                   => array(
                        "slug"             => "numbers",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
                ),
            ),
	        "arf_alcodes"  => array(
	            "name"         => "Alcodes",
	            "gatewaylabel" => "Alcodes " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"          => "https://www.alcodes.com/api/sms-compose",
	            "group"        => "get_post_header",
	            "auth_key"     => "authorization",
	            "auth_type"    => "",
	            "data_type"    => "json",
	            "data_value"   => "arf_alcodes",
	            "encode"       => 0,
	            "header"       => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "api_key",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_alcodes_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "alcodes_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                )
	            ),
	            "options" => array(
	                "is_otp" => array(
	                    "label"            => esc_html__("Is Otp", 'ARForms-SMS'),
	                    "slug"             => "is_otp",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "id"               => "arf_alcodes_is_otp",
	                    "type"             => "hidden",
	                    "field_name"	   => "alcodes_isotp",
	                    "value"            => false,
	                ),
                        "sender_id" => array(
                            "label"            => __("Sender ID", 'ARForms-SMS'),
                            "slug"             => "sender_id",
                            "show_in_settings" => 1,
                            "required"         => 1,
                            "id"               => "arf_alcodes_Sender ID",
                            "type"             => "text",
                            "empty_msg"        => __("Sender ID can not be left blank", 'ARForms-SMS'),
                        ),
                    "to"                   => array(
                        "slug"             => "phoneNumbers",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "message",
                        "show_in_settings" => 0,
                    ),
                    'lang_type'				   => array(
                    	"slug"			   => 'smsTypeId',
                    	"value"			   => '3',
                    	"show_in_settings" => 0
                    )
                ),
            ),
	        "arf_movile"  => array(
	            "name"         => "Movile",
	            "gatewaylabel" => "Movile " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"          => "https://api-messaging.wavy.global/v1/send-sms",
	            "group"        => "post_header_user",
	            "content_type" => "application/json",
	            "data_type"    => "json",
	            "data_value"   => "arf_movile",
	            "header"       => array(
	                "authenticationtoken" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "authenticationtoken",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_movile_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "movile_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                ),
	                "username" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "username",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_movile_username",
	                    "type"             => "text",
	                    "field_name"	   => "movile_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	            ),
                "options" => array(
                    "to"                   => array(
                        "slug"             => "destination",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "messageText",
                        "show_in_settings" => 0,
                    ),
                ),
            ),
	        /******** Usdpwd ********/
	        "arf_twilio"  => array(
	            "name"    => "Twilio",
	            "gatewaylabel"    => "Twilio " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://api.twilio.com/2010-04-01/Accounts/{ARF_ACCOUNT_NUMNER}/Messages.json",
	            "group"   => "post_usdpwd",
	            "data_value"   => "arf_twilio",
	            "content_type" => "application/x-www-form-urlencoded",
	            "header"  => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("Account SID", 'ARForms-SMS'),
	                    "slug"             => "account_sid",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_twilio_account_sid",
	                    "type"             => "text",
	                    "field_name"	   => "twilio_account_sid",
	                    "empty_msg"        => esc_html__("Account SID can not be left blank", 'ARForms-SMS'),
	                ),
	                "auth_token" => array(
	                    "label"            => esc_html__("Auth Token", 'ARForms-SMS'),
	                    "slug"             => "auth_token",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "id"               => "arf_twilio_auth_token",
	                    "field_name"	   => "twilio_auth_token",
	                    "type"             => "text",
	                )
	            ),
                "options" => array(
                    "From" => array(
                        "label"            => __("From", 'ARForms-SMS'),
                        "slug"             => "From",
                        "show_in_settings" => 1,
                        "required"         => 0,
                        "id"               => "arf_twilio_from",
                        "type"             => "text",
                    ),
                    "to"                   => array(
                        "slug"             => "To",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "Body",
                        "show_in_settings" => 0,
                    ),
                )
            ),
	        "arf_telerivet"  => array(
	            "name"    => "Telerivet",
	            "gatewaylabel"    => "Telerivet " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"     => "https://api.telerivet.com/v1/projects/{ARF_PROJECT_ID}/messages/send",
	            "group"   => "post_usdpwd",
	            "data_type" => "json",
	            "content_type" => "application/json",
	            "data_value"   => "arf_telerivet",
	            "header"  => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("API Key", 'ARForms-SMS'),
	                    "slug"             => "api_key",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_telerivet_api_key",
	                    "type"             => "text",
	                    "field_name"	   => "telerivet_api_key",
	                    "empty_msg"        => esc_html__("API Key can not be left blank", 'ARForms-SMS'),
	                )
	            ),
	            "options" => array(
	                "project_id" => array(
	                    "label"            => esc_html__("Project ID", 'ARForms-SMS'),
	                    "slug"             => "project_id",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "id"               => "arf_telerivet_project_id",
	                    "type"             => "text",
	                    "field_name"	   => "telerivet_project_id",
	                ),
	            )
	        ),
	        "arf_clicksend"  => array(
	            "name"         => "ClickSend",
	            "gatewaylabel"         => "ClickSend " . esc_html__("Settings", 'ARForms-SMS'),
	            "url"          => "https://rest.clicksend.com/v3/sms/send",
	            "group"        => "post_usdpwd",
	            "data_type"    => "json",
	            "content_type" => "application/json",
	            "data_value"   => "arf_clicksend",
	            "header"       => array(
	                "account_sid" => array(
	                    "label"            => esc_html__("Username", 'ARForms-SMS'),
	                    "slug"             => "account_sid",
	                    "show_in_settings" => 1,
	                    "required"         => 1,
	                    "id"               => "arf_clicksend_account_sid",
	                    "type"             => "text",
	                    "field_name"	   => "clicksend_username",
	                    "empty_msg"        => esc_html__("Username can not be left blank", 'ARForms-SMS'),
	                ),
	                "auth_token" => array(
	                    "label"            => esc_html__("Password", 'ARForms-SMS'),
	                    "slug"             => "auth_token",
	                    "show_in_settings" => 1,
	                    "required"         => 0,
	                    "id"               => "arf_clicksend_auth_token",
	                    "type"             => "text",
	                    "field_name"	   => "clicksend_password",
	                )
	            ),
                "options" => array(
                    "to"                   => array(
                        "slug"             => "to",
                        "show_in_settings" => 0,
                    ),
                    "message"              => array(
                        "slug"             => "body",
                        "show_in_settings" => 0,
                    ),
                )
            ),
	    );
	    $arfsms_gateway_list = apply_filters("arf_sms_gateways_outside", $arfsms_gateway_list);
	    // ksort($sms_gateway_list);
	    return $arfsms_gateway_list;
	}
}

global $arf_sms_api_url, $arf_sms_plugin_slug;

$arf_sms_api_url = $arformssms->arf_sms_getapiurl();
$arf_sms_plugin_slug = basename( dirname( __FILE__ ) );

add_filter( 'pre_set_site_transient_update_plugins', 'arf_sms_check_for_plugin_update' );

function arf_sms_check_for_plugin_update( $checked_data ) {
	global $arf_sms_api_url, $arf_sms_plugin_slug, $wp_version, $arformssms, $arformssms_version;

	if ( empty( $checked_data->checked ) ) {
		return $checked_data;
	}

	$args = array(
		'slug'            => $arf_sms_plugin_slug,
		'version'         => $arformssms_version,
		'other_variables' => $arformssms->arf_sms_get_remote_post_params(),
	);

	$request_string = array(
		'body'       => array(
			'action'  => 'basic_check',
			'request' => serialize( $args ),
			'api-key' => md5( home_url() ),
		),
		'user-agent' => 'ARFSMS-WordPress/' . $wp_version . '; ' . home_url(),
	);

	$raw_response = wp_remote_post( $arf_sms_api_url, $request_string );

	if ( ! is_wp_error( $raw_response ) && ( 200 == $raw_response['response']['code'] ) ) {
		$response = maybe_unserialize( $raw_response['body'] );
	}

	if ( isset( $response ) && ! empty( $response ) && isset( $response->token ) && '' != $response->token ) {
		update_option( 'arfsms_update_token', $response->token );
	}

	if ( isset( $response ) && is_object( $response ) && is_object( $checked_data ) && ! empty( $response ) ) {
		$checked_data->response[ $arf_sms_plugin_slug . '/' . $arf_sms_plugin_slug . '.php' ] = $response;
	}

	return $checked_data;
}

add_filter( 'plugins_api', 'arf_sms_plugin_api_call', 10, 3 );

function arf_sms_plugin_api_call( $def, $action, $args ) {
	global $arf_sms_plugin_slug, $arf_sms_api_url, $wp_version;

	if ( ! isset( $args->slug ) || ( $args->slug != $arf_sms_plugin_slug ) ) {
		return false;
	}

	$plugin_info     = get_site_transient( 'update_plugins' );
	$current_version = $plugin_info->checked[ $arf_sms_plugin_slug . '/' . $arf_sms_plugin_slug . '.php' ];
	$args->version   = $current_version;

	$request_string = array(
		'body'       => array(
			'action'       => $action,
			'update_token' => get_site_option( 'arfsms_update_token' ),
			'request'      => serialize( $args ),
			'api-key'      => md5( home_url() ),
		),
		'user-agent' => 'ARFSMS-WordPress/' . $wp_version . '; ' . home_url(),
	);

	$request = wp_remote_post( $arf_sms_api_url, $request_string );

	if ( is_wp_error( $request ) ) {
		$res = new WP_Error( 'plugins_api_failed', 'An Unexpected HTTP Error occurred during the API request.</p> <p><a href="?" onclick="document.location.reload(); return false;">Try again</a>', $request->get_error_message() );
	} else {
		$res = maybe_unserialize( $request['body'] );

		if ( false === $res ) {
			$res = new WP_Error( 'plugins_api_failed', 'An unknown error occurred', $request['body'] );
		}
	}

	return $res;
}
