<?php
/*
Plugin Name: ARForms - Post Creator Add on
Description: Add On for Arforms plugin to create basic/custom post from form entries
Version: 2.1
Plugin URI: http://www.arformsplugin.com/
Author: Repute InfoSystems
Author URI: http://reputeinfosystems.com/
Text Domain: ARForms-postcreator
 */

if ( ! defined( 'ARF_POSTCREATOR_DIR' ) ) {
	define( 'ARF_POSTCREATOR_DIR', WP_PLUGIN_DIR . '/arformspostcreator' );
}
if ( ! defined( 'ARF_POSTCREATOR_URL' ) ) {
	if( is_ssl() ){
		define( 'ARF_POSTCREATOR_URL', str_replace( 'http://', 'https://', WP_PLUGIN_URL . '/arformspostcreator') );
	} else {
		define( 'ARF_POSTCREATOR_URL', WP_PLUGIN_URL . '/arformspostcreator' );
	}
}

load_plugin_textdomain( 'ARForms-postcreator', false, 'arformspostcreator/languages/' );

global $arf_postcreator;
$arf_postcreator = new ARF_PostCreator();

global $arf_postcreator_version;
$arf_postcreator_version = '2.1';

global $arf_postcreator_assets_version;
$arf_postcreator_assets_version = $arf_postcreator_version . '_' . rand( 1, 100 );

class ARF_PostCreator {


	public function __construct() {

		global $is_version_compatible, $arf_version;
		$arf_version = $this->get_arforms_version();
		$is_version_compatible = $this->is_arforms_version();

		add_action( 'init', array( $this, 'arf_postcreator_db_check' ) );

		register_activation_hook( __FILE__, array( 'ARF_PostCreator', 'install' ) );
		register_activation_hook( __FILE__, array( 'ARF_PostCreator', 'arf_postcreator_check_network_activation' ) );

		register_uninstall_hook( __FILE__, array( 'ARF_PostCreator', 'uninstall' ) );

		if( !function_exists('is_plugin_active') ){
			include_once ABSPATH . 'wp-admin/includes/plugin.php';
		}

		if( is_plugin_active( 'arforms/arforms.php' ) ){

			add_action( 'admin_menu', array( $this, 'arf_postcreator_menu' ), 27 );
			add_action( 'admin_notices', array( $this, 'arf_postcreator_admin_notices' ) );

			add_action( 'wp_ajax_arf_postcreator_delete_form', array( $this, 'arf_postcreator_delete_form' ) );

			add_action( 'wp_ajax_arf_postcreator_form_bulk_act', array( $this, 'arf_postcreator_form_bulk_act' ) );

			add_action( 'wp_ajax_arf_postcreator_field_dropdown', array( $this, 'arf_postcreator_field_dropdown' ) );

			add_action( 'wp_ajax_add_custom_field', array( $this, 'arf_postcreator_custom_field' ) );

			add_action( 'wp_ajax_arf_postcreator_file_field_dropdown', array( $this, 'arf_postcreator_file_field_dropdown' ) );

			add_action( 'wp_ajax_arf_postcreator_custom_post_field', array( $this, 'arf_postcreator_custom_post_field_dropdown' ) );

			add_action( 'wp_ajax_arf_postcreator_get_custom_categories', array( $this, 'arf_postcreator_get_custom_categories' ) );

			add_action( 'wp_ajax_arf_postcreator_get_custom_categories_new', array( $this, 'arf_postcreator_get_custom_categories_new' ) );

			add_action( 'wp_ajax_arf_postcreator_user_fill_fields', array( $this, 'arf_postcreator_user_fill_fields' ) );

			add_action( 'wp_ajax_arf_retrieve_postcreator_config_data', array( $this, 'arf_retrieve_postcreator_config_data' ) );

			add_action( 'arfbeforedestroyform', array( $this, 'arfdelete_postcreator_form' ), 11, 1 );

			add_filter( 'arf_check_for_draw_outside', array( $this, 'arf_checkifdrawoutside' ), 11, 2 );

			add_filter( 'arf_drawthisfieldfromoutside', array( $this, 'drawfieldvalue' ), 11, 4 );

			add_action( 'wp_ajax_arf_postcreator_user_fill_format_fields', array( $this, 'arf_postcreator_user_fill_format_fields' ) );

			add_action( 'admin_enqueue_scripts', array( $this, 'arf_set_js' ), 11 );

			add_action( 'admin_enqueue_scripts', array( $this, 'arf_set_css' ), 11 );

			add_filter( 'upgrader_pre_install', array( $this, 'arfpostcreator_backup' ), 10, 2 );

			add_action( 'arfaftercreateentry', array( $this, 'after_submit_form' ), 100, 2 );

			add_action( 'arf_after_paypal_successful_paymnet', array( $this, 'after_paypal_submit_form' ), 21, 3 );

			add_filter( 'arf_is_validateform_outside', array( $this, 'arfpostcreator_validate_process' ), 10, 2 );

			add_filter( 'arf_validate_form_outside_errors', array( $this, 'arf_prevalidate_fields' ), 25, 4 );

			add_action( 'user_register', array( $this, 'arf_add_capabilities_to_new_user' ) );

			add_action( 'admin_init', array( $this, 'arf_postcreator_upgrade_date' ) );

			add_action( 'wp_ajax_arf_save_postcreator_data', array( $this, 'arf_save_postcreator_data_callback' ) );
			
			add_action( 'arf_view_entry_edited', array($this, 'arf_check_update_post') );

		}
	}

	public static function arf_postcreator_check_network_activation( $network_wide ) {
		if ( ! $network_wide ) {
			return;
		}
		deactivate_plugins( plugin_basename( __FILE__ ), true, true );
		header( 'Location: ' . network_admin_url( 'plugins.php?deactivate=true' ) );
		exit;
	}

	public function arfpostcreator_getapiurl() {
		$api_url = 'https://www.arpluginshop.com/';
		return $api_url;
	}

	public function arfpostcreator_get_remote_post_params( $plugin_info = '' ) {
		global $wpdb, $arfversion;

		$action = '';
		$action = $plugin_info;

		if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}
		$plugin_list = get_plugins();
		$site_url    = home_url();
		$plugins     = array();

		$active_plugins = get_option( 'active_plugins' );

		foreach ( $plugin_list as $key => $plugin ) {
			$is_active = in_array( $key, $active_plugins );

			if ( strpos( strtolower( $plugin['Title'] ), 'arformspostcreator' ) !== false ) {
				$name      = substr( $key, 0, strpos( $key, '/' ) );
				$plugins[] = array(
					'name'      => $name,
					'version'   => $plugin['Version'],
					'is_active' => $is_active,
				);
			}
		}
		$plugins = json_encode( $plugins );

		$theme            = wp_get_theme();
		$theme_name       = $theme->get( 'Name' );
		$theme_uri        = $theme->get( 'ThemeURI' );
		$theme_version    = $theme->get( 'Version' );
		$theme_author     = $theme->get( 'Author' );
		$theme_author_uri = $theme->get( 'AuthorURI' );

		$im        = is_multisite();
		$sortorder = get_option( 'arfSortOrder' );

		$post = array(
			'wp'        => get_bloginfo( 'version' ),
			'php'       => phpversion(),
			'mysql'     => $wpdb->db_version(),
			'plugins'   => $plugins,
			'tn'        => $theme_name,
			'tu'        => $theme_uri,
			'tv'        => $theme_version,
			'ta'        => $theme_author,
			'tau'       => $theme_author_uri,
			'im'        => $im,
			'sortorder' => $sortorder,
		);

		return $post;
	}

	public function arf_postcreator_upgrade_date() {
		global $newarfpostcreatorversion;

		if ( ! isset( $newarfpostcreatorversion ) || '' == $newarfpostcreatorversion ) {
			$newarfpostcreatorversion = get_option( 'arf_postcreator_version' );
		}

		if ( version_compare( $newarfpostcreatorversion, '2.1', '<' ) ) {
			if ( file_exists( ARF_POSTCREATOR_DIR . '/core/upgrade_latest_data.php' ) ) {
				include ARF_POSTCREATOR_DIR . '/core/upgrade_latest_data.php';
			}
		}

	}

	public function arf_add_capabilities_to_new_user( $user_id ) {
		if ( $user_id == '' ) {
			return;
		}
		if ( user_can( $user_id, 'administrator' ) ) {
			$postcrtcapabilities = array(
				'arfpostcreator' => esc_html__( 'Configure Post Creator form', 'ARForms-postcreator' ),
			);
			$arfroles            = $postcrtcapabilities;
			$userObj             = new WP_User( $user_id );
			foreach ( $arfroles as $arfrole => $arfroledescription ) {
				$userObj->add_cap( $arfrole );
			}
			unset( $arfrole );
			unset( $arfroles );
			unset( $arfroledescription );
		}
	}
	public function arfdelete_postcreator_form( $form_id ) {
		global $wpdb, $db_record;
		if ( ! $form_id ) {
			return;
		}
		$res = $wpdb->query( $wpdb->prepare( 'DELETE FROM ' . $wpdb->prefix . 'arf_postcreator_forms WHERE form_id = %d', $form_id ) );
	}
	public function arf_postcreator_db_check() {
		global $arf_postcreator;
		$arf_postcreator_version = get_option( 'arf_postcreator_version' );
		if ( ! isset( $arf_postcreator_version ) || '' == $arf_postcreator_version ) {
			$arf_postcreator->install();
		}
		if ( ! current_theme_supports( 'post-thumbnails' ) ) {
			add_theme_support( 'post-thumbnails' );
		}
	}
	public static function install() {

		$arf_postcreator_version = get_option( 'arf_postcreator_version' );

		if ( ! isset( $arf_postcreator_version ) || '' == $arf_postcreator_version ) {
			global $wpdb, $arf_postcreator_version, $arf_postcreator;
			update_option( 'arf_postcreator_version', $arf_postcreator_version );
			$charset_collate = '';
			if ( ! empty( $wpdb->charset ) ) {
				$charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
			}
			if ( ! empty( $wpdb->collate ) ) {
				$charset_collate .= " COLLATE $wpdb->collate";
			}
			if ( file_exists( ABSPATH . 'wp-admin/includes/upgrade.php' ) ) {
				require_once ABSPATH . 'wp-admin/includes/upgrade.php';
			}
			$table_name = $wpdb->prefix . 'arf_postcreator_forms';
			$sql        = "CREATE TABLE {$table_name} (
                    id int(11) NOT NULL auto_increment,
                    form_id int(11) NOT NULL,
                    form_name varchar(255) default NULL,
                    options longtext default NULL,
                    created_at datetime NOT NULL,
                    PRIMARY KEY (id)
                  ) {$charset_collate};";
			dbDelta( $sql );
			$arf_postcreator->getwpversion();
		}

		$args = array(
			'role'   => 'administrator',
			'fields' => 'id',
		);

		$users = get_users( $args );
		if ( count( $users ) > 0 ) {
			foreach ( $users as $key => $user_id ) {
				$postcrtcapabilities = array(
					'arfpostcreator' => esc_html__( 'Configure Post Creator form', 'ARForms-postcreator' ),
				);
				$arfroles            = $postcrtcapabilities;
				$userObj             = new WP_User( $user_id );
				foreach ( $arfroles as $arfrole => $arfroledescription ) {
					$userObj->add_cap( $arfrole );
				}
				unset( $arfrole );
				unset( $arfroles );
				unset( $arfroledescription );
			}
		}
	}

	public static function uninstall() {
		global $wpdb,$arfform,$arf_version;
		if ( is_multisite() ) {

			if( version_compare( $arf_version, '4.3', '<' ) ){

				$blogs = $wpdb->get_results( "SELECT blog_id FROM {$wpdb->blogs}", ARRAY_A );

			}else{

				$blogs = $arfform->arf_select_db_data(true, '', $wpdb->blogs, 'blog_id', '', array(), '', '', '', false, false, 'ARRAY_A' ); 

			}

			if ( $blogs ) {
				foreach ( $blogs as $blog ) {
					switch_to_blog( $blog['blog_id'] );
					delete_option( 'arf_postcreator_version' );
					$wpdb->query( 'DROP TABLE IF EXISTS ' . $wpdb->prefix . 'arf_postcreator_forms' );
				}
				restore_current_blog();
			}
		} else {
			delete_option( 'arf_postcreator_version' );
			$wpdb->query( 'DROP TABLE IF EXISTS ' . $wpdb->prefix . 'arf_postcreator_forms' );
		}
	}

	public function arf_postcreator_admin_notices() {
		global $arf_postcreator, $wp_version,$arf_version;

		if ( version_compare( $wp_version, '4.5.0', '<' ) ) {
			deactivate_plugins( plugin_basename( __FILE__ ), true, false );
			echo "<div class='error arf_error'><p>Please meet the minimum requirement of WordPress version 4.5 to activate ARForms - Post Creator Add-on</p></div>";
		}

		if ( ! $arf_postcreator->is_arforms_support() ) {
			echo "<div class='updated'><p>" . esc_html__( 'Post Creator For ARForms plugin requires ARForms Plugin installed and active.', 'ARForms-postcreator' ) . '</p></div>';
		} else if ( ! version_compare( $arf_version, '3.0', '>=' ) ) {
			echo "<div class='updated'><p>" . esc_html__( 'Post Creator For ARForms plugin requires ARForms plugin installed with version 3.0 or higher.', 'ARForms-postcreator' ) . '</p></div>';
		}
	}

	public function is_arforms_support() {
		if ( file_exists( ABSPATH . 'wp-admin/includes/plugin.php' ) ) {
			include_once ABSPATH . 'wp-admin/includes/plugin.php';
		}
		return is_plugin_active( 'arforms/arforms.php' );
	}

	public function is_arforms_version() {
		global $arf_version;
		if ( version_compare( $arf_version, '3.0', '>=' ) ) {
			return true;
		} else {
			return false;
		}
	}

	public function is_buddypress_active(){

		if( ! defined('BP_VERSION') )
			return false;

		return true;
	}

	public function get_arforms_version() {
		$arf_db_version = get_option( 'arf_db_version' );
		return ( isset( $arf_db_version ) ) ? $arf_db_version : 0;
	}

	public static function route() {
		global $arf_postcreator;
		if ( isset( $_REQUEST['page'] ) && 'ARForms-postcreator' == $_REQUEST['page'] && isset( $_REQUEST['arfaction'] ) && ( 'new' == $_REQUEST['arfaction'] || 'edit' == $_REQUEST['arfaction'] ) ) {
			return $arf_postcreator->edit_form();
		} elseif ( isset( $_REQUEST['page'] ) && 'ARForms-postcreator' == $_REQUEST['page'] ) {
			return $arf_postcreator->list_forms();
		} else {
			return $arf_postcreator->list_forms();
		}
	}

	public function arf_postcreator_menu() {
		global $arf_version;
		if ( version_compare( $arf_version, '3.0', '>=' ) ) {
			add_submenu_page( 'ARForms', 'ARForms | ' . esc_html__( 'Post Creator Configuration', 'ARForms-postcreator' ), esc_html__( 'Post Creator Configuration', 'ARForms-postcreator' ), 'arfpostcreator', 'ARForms-postcreator', array( 'ARF_PostCreator', 'route' ) );
		}
	}

	public function arf_set_js() {
		global $arf_postcreator_assets_version,$arf_version;

		wp_register_script( 'arfpostcreator-js', ARF_POSTCREATOR_URL . '/js/arf_postcreator.js', array( 'jquery' ), $arf_postcreator_assets_version );

		wp_register_script( 'bootstrap', ARFURL . '/bootstrap/js/bootstrap.min.js', array( 'jquery' ), $arf_postcreator_assets_version );

		if( version_compare( $arf_version, '4.2', '<') ){
			wp_register_script( 'dataTable', ARFURL . '/datatables/media/js/jquery.dataTables.js', array( 'jquery' ), $arf_postcreator_assets_version );

			wp_register_script( 'ColVis', ARFURL . '/datatables/media/js/ColVis.js', array( 'dataTable' ), $arf_postcreator_assets_version );

			wp_register_script( 'FixedColumns', ARFURL . '/datatables/media/js/FixedColumns.js', array( 'jquery' ), $arf_postcreator_assets_version );
		}

		wp_register_script( 'tipso', ARFURL . '/js/tipso.min.js', array( 'jquery' ), $arf_postcreator_assets_version );

		wp_register_script( 'bootstrap-typeahead', ARFURL . '/bootstrap/js/bootstrap-typeahead.js', array( 'jquery' ), $arf_postcreator_assets_version );

		if ( isset( $_REQUEST['page'] ) && '' != $_REQUEST['page'] && 'ARForms-postcreator' == $_REQUEST['page'] ) {
			wp_enqueue_script( 'arfpostcreator-js' );
			if( version_compare( $arf_version, '4.2', '<' )){
				wp_enqueue_script( 'dataTable' );
				wp_enqueue_script( 'ColVis' );
				wp_enqueue_script( 'FixedColumns' );
			} else {
				wp_enqueue_script( 'datatables' );
                wp_enqueue_script( 'buttons-colvis' );
                wp_enqueue_style( 'datatables' );
			}
			wp_enqueue_script( 'tipso' );
			wp_enqueue_script( 'bootstrap-typeahead' );
			wp_enqueue_script('bootstrap');
		}
		
		$script_data  = "__ARF_NO_FILES_SELECTED='" . esc_html__( 'No file Selected', 'ARForms-postcreator' ) . "';";
		$script_data .= "__ARF_SEARCH_PLACEHOLDER='" . esc_html__( 'Search', 'ARForms-postcreator' ) . "';";
		$script_data .= "__ARF_DB_VERSION= parseFloat ( '" . $arf_version . "');";

		$script_data .= "__ARF_NO_FILES_SELECT='" . esc_html__( 'Please select valid action.', 'ARForms-postcreator' ) . "';";

		$script_data .= "__ARF_SELECT_ONE_FILE='" . esc_html__( 'Please select one or more record to perform action.', 'ARForms-postcreator' ) . "';";
					
		wp_add_inline_script( 'arfpostcreator-js', $script_data, 'before' );
	}

	public function arf_set_css( $hook ) {
		global $arf_postcreator_assets_version;

		wp_register_style( 'arfpostcreator-css', ARF_POSTCREATOR_URL . '/css/arf_postcreator.css', array(), $arf_postcreator_assets_version );

		wp_register_style( 'bootstrap', ARFURL . '/bootstrap/css/bootstrap.css', array(), $arf_postcreator_assets_version );

		wp_register_style( 'tipso', ARFURL . '/css/tipso.min.css', array(), $arf_postcreator_assets_version );

		if ( isset( $_REQUEST['page'] ) && '' != $_REQUEST['page'] && 'ARForms-postcreator' == $_REQUEST['page'] ) {
			wp_enqueue_style( 'arfpostcreator-css' );
			wp_enqueue_style( 'arfbootstrap-css' );
			wp_enqueue_style( 'tipso' );
		}

		if( isset( $hook ) && 'plugins.php' == $hook ){
			global $wp_version;

			if( version_compare($wp_version, '4.5', '<') ){
				wp_print_styles( 'arfpostcreator-css' );
				deactivate_plugins( plugin_basename( __FILE__ ), true, false );
				$redirect_url = network_admin_url( 'plugins.php?deactivate=true' );
				wp_die( '<div class="arf_pc_wp_notice"><p class="arf_pc_wp_notice_text" >Please meet the minimum requirement of WordPress version 4.5 to activate ARForms - Post Creator Add-on<p class="arf_pc_wp_notice_continue">Please <a href="javascript:void(0)" onclick="window.location.href=\'' . $redirect_url . '\'">Click Here</a> to continue.</p></div>' );
			}
		}
	}

	public function list_forms( $message = '' ) {
		require ARF_POSTCREATOR_DIR . '/core/list_forms_3.0.php';
	}

	public function arf_checkifdrawoutside( $check, $field ) {
		global $wpdb, $arf_postcreator,$arfform,$MdlDb,$arf_version;
		$form_id = $field['form_id'];

		$field_id = $field['id'];
		if ( isset( $_GET['arfaction'] ) && 'preview' == $_GET['arfaction'] ) {
			return $check;
		}

		$form_data   = $wpdb->get_row($wpdb->prepare("SELECT * FROM " . $MdlDb->forms . " WHERE id = %d", $form_id));

		$form_mapped = maybe_unserialize( $form_data->arf_mapped_addon );

		if ( isset( $form_mapped ) && ! empty( $form_mapped ) ) {
			$form_mapped = $form_mapped['arf_mapped_addon'];
			if ( ! in_array( 'postcreator', $form_mapped ) ) {
				return $check;
			}
		}

		if( version_compare( $arf_version, '4.3', '<' ) ){
			
			$data = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM ' . $wpdb->prefix . 'arf_postcreator_forms WHERE form_id =%d ', $form_id ) );

		}else{
			
			$tblnm = $wpdb->prefix . 'arf_postcreator_forms pst LEFT JOIN ' . $MdlDb->forms . ' frm ON pst.form_id = frm.id';
			$data = $arfform->arf_select_db_data( true, '', $tblnm , 'pst.*', 'WHERE pst.form_id = %d', array($form_id));

		}

		$opt  = ! empty( $data ) ? maybe_unserialize( $data[0]->options ) : array();
		
		if ( ! empty( $opt ) ) {
			if ( $opt['post_type'] != 'basic' ) {
				$custom_cats = isset($opt['custom_categories']) ? $opt['custom_categories'] : array();
				if ( is_array( $custom_cats ) ) {
					foreach ( $custom_cats as $cats ) {
						if ( isset($opt['category_single'][ $cats ][0]) && $opt['category_single'][ $cats ][0] != '' ) {
							if ( $opt['category_single'][ $cats ][0] == $field_id ) {
								$check = true;
							}
						}
					}
				}
			} else {
				if ( $opt['category_single'][0] != '' ) {

					if ( $opt['category_single'][0] == $field['id'] ) {
						$check = true;
					}
				}
			}
			if ( isset( $opt['post_format'] ) && $opt['post_format'] == $field['id'] && $opt['post_format_fixed'] == 0 ) {
				$check = true;
			}
			if ( $opt['description'] == $field['id'] && $opt['description'] != '' ) {
				$check = true;
			}

			if( 'buddypress_grp' == $opt['post_type'] ){
				if ( isset($opt['bp_group_name']) && $opt['bp_group_name'] == $field['id'] && $opt['bp_group_name'] != '') {
					$check = true;
				}

				$membersingrp = array();
				if ($arf_postcreator->is_buddypress_active() && bp_is_active('groups')) {
					$arf_current_userid = get_current_user_id();
					$membersingrp = BP_Groups_Member::get_group_ids($arf_current_userid);
				}
				if (empty($membersingrp['groups']) || empty($membersingrp)) {
					$check = false;
				}
			}
		}

		return $check;
	}

	public function drawfieldvalue( $return_string, $field, $arf_on_change_function, $arf_data_uniq_id ) {
		global $wpdb, $arfieldhelper, $armainhelper, $arfieldcontroller, $arf_postcreator, $arf_form_all_footer_js, $arfform, $MdlDb, $arf_version, $arformcontroller, $maincontroller;

		$field_id    = $field['id'];
		$form_id     = $field['form_id'];


		$form_data   = $wpdb->get_row($wpdb->prepare("SELECT * FROM " . $MdlDb->forms . " WHERE id = %d", $form_id));

		$form_mapped = maybe_unserialize( $form_data->arf_mapped_addon );
		$form_mapped = $form_mapped['arf_mapped_addon'];
		$exclude     = array();
		$value       = array();
		$form_css 	 = maybe_unserialize( $form_data->form_css );
		$inputStyle = $form_css['arfinputstyle'];
		if ( isset( $form_mapped ) && ! empty( $form_mapped ) ) {
			if ( ! in_array( 'postcreator', $form_mapped ) ) {
				return $return_string;
			}
		}
		

		if( version_compare( $arf_version, '4.3', '<' ) ){

			$data = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM ' . $wpdb->prefix . 'arf_postcreator_forms WHERE form_id =%d ', $form_id ) );

		}else{

			$tblnm = $wpdb->prefix . 'arf_postcreator_forms pst LEFT JOIN ' . $MdlDb->forms . ' frm ON pst.form_id = frm.id';
			$data = $arfform->arf_select_db_data( true, '', $tblnm, 'pst.*','WHERE pst.form_id = %d', array($form_id));

		}

		$opt  = maybe_unserialize( $data[0]->options );
		
		$field_tooltip = '';
		
		if ( isset( $field['tooltip_text'] ) and $field['tooltip_text'] != '' ) {
			$field_tooltip = $arfieldhelper->arf_tooltip_display( $field['tooltip_text'] );
		}

		$inline_css_with_style_tag = '';
		$inline_css_without_style  = '';
		$arf_main_label_cls = '';
		if( $field['type'] == 'select' && $inputStyle == 'material_outlined' ){
            $arf_main_label_cls = ' active ';
        }
		$arf_required = '';
        if ($field['required']) {
            $field['required_indicator'] = ( isset($field['required_indicator']) && ($field['required_indicator'] != '' )) ? $field['required_indicator'] : '*';
            $arf_required = '<span class="arfcheckrequiredfield">' . $field['required_indicator'] . '</span>';
        }
		$arf_main_label = '';
        if( $field['name'] != '' ){
            $arf_main_label .='<label data-type="'.$field['type'].'" class="arf_main_label '.$arf_main_label_cls.'">' . $field['name'];
            $arf_main_label .=$arf_required;
            $arf_main_label .='</label>';
        }else{
            $arf_material_outliner_cls = ' arf_material_outliner_display ';
        }

		$arf_input_field_html  = '';
		$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
		$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
		if ( isset( $opt['post_format'] ) && $opt['post_format'] == $field['id'] && $opt['post_format_fixed'] == 0 ) {
			$is_format = '';
			if ( current_theme_supports( 'post-formats' ) ) {
				$post_formats = get_theme_support( 'post-formats' );

				if ( is_array( $post_formats[0] ) ) {
					$post_formats_single = $post_formats[0];
					$is_format           = 1;
				}
			}
			if ( $field['type'] == 'radio' ) {
				$defaults = array(
					'field'      => 0,
					'field_name' => false,
					'opt_key'    => 0,
					'opt'        => '',
					'type'       => $field['type'],
					'value'      => false,
					'exclude'    => 0,
					'hide_id'    => false,
				);

				if ( !isset($field_name) ) {
					$field_name = "item_meta[$field_id]";
				}
				$onchange = '';

				$sanitized_name = ( isset( $field['id'] ) ) ? $field['id'] . '-0' : 'standard-0';
				if ( isset( $field['align'] ) && $field['align'] == 'arf_col_2' ) {
					$return_string .= '<div class="arf_chk_radio_col_two">';
				} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_3' ) {
					$return_string .= '<div class="arf_chk_radio_col_thiree">';
				} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_4' ) {
					$return_string .= '<div class="arf_chk_radio_col_four">';
				}

				$return_string        .= '<div class="arf_radiobutton">';
				$_REQUEST['arfaction'] = ( isset( $_REQUEST['arfaction'] ) ) ? $_REQUEST['arfaction'] : '';
				$return_string        .= "<div class='arf_radio_input_wrapper'>";
				$return_string        .= '<input type="radio" name="' . $field_name . '[]" id="field_' . $sanitized_name . '" value="Standard"';

				$return_string .= $arf_input_field_html;
				
				if ( isset( $key ) && $key == 0 ) {
					if ( isset( $field['required'] ) and $field['required'] ) {
						$return_string .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
					}
				}

				if ( isset( $_REQUEST['arfaction'] ) && $_REQUEST['arfaction'] == 'preview' ) {
					$return_string .= $arf_on_change_function;
				}

				$return_string .= " {$arf_on_change_function} />";
				$return_string .= '<span>';
				/*if ( $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arfcheckradiostyle'] == 'custom' ) {
					$custom_radio   = $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arf_checked_radio_icon'];
					$return_string .= "<i class='arfa {$custom_radio}'></i>";
				}*/
				$return_string .= '</span>';
				$return_string .= '</div>';
				$return_string .= '<label for="field_' . $sanitized_name . '" >';
				$return_string .= 'Standard';

				$return_string .= '</label>';

				$return_string .= '</div>';
				if ( $is_format == 1 ) {
					$cntr = 2;
					foreach ( $post_formats_single as $key => $format ) {
						if ( is_array( $value ) ) {
							$checked = ( in_array( $format, $value ) ) ? 'checked="checked" ' : '';
						} elseif ( $format == $value ) {
							$checked = 'checked="checked" ';
						} else {
							$checked = '';
						}
						$class = '';

						$sanitized_name = ( isset( $field['id'] ) ) ? $field['id'] . '-' . $cntr : $format . '-' . $cntr;

						$return_string        .= '<div class="arf_radiobutton">';
						$_REQUEST['arfaction'] = ( isset( $_REQUEST['arfaction'] ) ) ? $_REQUEST['arfaction'] : '';
						$return_string        .= "<div class='arf_radio_input_wrapper'>";
						$return_string        .= '<input type="radio" name="' . $field_name . '[]" id="field_' . $sanitized_name . '" value="' . esc_attr( $format ) . '"';

						$return_string .= $arf_input_field_html;
						if ( $key == 0 ) {
							if ( isset( $field['required'] ) and $field['required'] ) {
								$return_string .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
							}
						}

						if ( isset( $_REQUEST['arfaction'] ) && $_REQUEST['arfaction'] == 'preview' ) {
							$return_string .= $arf_on_change_function;
						}

						$return_string .= " {$arf_on_change_function} />";
						$return_string .= '<span>';
						/*if ( $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arfcheckradiostyle'] == 'custom' ) {
							$custom_radio   = $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arf_checked_radio_icon'];
							$return_string .= "<i class='arfa {$custom_radio}'></i>";
						}*/
						$return_string .= '</span>';
						$return_string .= '</div>';
						$return_string .= '<label for="field_' . $sanitized_name . '" >';
						$return_string .= $format;

						$return_string .= '</label>';

						$return_string .= '</div>';

						if ( isset( $field['align'] ) && $field['align'] == 'arf_col_2' ) {
							if ( $cntr % 2 == 0 ) {
								$return_string .= '</div><div class="arf_chk_radio_col_two">';
							}
						} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_3' ) {
							if ( $cntr % 3 == 0 ) {
								$return_string .= '</div><div class="arf_chk_radio_col_thiree">';
							}
						} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_4' ) {
							if ( $cntr % 4 == 0 ) {
								$return_string .= '</div><div class="arf_chk_radio_col_four">';
							}
						}
						$cntr++;
					}
				}
				if ( isset( $field['align'] ) && ( $field['align'] == 'arf_col_2' || $field['align'] == 'arf_col_3' || $field['align'] == 'arf_col_4' ) ) {
					$return_string .= '</div>';
				}
			} elseif ( $field['type'] == 'select' ) {
				$defaults = array(
					'field'      => 0,
					'field_name' => false,
					'opt_key'    => 0,
					'opt'        => '',
					'type'       => 'select',
					'value'      => false,
					'exclude'    => 0,
					'hide_id'    => false,
				);

				if ( ! isset( $field_name ) ) {
					$field_name = "item_meta[$field_id]";
				}

				$level           = isset( $opt_key ) ? 2 : 1;
				$data_validation = '';
				if ( isset( $field['required'] ) and $field['required'] ) {
					$data_validation = 'data-validation-required-message="' . esc_attr( $field['blank'] ) . '"';
				}
				
                if( $inputStyle == 'material_outlined' ){
                   $return_string .= '<div class="arf_material_outline_container">';
                }

                $select_attrs = array();
                $pattern = '/(onChange|onchange)\=(\'|\")(.*)(\'|\")/';
                if( !empty( $arf_on_change_function ) ){
                    preg_match( $pattern, $arf_on_change_function, $match );
                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
                        $select_attrs[ $match[1] ] = $match[3];
                    }
                }

                $pattern = '/(onKeyup|onkeyup)\=(\'|\")(.*)(\'|\")/';
                if( !empty( $arf_on_change_function ) ){
                    preg_match( $pattern, $arf_on_change_function, $match );
                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
                        $select_attrs[ $match[1] ] = $match[3];
                    }
                }

                if( method_exists( $maincontroller, 'arf_selectpicker_dom' ) ){
                	foreach( $post_formats_single as $key => $format ){
                		$post_format_arr[ ucwords( $format ) ] = ucwords( $format );
                	}
                	$input_class = "";
                	if( 'material_outlined' == $inputStyle && !preg_match('/(arf_material_active)/', $arf_input_field_html) ){
	                    $input_class = ' arf_material_active ';
	                }
                	$select_attrs['class']	=	$input_class;

                	$return_string .= $maincontroller->arf_selectpicker_dom( $field_name, 'field_' . $field['field_key'], ' arf_form_field_picker ', '', '', $select_attrs, $post_format_arr );

                } else {

					$return_string .= '<select name="' . $field_name . '" ' . $data_validation . ' id="field_' . $field['field_key'] . '"';
					if( 'material_outlined' == $inputStyle && !preg_match('/(arf_material_active)/', $arf_input_field_html) ){
	                    $return_string .= ' class="arf_material_active" ';
	                }
					$return_string .= $arf_input_field_html;
					$return_string .= $arf_input_field_html;

					$return_string .= ' data-size="15"  ' . $arf_on_change_function . ' >';
					$count_i        = 0;
					$return_string .= '<option value="" ';
					$return_string .= ' data-content="' . esc_html__( 'Please Select', 'ARForms-postcreator' ) . '">' . esc_html__( 'Please Select', 'ARForms-postcreator' ) . '</option>';
					$return_string .= '<option value="0" ';
					$return_string .= ' data-content="' . esc_html__( 'Standard', 'ARForms-postcreator' ) . '">' . esc_html__( 'Standard', 'ARForms-postcreator' ) . '</option>';
					if ( $is_format == 1 ) {
						foreach ( $post_formats_single as $key => $format ) {
							$return_string .= '<option value="' . esc_attr( $format ) . '" ';
							$return_string .= ' data-content="' . ucwords( $format ) . '">' . ucwords( $format ) . '</option>';
							$count_i++;
						}
					}
					$return_string .= '</select>';
                }
				if( $inputStyle == 'material_outlined' ){
                    $return_string .= '<div class="arf_material_outliner arf_material_active">';
                        $return_string .= '<div class="arf_material_outliner_prefix"></div>';
                        $return_string .= '<div class="arf_material_outliner_notch">';
                            $return_string .= $arf_main_label;
                        $return_string .= '</div>';
                        $return_string .= '<div class="arf_material_outliner_suffix"></div>';
                    $return_string .= '</div>';
                $return_string .= '</div>';
                }
			}
		} elseif ( $opt['description'] == $field['id'] && $opt['description'] != '' ) {
			if( 'material_outlined' == $inputStyle ){
                $material_outlined_cls = '';
                if( !empty( $field['enable_arf_prefix'] ) || !empty( $field['enable_arf_suffix'] ) ){
                    $material_outlined_cls = 'arf_material_outline_container_with_icons';
                }
                if( !empty( $field['enable_arf_prefix'] ) && empty( $field['enable_arf_suffix'] ) ){
                    $material_outlined_cls .= ' arf_only_leading_icon ';
                }
                if( empty( $field['enable_arf_prefix'] ) && !empty( $field['enable_arf_suffix'] ) ){
                    $material_outlined_cls .= ' arf_only_trailing_icon ';
                }
                $return_string .= '<div class="arf_material_outline_container '.$material_outlined_cls.' ">';

                $return_string .= $arformcontroller->arf_prefix_suffix_for_outlined($field);
            }
			$return_string .= '<textarea name="' . 'item_meta[' . $field['id'] . ']' . '" id="field_' . $field['field_key'] . '_' . $arf_data_uniq_id . '" ';
			if ( isset( $field['max_rows'] ) && $field['max_rows'] ) {
				$return_string .= ' rows="' . $field['max_rows'] . '" ';
			}
			$return_string .= $arf_input_field_html;

			if ( ( isset( $field['clear_on_focus'] ) and $field['clear_on_focus'] and ! empty( $field['default_value'] ) ) ) {

			} else {
				if ( isset( $field['default_blank'] ) && $field['default_blank'] == 0 && $field['placeholdertext'] != '' ) {
					$return_string .= ' placeholder="' . trim( esc_attr( $field['placeholdertext'] ) ) . '"';
				}
			}

			if ( isset( $field['required'] ) and $field['required'] ) {
				$return_string .= ' data-validation-required-message="' . esc_attr( $field['blank'] ) . '" ';
			}

			if ( $field['max'] != '' ) {

				$return_string .= ' data-validation-maxlength-message="' . esc_html__( 'Invalid maximum characters length', 'ARForms-postcreator' ) . '" ';
			}
			if ( $field['minlength'] != '' ) {
				$return_string .= ' minlength="' . $field['minlength'] . '" data-validation-minlength-message="' . esc_attr( $field['minlength_message'] ) . '" ';
			}
			if ( isset( $field['placeholdertext'] ) && $field['placeholdertext'] != '' ) {
				$return_string .= 'placeholder="' . esc_attr( $field['placeholdertext'] ) . '"';
			}

			$return_string .= $arf_on_change_function . ' >';
			if ( isset( $field['set_field_value'] ) ) {
				$return_string .= trim( $field['set_field_value'] );
			} else {
				if ( ( isset( $field['clear_on_focus'] ) and $field['clear_on_focus'] and ! empty( $field['default_value'] ) ) ) {
					if ( $field['default_blank'] == 1 ) {
						$return_string .= trim( esc_attr( $field['value'] ) );
					}
				} else {
					if ( isset( $field['default_blank'] ) && $field['default_blank'] == 1 ) {
						$return_string .= trim( esc_attr( $field['value'] ) );
					}
				}
			}
			$return_string .= '</textarea>';
			if( 'material_outlined' == $inputStyle ){
                $return_string .= '<div class="arf_material_outliner">';
                    $return_string .= '<div class="arf_material_outliner_prefix"></div>';
                    $return_string .= '<div class="arf_material_outliner_notch">';
                        $return_string .= $arf_main_label;
                    $return_string .= '</div>';
                    $return_string .= '<div class="arf_material_outliner_suffix"></div>';
                $return_string .= '</div>';
                $return_string .= '</div>';
            }
		} elseif ( $arf_postcreator->is_buddypress_active() && bp_is_active('groups') && $opt['bp_group_name'] == $field['id'] && $opt['bp_group_name'] != ''){
			if ( $field['type'] == 'radio' || $field['type'] == 'checkbox' ) {
				if ( ! isset( $field_name ) ) {
					$field_name = "item_meta[$field_id]";
				}
				$onchange = '';

				if ( isset( $field['align'] ) && $field['align'] == 'arf_col_2' ) {
					$return_string .= '<div class="arf_chk_radio_col_two">';
				} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_3' ) {
					$return_string .= '<div class="arf_chk_radio_col_thiree">';
				} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_4' ) {
					$return_string .= '<div class="arf_chk_radio_col_four">';
				}
				
				$arf_chk_counter = 1;
				$vgroups = $groups = BP_Groups_Group::get(array('type'=>'alphabetical'));
				$arf_current_userid = get_current_user_id();
				$membersingrp = BP_Groups_Member::get_group_ids($arf_current_userid);
				$count = 1;
				$arf_groups_list =  $vgroups['groups'];
				foreach ( $arf_groups_list as $key => $group ) {
					$group_name = $group->name;

					if (in_array($group->id, $membersingrp['groups'])) {
						$arf_input_field_html  = '';
						$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
						$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
						$field_id = $field['id'];
						$class = '';
						$field_name = 'item_meta['.$field_id.']';
						if ( $field['type'] == 'checkbox' ) {
							$return_string        .= '<div class="arf_checkbox_style" id="frm_checkbox_' . $field['id'] . '">';
							$_REQUEST['arfaction'] = ( isset( $_REQUEST['arfaction'] ) ) ? $_REQUEST['arfaction'] : '';
							$return_string        .= "<div class='arf_checkbox_input_wrapper'>";
							$return_string        .= '<input type="checkbox" name="' . $field_name . '[]" id="field_' . $field['id'] . '_'. $count .'" value="' . $group->id . '"';

							$return_string .= $arf_input_field_html;
							if ( isset( $field['required'] ) and $field['required'] ) {
								$return_string .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
							}
						

							if ( isset( $_REQUEST['arfaction'] ) && $_REQUEST['arfaction'] == 'preview' ) {
								$return_string .= $arf_on_change_function;
							}

							$return_string .= " {$arf_on_change_function} />";
							$return_string .= '<span>';
							/*if ( $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arfcheckradiostyle'] == 'custom' ) {
								$custom_checkbox = $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arf_checked_checkbox_icon'];
								$return_string  .= "<i class='arfa {$custom_checkbox}'></i>";
							}*/
							$return_string .= '</span>';
							$return_string .= '</div>';
							$return_string .= '<label for="field_' . $field['id'] . '_'. $count .'" >';
							$return_string .= $group_name;

							$return_string .= '</label>';

							$return_string .= '</div>';
						}

						if ( $field['type'] == 'radio' ) {
							$return_string        .= '<div class="arf_radiobutton">';
							$_REQUEST['arfaction'] = ( isset( $_REQUEST['arfaction'] ) ) ? $_REQUEST['arfaction'] : '';
							$return_string        .= "<div class='arf_radio_input_wrapper'>";
							$return_string        .= '<input type="radio" name="' . $field_name . '" id="field_'. $field['id'] . '_'. $count .'" value="' . $group->id . '"';

							$return_string .= $arf_input_field_html;
							if ( isset( $field['required'] ) and $field['required'] ) {
								$return_string .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
								
							}

							if ( isset( $_REQUEST['arfaction'] ) && $_REQUEST['arfaction'] == 'preview' ) {
								$return_string .= $arf_on_change_function;
							}

							$return_string .= " {$arf_on_change_function} />";
							$return_string .= '<span>';
							/*if ( $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arfcheckradiostyle'] == 'custom' ) {
								$custom_radio   = $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arf_checked_radio_icon'];
								$return_string .= "<i class='arfa {$custom_radio}'></i>";
							}*/
							$return_string .= '</span>';
							$return_string .= '</div>';
							$return_string .= '<label for="field_' . $field['id'] . '_'. $count .'" >';
							$return_string .= $group_name;

							$return_string .= '</label>';

							$return_string .= '</div>';
						}
					}
					if ( isset( $field['align'] ) && $field['align'] == 'arf_col_2' ) {
						if ( $arf_chk_counter % 2 == 0 ) {
							$return_string .= '</div><div class="arf_chk_radio_col_two">';
						}
					} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_3' ) {
						if ( $arf_chk_counter % 3 == 0 ) {
							$return_string .= '</div><div class="arf_chk_radio_col_thiree">';
						}
					} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_4' ) {
						if ( $arf_chk_counter % 4 == 0 ) {
							$return_string .= '</div><div class="arf_chk_radio_col_four">';
						}
					}
					$count++;
					$arf_chk_counter++;
				}
				if ( isset( $field['align'] ) && ( $field['align'] == 'arf_col_2' || $field['align'] == 'arf_col_3' || $field['align'] == 'arf_col_4' ) ) {
					$return_string .= '</div>';
				}
			}else if ( $field['type'] == 'select' ) {
				$defaults = array(
					'field'      => 0,
					'field_name' => false,
					'opt_key'    => 0,
					'opt'        => '',
					'type'       => 'select',
					'value'      => false,
					'exclude'    => 0,
					'hide_id'    => false,
				);

				if ( ! isset( $field_name ) ) {
					$field_name = "item_meta[$field_id]";
				}
				$onchange = '';	
				$inline_css_with_style_tag = '';
				$inline_css_without_style  = '';

				$arf_input_field_html  = '';
				$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
				$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
				$level                 = isset( $opt_key ) ? 2 : 1;
				$field['options']      = $arfieldhelper->changeoptionorder( $field );
				if( $inputStyle == 'material_outlined' ){
                   $return_string .= '<div class="arf_material_outline_container">';
                }
                if( method_exists( $maincontroller, 'arf_selectpicker_dom') ){
                	$group_list_arr = array();
                	$vgroups = $groups = BP_Groups_Group::get(array('type'=>'alphabetical'));
					$arf_current_userid = get_current_user_id();
					$membersingrp = BP_Groups_Member::get_group_ids($arf_current_userid);
					if( !isset( $select_attrs ) ){
						$select_attrs = array();
					}
					$pattern = '/(onChange|onchange)\=(\'|\")(.*)(\'|\")/';
					if( !empty( $arf_on_change_function ) ){
					    preg_match( $pattern, $arf_on_change_function, $match );
					    if( !empty( $match[1] ) && !empty( $match[3] ) ){
					        $select_attrs[ $match[1] ] = $match[3];
					    }
					}

					$pattern = '/(onKeyup|onkeyup)\=(\'|\")(.*)(\'|\")/';
					if( !empty( $arf_on_change_function ) ){
					    preg_match( $pattern, $arf_on_change_function, $match );
					    if( !empty( $match[1] ) && !empty( $match[3] ) ){
					        $select_attrs[ $match[1] ] = $match[3];
					    }
					}

					$arf_groups_list =  $vgroups['groups'];
					$arf_group_list_cls = array(
						'' => esc_html__( 'Please Select', 'ARForms-postcreator' )
					);
					$count_i = 0;
                	foreach( $arf_groups_list as $key => $group ){
                		$count_i++;
                		$group_list_arr[ $group->id ] = $group->name;
                		$arf_group_list_cls[ $group->id ] = 'frm_bpgroup_' . $count_i;
                	}
                	if( 'material_outlined' == $inputStyle) {
	                    $select_attrs['class'] = 'arf_material_active';
	                }
                	$return_string .= $maincontroller->arf_selectpicker_dom( $field_name, 'field_' . $field['field_key'] . '_' . $arf_data_uniq_id, 'arf_form_field_picker', '', '', $select_attrs, $group_list_arr );
                } else {
					$return_string        .= '<select name="' . $field_name . '"';
					if ( isset( $field['required'] ) and $field['required'] ) {
						$return_string .= ' data-validation-required-message="' . esc_attr( $field['blank'] ) . '"';
					}
					$return_string .= ' id="field_' . $field['field_key'] . '_' . $arf_data_uniq_id . '" ';
					$return_string .= $arf_input_field_html;
					if( 'material_outlined' == $inputStyle && !preg_match('/(arf_material_active)/', $arf_input_field_html) ){
	                    $return_string .= ' class="arf_material_active" ';
	                }

					$return_string .= ' data-size="15"  ' . $arf_on_change_function . ' >';
					$return_string .= '<option value="">' . esc_html__( 'Please Select', 'ARForms-postcreator' ) . '</option>';
					$count_i        = 0;
					$vgroups = $groups = BP_Groups_Group::get(array('type'=>'alphabetical'));
					$arf_current_userid = get_current_user_id();
					$membersingrp = BP_Groups_Member::get_group_ids($arf_current_userid);

					$arf_groups_list =  $vgroups['groups'];
					foreach ( $arf_groups_list as $key => $group ) {
						$count_i++;
						if (in_array($group->id, $membersingrp['groups'])) {
							$return_string .='<option value="'. $group->id .'" class="frm_bpgroup_'.$count_i.'" id="field_'.$field_id.'"_"'.$count_i.'" data-content="'.$group->name.'">'.$group->name.'</option>';
						}
					}
					$return_string .= '</select>';
				}
				 if( $inputStyle == 'material_outlined' ){
                    $return_string .= '<div class="arf_material_outliner arf_material_active">';
                        $return_string .= '<div class="arf_material_outliner_prefix"></div>';
                        $return_string .= '<div class="arf_material_outliner_notch">';
                            $return_string .= $arf_main_label;
                        $return_string .= '</div>';
                        $return_string .= '<div class="arf_material_outliner_suffix"></div>';
                    $return_string .= '</div>';
                $return_string .= '</div>';
                }
				$return_string .= $field_tooltip;
			} elseif ( $field['type'] == 'arf_multiselect'){
				
				$defaults = array(
					'field'      => 0,
					'field_name' => false,
					'opt_key'    => 0,
					'opt'        => '',
					'type'       => 'arf_multiselect',
					'value'      => false,
					'exclude'    => 0,
					'hide_id'    => false,
				);

				$field_name = "item_meta[$field_id]";

				$onchange = '';
				$inline_css_with_style_tag = '';
				$inline_css_without_style  = '';

				$arf_material_outliner_cls = '';

				$arf_input_field_html  = '';
				$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
				$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
				$level                 = isset( $opt_key ) ? 2 : 1;
				$field['options']      = $arfieldhelper->changeoptionorder( $field );
				if( $inputStyle == 'material_outlined' ){
                   $return_string .= '<div class="arf_material_outline_container">';
                }

                if( method_exists( $maincontroller, 'arf_selectpicker_dom' ) ){
                	$group_list_arr = array();
                	$vgroups = $groups = BP_Groups_Group::get(array('type'=>'alphabetical'));
					$arf_current_userid = get_current_user_id();
					$membersingrp = BP_Groups_Member::get_group_ids($arf_current_userid);
					if( !isset( $select_attrs ) ){
						$select_attrs = array();
					}
					$pattern = '/(onChange|onchange)\=(\'|\")(.*)(\'|\")/';
					if( !empty( $arf_on_change_function ) ){
					    preg_match( $pattern, $arf_on_change_function, $match );
					    if( !empty( $match[1] ) && !empty( $match[3] ) ){
					        $select_attrs[ $match[1] ] = $match[3];
					    }
					}

					$pattern = '/(onKeyup|onkeyup)\=(\'|\")(.*)(\'|\")/';
					if( !empty( $arf_on_change_function ) ){
					    preg_match( $pattern, $arf_on_change_function, $match );
					    if( !empty( $match[1] ) && !empty( $match[3] ) ){
					        $select_attrs[ $match[1] ] = $match[3];
					    }
					}

					$arf_groups_list =  $vgroups['groups'];
					$arf_group_list_cls = array(
						'' => esc_html__( 'Please Select', 'ARForms-postcreator' )
					);
					$count_i = 0;
                	foreach( $arf_groups_list as $key => $group ){
                		$count_i++;
                		$group_list_arr[ $group->id ] = $group->name;
                		$arf_group_list_cls[ $group->id ] = 'frm_bpgroup_' . $count_i;
                	}
                	if( 'material_outlined' == $inputStyle ){
	                    $select_attrs['class'] = 'arf_material_active';
	                }
                	$return_string .= $maincontroller->arf_selectpicker_dom( $field_name, 'field_' . $field['field_key'] . '_' . $arf_data_uniq_id, 'arf_form_field_picker multi-select', '', '', $select_attrs, $group_list_arr );
				} else {

					$return_string        .= '<select data-test="multiselect-categoris" multiple name="' . $field_name . '[]"';
					if ( isset( $field['required'] ) and $field['required'] ) {
						$return_string .= ' data-validation-required-message="' . esc_attr( $field['blank'] ) . '"';
					}
					$return_string .= ' id="field_' . $field['field_key'] . '_' . $arf_data_uniq_id . '" ';
					$return_string .= $arf_input_field_html;
					
					$return_string .= ' data-size="15"  ' . $arf_on_change_function . ' >';
					$return_string .= '<option value="">' . esc_html__( 'Please Select', 'ARForms-postcreator' ) . '</option>';
					$count_i        = 0;
					$vgroups = $groups = BP_Groups_Group::get(array('type'=>'alphabetical'));
					$arf_current_userid = get_current_user_id();
					$membersingrp = BP_Groups_Member::get_group_ids($arf_current_userid);
					$arf_groups_list =  $vgroups['groups'];
					foreach ( $arf_groups_list as $key => $group ) {
						$count_i++;
						if (in_array($group->id, $membersingrp['groups'])) {
							$return_string .='<option value="'. $group->id .'" class="frm_bpgroup_'.$count_i.'" id="field_'.$field_id.'"_"'.$count_i.'" data-content="'.$group->name.'">'.$group->name.'</option>';
						}
					}
					$return_string .= '</select>';
				}
				if( $inputStyle == 'material_outlined' ){
                    $return_string .= '<div class="arf_material_outliner arf_material_active">';
                        $return_string .= '<div class="arf_material_outliner_prefix"></div>';
                        $return_string .= '<div class="arf_material_outliner_notch">';
                            $return_string .= $arf_main_label;
                        $return_string .= '</div>';
                        $return_string .= '<div class="arf_material_outliner_suffix"></div>';
                    $return_string .= '</div>';
                $return_string .= '</div>';
                }
				$return_string .= $field_tooltip;
			} elseif ( $field['type'] == 'arf_autocomplete') {

				$defaults = array(
					'field'      => 0,
					'field_name' => false,
					'opt_key'    => 0,
					'opt'        => '',
					'type'       => 'arf_autocomplete',
					'value'      => false,
					'exclude'    => 0,
					'hide_id'    => false,
				);

				$field_name = "item_meta[$field_id]";
				
				$onchange = '';
				
	
				$inline_css_with_style_tag = '';
				$inline_css_without_style  = '';

				$arf_input_field_html  = '';
				$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
				$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
				$level                 = isset( $opt_key ) ? 2 : 1;
				$field['options']      = $arfieldhelper->changeoptionorder( $field );
				$autocomplt_opt_arr    = array();
				$separate_value_lbl    = array();
				$autocomplete_separate_value = '';
				
				$vgroups = $groups = BP_Groups_Group::get(array('type'=>'alphabetical'));
				$arf_current_userid = get_current_user_id();
				$membersingrp = BP_Groups_Member::get_group_ids($arf_current_userid);
				$arf_groups_list =  $vgroups['groups'];
				foreach ($arf_groups_list as $key => $group) {
					if (in_array($group->id, $membersingrp['groups'])) {
						$autocomplt_opt_arr[] = '"' .$group->name . '"';
						if (isset($field['separate_value']) && $field['separate_value'] == '1') {
							$separate_value_lbl[$group->name] =  $group->name;
							$autocomplete_separate_value .= "{id: '" . $group->name . "', name: '" . $group->name . "'},";
						}
					}

				}
				
				$separate_value_lbl = json_encode($separate_value_lbl);
				$autocomplt_data = implode(',', $autocomplt_opt_arr);
				
                $arf_data_provided = 'data-provide="typeahead"';
                $arf_autocomplete_id = 'field_' . $field['field_key'] . '_' . $arf_data_uniq_id;
            	$arf_autocomplete_value_id = 'field_value_' . $field['field_key'] . '_' . $arf_data_uniq_id;

            	if (isset($field['separate_value']) && $field['separate_value'] == '1') {
            		$return_string .= '<input id="' . $arf_autocomplete_id . '" data-id="' . $field['id'] . '" type="text" name="arf_autocomplete_' . $field['id'] . '" data-field-id="' . $arf_autocomplete_value_id . '"  autocomplete="off" ';
                    if (isset($field['required']) and $field['required']) {
                        $return_string .= 'data-validation-required-message="' . esc_attr($field['blank']) . '" ';
                    }
                   
                    $return_string .= $arf_on_change_function;
                    $return_string .= ' autocomplete="off" />';
                    $return_string .='<input id="' . $arf_autocomplete_value_id . '" type="hidden" name="' . $field_name . '" value="' . $field['default_value'] . '" ';

                    $return_string .= ' data-sep-labels=\''. $separate_value_lbl .'\'';

                	$return_string .= $arf_on_change_function;
                
                    
                    $return_string .='/>';
                     $arf_form_all_footer_js .='
                            jQuery("#' . $arf_autocomplete_id . '").typeahead({
                                source: [' . substr($autocomplete_separate_value, 0, -1) . '],
                                onSelect: function (item) {
                                    jQuery("#' . $arf_autocomplete_value_id . '").val(item.value);
                                },
                            });';
                    
            	}else{
            		$return_string .= '<input type="text" data-type="arf_autocomplete" id="field_' . $field['field_key'] . '_' . $arf_data_uniq_id . '" name="' . $field_name . '" data-source=\'['.$autocomplt_data.']\' data-items="10" '.$arf_data_provided.' class="" value="' . $field['default_value'] . '" ';
            	
            		if (isset($field['required']) and $field['required']) {
                        $return_string .=' data-validation-required-message="' . esc_attr($field['blank']) . '" ';
                    }
					$return_string .= $arf_input_field_html;
					$return_string .= $arf_on_change_function;
					$return_string .=' autocomplete="off" />';
				}
				$return_string .= $field_tooltip;
			}
		} else {	
			$check = '';
			if ( $opt['post_type'] != 'basic' ) {
				$custom_cats = $opt['custom_categories'];
				if ( is_array( $custom_cats ) ) {
					foreach ( $custom_cats as $cats ) {
						if ( isset($opt['category_single'][ $cats ][0]) && $opt['category_single'][ $cats ][0] != '' ) {
							if ( $opt['category_single'][ $cats ][0] == $field_id ) {
								$check = true;
							}
						}
					}
				}
			} else {
				if ( $opt['category_single'][0] != '' ) {
					if ( $opt['category_single'][0] == $field['id'] ) {
						$check = true;
					}
				}
			}

			if ( $check == true ) {
				if ( $field['type'] == 'radio' || $field['type'] == 'checkbox' ) {
					$defaults = array(
						'field'      => 0,
						'field_name' => false,
						'opt_key'    => 0,
						'opt'        => '',
						'type'       => $field['type'],
						'value'      => false,
						'exclude'    => 0,
						'hide_id'    => false,
					);
					if ( ! isset( $field_name ) ) {
						$field_name = "item_meta[$field_id]";
					}
					
					$onchange = '';
				
					if ( $opt['post_type'] == 'basic' ) {
						$post_type = 'post';
						$taxonomy  = 'category';
						$args      = array(
							'orderby'    => 'name',
							'order'      => 'ASC',
							'hide_empty' => false,
							'parent'     => 0,
							'exclude'    => 'all',
							'type'       => $post_type,
						);

						$children = get_categories( $args );
						$level    = isset( $opt_key ) ? 2 : 1;

						if ( isset( $field['align'] ) && $field['align'] == 'arf_col_2' ) {
							$return_string .= '<div class="arf_chk_radio_col_two">';
						} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_3' ) {
							$return_string .= '<div class="arf_chk_radio_col_thiree">';
						} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_4' ) {
							$return_string .= '<div class="arf_chk_radio_col_four">';
						}
						
						$exclude = isset( $args['exclude'] ) ? $args['exclude'] : $defaults['exclude']; 
						$type = isset( $args['type'] ) ? $args['type'] : $defaults['type'];
						$value = isset( $args['value'] ) ? $args['value'] : $defaults['value'];
						$hide_id = isset( $args['hide_id'] ) ? $args['hide_id'] : $defaults['hide_id'];
						$arf_chk_counter = 1;
						foreach ( $children as $key => $cat ) {
							$return_string .= $arf_postcreator->arf_show_category_front( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $key, $arf_on_change_function );
							if ( isset( $field['align'] ) && $field['align'] == 'arf_col_2' ) {
								if ( $arf_chk_counter % 2 == 0 ) {
									$return_string .= '</div><div class="arf_chk_radio_col_two">';
								}
							} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_3' ) {
								if ( $arf_chk_counter % 3 == 0 ) {
									$return_string .= '</div><div class="arf_chk_radio_col_thiree">';
								}
							} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_4' ) {
								if ( $arf_chk_counter % 4 == 0 ) {
									$return_string .= '</div><div class="arf_chk_radio_col_four">';
								}
							}
							$arf_chk_counter++;
						}
						if ( isset( $field['align'] ) && ( $field['align'] == 'arf_col_2' || $field['align'] == 'arf_col_3' || $field['align'] == 'arf_col_4' ) ) {
							$return_string .= '</div>';
						}
					} else {
						if ( is_array( $opt['custom_categories'] ) ) {

							foreach ( $opt['custom_categories'] as $taxonomy ) {
								if ( is_array( $opt['category_single'] ) ) {
									if ( isset($opt['category_single'][ $taxonomy ][0])) {
										if ( isset( $field['align'] ) && $field['align'] == 'arf_col_2' ) {
											$return_string .= '<div class="arf_chk_radio_col_two">';
										} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_3' ) {
											$return_string .= '<div class="arf_chk_radio_col_thiree">';
										} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_4' ) {
											$return_string .= '<div class="arf_chk_radio_col_four">';
										}
										$arf_chk_counter = 1;
										foreach ( $opt['category_single'][ $taxonomy ] as $single_category ) {
											$return_string .= $arf_postcreator->get_child_checkboxes( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $opt['custom_post'], $taxonomy, $single_category, $arf_on_change_function );
											if ( isset( $field['align'] ) && $field['align'] == 'arf_col_2' ) {
												if ( $arf_chk_counter % 2 == 0 ) {
													$return_string .= '</div><div class="arf_chk_radio_col_two">';
												}
											} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_3' ) {
												if ( $arf_chk_counter % 3 == 0 ) {
													$return_string .= '</div><div class="arf_chk_radio_col_thiree">';
												}
											} elseif ( isset( $field['align'] ) && $field['align'] == 'arf_col_4' ) {
												if ( $arf_chk_counter % 4 == 0 ) {
													$return_string .= '</div><div class="arf_chk_radio_col_four">';
												}
											}
											$arf_chk_counter++;
										}
										if ( isset( $field['align'] ) && ( $field['align'] == 'arf_col_2' || $field['align'] == 'arf_col_3' || $field['align'] == 'arf_col_4' ) ) {
											$return_string .= '</div>';
										}
									}
								}
							}
						}
					}
				} elseif ( $field['type'] == 'select' ) {
					?>
					<?php
					$defaults = array(
						'field'      => 0,
						'field_name' => false,
						'opt_key'    => 0,
						'opt'        => '',
						'type'       => 'select',
						'value'      => false,
						'exclude'    => 0,
						'hide_id'    => false,
					);

					if ( ! isset( $field_name ) ) {
						$field_name = "item_meta[$field_id]";
					}

					$onchange = '';
					if ( $opt['post_type'] == 'basic' ) {
						$post_type = 'post';
						$taxonomy  = 'category';

						$args = array(
							'orderby'    => 'name',
							'order'      => 'ASC',
							'hide_empty' => false,
							'parent'     => 0,
							'exclude'    => 'all',
							'type'       => $post_type,
						);
						

						$children = get_categories( $args );

						$inline_css_with_style_tag = '';
						$inline_css_without_style  = '';

						$arf_input_field_html  = '';
						$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
						$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
						$level                 = isset( $opt_key ) ? 2 : 1;
						$field['options']      = $arfieldhelper->changeoptionorder( $field );
						if( $inputStyle == 'material_outlined' ){
	                       $return_string .= '<div class="arf_material_outline_container">';
	                    }
	                    $post_category_arr = array();
	                    if( method_exists( $maincontroller, 'arf_selectpicker_dom' ) ){
	                    	
	                    	$select_attrs = array();
			                $pattern = '/(onChange|onchange)\=(\'|\")(.*)(\'|\")/';
			                if( !empty( $arf_on_change_function ) ){
			                    preg_match( $pattern, $arf_on_change_function, $match );
			                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
			                        $select_attrs[ $match[1] ] = $match[3];
			                    }
			                }

			                $pattern = '/(onKeyup|onkeyup)\=(\'|\")(.*)(\'|\")/';
			                if( !empty( $arf_on_change_function ) ){
			                    preg_match( $pattern, $arf_on_change_function, $match );
			                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
			                        $select_attrs[ $match[1] ] = $match[3];
			                    }
			                }

	                    	foreach ( $children as $key => $cat ) {
	                    		$args = array(
									'orderby'    => 'name',
									'order'      => 'ASC',
									'hide_empty' => false,
									'parent'     => $cat->cat_ID,
									'exclude'    => $exclude,
									'type'       => $post_type,
									'taxonomy'   => $taxonomy,
								);
	                    		
	                    		$post_category_arr[ $cat->cat_name ] = $cat->cat_name;
	                    		$children       = get_categories( $args );
	                    		if ( $children ) {
	                    			$level++;
	                    			foreach ( $children as $key => $cat ) {
	                    				$post_category_arr[ $cat->cat_name ] = $cat->cat_name;
	                    			}
	                    		}
	                    	}

		                	$input_class = "";
		                	if( 'material_outlined' == $inputStyle && !preg_match('/(arf_material_active)/', $arf_input_field_html) ){
			                    $input_class = ' arf_material_active ';
			                }
		                	$select_attrs['class']	=	$input_class;
		                	$return_string .= $maincontroller->arf_selectpicker_dom( $field_name, 'field_' . $field['field_key']. '_' . $arf_data_uniq_id , ' arf_form_field_picker ', '', '', $select_attrs, $post_category_arr );

		                } else {
							$return_string        .= '<select name="' . $field_name . '"';
							if ( isset( $field['required'] ) and $field['required'] ) {
								$return_string .= ' data-validation-required-message="' . esc_attr( $field['blank'] ) . '"';
							}
							$return_string .= ' id="field_' . $field['field_key'] . '_' . $arf_data_uniq_id . '" ';
							$return_string .= $arf_input_field_html;
							if( 'material_outlined' == $inputStyle && !preg_match('/(arf_material_active)/', $arf_input_field_html) ){
	                            $return_string .= ' class="arf_material_active" ';
	                        }
							$return_string .= ' data-size="15"  ' . $arf_on_change_function . ' >';
							$count_i        = 0;
							foreach ( $children as $key => $cat ) {
								$return_string .= $arf_postcreator->arf_show_category_select( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $return_string );
							}
							$return_string .= '</select>';
						}
					    if( $inputStyle == 'material_outlined' ){
                            $return_string .= '<div class="arf_material_outliner arf_material_active">';
                                $return_string .= '<div class="arf_material_outliner_prefix"></div>';
                                $return_string .= '<div class="arf_material_outliner_notch">';
                                    $return_string .= $arf_main_label;
                                $return_string .= '</div>';
                                $return_string .= '<div class="arf_material_outliner_suffix"></div>';
                            $return_string .= '</div>';
                        $return_string .= '</div>';
	                    }
						$return_string .= $field_tooltip;
					} else {
						$post_type  = $opt['custom_post'];
						$taxonomies = get_object_taxonomies( $post_type );

						foreach ( $taxonomies as $taxonomy ) {
							$args = array(
								'orderby'    => 'name',
								'order'      => 'ASC',
								'hide_empty' => false,
								'parent'     => 0,
								'exclude'    => 'all',
								'type'       => $post_type,
								'taxonomy'   => $taxonomy,
							);
							if ( $field_id == $opt['category_single'][ $taxonomy ][0] ) {
								$cats                      = get_categories( $args );
								$level                     = isset( $opt_key ) ? 2 : 1;
								$inline_css_with_style_tag = '';
								$inline_css_without_style  = '';

								$arf_input_field_html  = '';
								$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
								$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
								$level                 = isset( $opt_key ) ? 2 : 1;
								$field['options']      = $arfieldhelper->changeoptionorder( $field );
								
								if( method_exists( $maincontroller, 'arf_selectpicker_dom' ) ){
									$select_attrs = array();
					                $pattern = '/(onChange|onchange)\=(\'|\")(.*)(\'|\")/';
					                if( !empty( $arf_on_change_function ) ){
					                    preg_match( $pattern, $arf_on_change_function, $match );
					                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
					                        $select_attrs[ $match[1] ] = $match[3];
					                    }
					                }

					                $pattern = '/(onKeyup|onkeyup)\=(\'|\")(.*)(\'|\")/';
					                if( !empty( $arf_on_change_function ) ){
					                    preg_match( $pattern, $arf_on_change_function, $match );
					                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
					                        $select_attrs[ $match[1] ] = $match[3];
					                    }
					                }

					                $input_class = "";
					                $custom_post_category_arr = array();
					                foreach ( $cats as $key => $cat ) {
			                    		$args = array(
											'orderby'    => 'name',
											'order'      => 'ASC',
											'hide_empty' => false,
											'parent'     => $cat->cat_ID,
											'exclude'    => $exclude,
											'type'       => $post_type,
											'taxonomy'   => $taxonomy,
										);
			                    		$custom_post_category_arr[ $cat->cat_name ] = $cat->cat_name;
			                    		$children       = get_categories( $args );
			                    		if ( $children ) {
			                    			$level++;
			                    			foreach ( $children as $key => $cat ) {
			                    				$custom_post_category_arr[ $cat->cat_name ] = $cat->cat_name;
			                    			}
			                    		}
			                    	}

				                	if( 'material_outlined' == $inputStyle && !preg_match('/(arf_material_active)/', $arf_input_field_html) ){
					                    $input_class = ' arf_material_active ';
					                }
				                	$select_attrs['class']	=	$input_class;
				                	$return_string .= $maincontroller->arf_selectpicker_dom( $field_name, 'field_' . $field['field_key']. '_' . $arf_data_uniq_id , ' arf_form_field_picker ', '', '', $select_attrs, $custom_post_category_arr );
								} else {
									$return_string        .= '<select name="' . $field_name . '"';
									if ( isset( $field['required'] ) and $field['required'] ) {
										$return_string .= ' data-validation-required-message="' . esc_attr( $field['blank'] ) . '"';
									}
									$return_string .= ' id="field_' . $field['field_key'] . '_' . $arf_data_uniq_id . '" ';
									$return_string .= $arf_input_field_html;
									$return_string .= ' data-size="15"  ' . $arf_on_change_function . ' >';
									$return_string .= '<option value="">' . esc_html__( 'Please Select', 'ARForms-postcreator' ) . '</option>';
									$count_i        = 0;
									foreach ( $cats as $key => $cat ) {
										$return_string .= $arf_postcreator->arf_show_category_select_custom_post( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $taxonomy, $post_type );
									}
									$return_string .= '</select>';
								}
								$return_string .= $field_tooltip;

							}
						}
					}
				} elseif ( $field['type'] == 'arf_multiselect'){
					$defaults = array(
						'field'      => 0,
						'field_name' => false,
						'opt_key'    => 0,
						'opt'        => '',
						'type'       => 'arf_multiselect',
						'value'      => false,
						'exclude'    => 0,
						'hide_id'    => false,
					);

					$field_name = "item_meta[$field_id]";

					$onchange = '';
					if ( $opt['post_type'] == 'basic' ) {
						$post_type = 'post';
						$taxonomy  = 'category';

						$args = array(
							'orderby'    => 'name',
							'order'      => 'ASC',
							'hide_empty' => false,
							'parent'     => 0,
							'exclude'    => 'all',
							'type'       => $post_type,
						);

						$children = get_categories( $args );
 	
						$inline_css_with_style_tag = '';
						$inline_css_without_style  = '';

						$arf_input_field_html  = '';
						$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
						$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
						$level                 = isset( $opt_key ) ? 2 : 1;
						$field['options']      = $arfieldhelper->changeoptionorder( $field );

						if( $inputStyle == 'material_outlined' ){
	                       $return_string .= '<div class="arf_material_outline_container">';
	                    }

	                    
						if( method_exists( $maincontroller, 'arf_selectpicker_dom' ) ){
							$select_attrs = array();
			                $pattern = '/(onChange|onchange)\=(\'|\")(.*)(\'|\")/';
			                if( !empty( $arf_on_change_function ) ){
			                    preg_match( $pattern, $arf_on_change_function, $match );
			                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
			                        $select_attrs[ $match[1] ] = $match[3];
			                    }
			                }

			                $pattern = '/(onKeyup|onkeyup)\=(\'|\")(.*)(\'|\")/';
			                if( !empty( $arf_on_change_function ) ){
			                    preg_match( $pattern, $arf_on_change_function, $match );
			                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
			                        $select_attrs[ $match[1] ] = $match[3];
			                    }
			                }

			                $post_category_arr = array();
	                    	foreach ( $children as $key => $cat ) {
	                    		$args = array(
									'orderby'    => 'name',
									'order'      => 'ASC',
									'hide_empty' => false,
									'parent'     => $cat->cat_ID,
									'exclude'    => $exclude,
									'type'       => $post_type,
									'taxonomy'   => $taxonomy,
								);
	                    		$post_category_arr[ $cat->cat_name ] = $cat->cat_name;
	                    		$children       = get_categories( $args );
	                    		if ( $children ) {
	                    			$level++;
	                    			foreach ( $children as $key => $cat ) {
	                    				$post_category_arr[ $cat->cat_name ] = $cat->cat_name;
	                    			}
	                    		}
	                    	}

		                	$input_class = "";
		                	if( 'material_outlined' == $inputStyle && !preg_match('/(arf_material_active)/', $arf_input_field_html) ){
			                    $input_class = ' arf_material_active ';
			                }
		                	$select_attrs['class']	=	$input_class;
		                	$return_string .= $maincontroller->arf_selectpicker_dom( $field_name. '[]', 'field_' . $field['field_key']. '_' . $arf_data_uniq_id , ' arf_form_field_picker multi-select', '', '', $select_attrs, $post_category_arr );

						} else {
							$return_string        .= '<select data-test="multiselect-categoris" multiple name="' . $field_name . '[]"';
							if ( isset( $field['required'] ) and $field['required'] ) {
								$return_string .= ' data-validation-required-message="' . esc_attr( $field['blank'] ) . '"';
							}
							$return_string .= ' id="field_' . $field['field_key'] . '_' . $arf_data_uniq_id . '" ';
							
							$return_string .= $arf_input_field_html;
							
							$return_string .= ' data-size="15"  ' . $arf_on_change_function . ' >';
							$return_string .= '<option value="">' . esc_html__( 'Please Select', 'ARForms-postcreator' ) . '</option>';
							$count_i        = 0;
							foreach ( $children as $key => $cat ) {
								$return_string .= $arf_postcreator->arf_show_category_select( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $return_string );
							}
							$return_string .= '</select>';
						}

						if( $inputStyle == 'material_outlined' ){
                            $return_string .= '<div class="arf_material_outliner arf_material_active">';
                                $return_string .= '<div class="arf_material_outliner_prefix"></div>';
                                $return_string .= '<div class="arf_material_outliner_notch">';
                                    $return_string .= $arf_main_label;
                                $return_string .= '</div>';
                                $return_string .= '<div class="arf_material_outliner_suffix"></div>';
                            $return_string .= '</div>';
                        $return_string .= '</div>';
	                    }
						$return_string .= $field_tooltip;
					} else {
						$post_type  = $opt['custom_post'];
						$taxonomies = get_object_taxonomies( $post_type );

						foreach ( $taxonomies as $taxonomy ) {
							$args = array(
								'orderby'    => 'name',
								'order'      => 'ASC',
								'hide_empty' => false,
								'parent'     => 0,
								'exclude'    => 'all',
								'type'       => $post_type,
								'taxonomy'   => $taxonomy,
							);
							if ( isset($opt['category_single'][ $taxonomy ][0]) && $field_id == $opt['category_single'][ $taxonomy ][0] ) {
								$cats                      = get_categories( $args );
								$level                     = isset( $opt_key ) ? 2 : 1;
								$inline_css_with_style_tag = '';
								$inline_css_without_style  = '';
								

								$arf_input_field_html  = '';
								$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
								$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
								$level                 = isset( $opt_key ) ? 2 : 1;
								$field['options']      = $arfieldhelper->changeoptionorder( $field );
								if( $inputStyle == 'material_outlined' ){
			                       $return_string .= '<div class="arf_material_outline_container">';
			                    }
			                    
			                    if( method_exists( $maincontroller, 'arf_selectpicker_dom' ) ){
			                    	$select_attrs = array();
					                $pattern = '/(onChange|onchange)\=(\'|\")(.*)(\'|\")/';
					                if( !empty( $arf_on_change_function ) ){
					                    preg_match( $pattern, $arf_on_change_function, $match );
					                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
					                        $select_attrs[ $match[1] ] = $match[3];
					                    }
					                }

					                $pattern = '/(onKeyup|onkeyup)\=(\'|\")(.*)(\'|\")/';
					                if( !empty( $arf_on_change_function ) ){
					                    preg_match( $pattern, $arf_on_change_function, $match );
					                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
					                        $select_attrs[ $match[1] ] = $match[3];
					                    }
					                }

					                $custom_post_category_arr = array();
					                foreach ( $cats as $key => $cat ) {
			                    		$args = array(
											'orderby'    => 'name',
											'order'      => 'ASC',
											'hide_empty' => false,
											'parent'     => $cat->cat_ID,
											'exclude'    => $exclude,
											'type'       => $post_type,
											'taxonomy'   => $taxonomy,
										);
			                    		$custom_post_category_arr[ $cat->cat_name ] = $cat->cat_name;
			                    		$children       = get_categories( $args );
			                    		if ( $children ) {
			                    			$level++;
			                    			foreach ( $children as $key => $cat ) {
			                    				$custom_post_category_arr[ $cat->cat_name ] = $cat->cat_name;
			                    			}
			                    		}
			                    	}

				                	$input_class = "";
				                	if( 'material_outlined' == $inputStyle && !preg_match('/(arf_material_active)/', $arf_input_field_html) ){
					                    $input_class = ' arf_material_active ';
					                }
				                	$select_attrs['class']	=	$input_class;
				                	$return_string .= $maincontroller->arf_selectpicker_dom( $field_name.'[]', 'field_' . $field['field_key']. '_' . $arf_data_uniq_id , ' arf_form_field_picker multi-select', '', '', $select_attrs, $custom_post_category_arr );

			                    } else {
									$return_string        .= '<select multiple name="' . $field_name . '[]"';
									if ( isset( $field['required'] ) and $field['required'] ) {
										$return_string .= ' data-validation-required-message="' . esc_attr( $field['blank'] ) . '"';
									}
									$return_string .= ' id="field_' . $field['field_key'] . '_' . $arf_data_uniq_id . '" ';
									$return_string .= $arf_input_field_html;
									
									$return_string .= ' data-size="15"  ' . $arf_on_change_function . ' >';
									$return_string .= '<option value="">' . esc_html__( 'Please Select', 'ARForms-postcreator' ) . '</option>';
									$count_i        = 0;
									foreach ( $cats as $key => $cat ) {
										$return_string .= $arf_postcreator->arf_show_category_select_custom_post( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $taxonomy, $post_type );
									}
									$return_string .= '</select>';
			                    }
								if( $inputStyle == 'material_outlined' ){
		                            $return_string .= '<div class="arf_material_outliner arf_material_active">';
		                                $return_string .= '<div class="arf_material_outliner_prefix"></div>';
		                                $return_string .= '<div class="arf_material_outliner_notch">';
		                                    $return_string .= $arf_main_label;
		                                $return_string .= '</div>';
		                                $return_string .= '<div class="arf_material_outliner_suffix"></div>';
		                            $return_string .= '</div>';
		                        $return_string .= '</div>';
			                    }
								$return_string .= $field_tooltip;

							}
						}
					}
				} elseif ( $field['type'] == 'arf_autocomplete') {

					$defaults = array(
						'field'      => 0,
						'field_name' => false,
						'opt_key'    => 0,
						'opt'        => '',
						'type'       => 'arf_autocomplete',
						'value'      => false,
						'exclude'    => 0,
						'hide_id'    => false,
					);

					$field_name = "item_meta[$field_id]";

					$onchange = '';
					if ( $opt['post_type'] == 'basic' ) {
						$post_type = 'post';
						$taxonomy  = 'category';

						$args = array(
							'orderby'    => 'name',
							'order'      => 'ASC',
							'hide_empty' => false,
							'parent'     => 0,
							'exclude'    => 'all',
							'type'       => $post_type,
						);

						$cat = get_categories( $args );
 	
						$inline_css_with_style_tag = '';
						$inline_css_without_style  = '';

						$arf_input_field_html  = '';
						$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
						$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
						$level                 = isset( $opt_key ) ? 2 : 1;
						$field['options']      = $arfieldhelper->changeoptionorder( $field );
						$autocomplt_opt_arr    = array();
						$separate_value_lbl    = array();
						$autocomplete_separate_value = '';
						$children       = get_categories(
							array(
								'type'       => $post_type,
								'orderby'    => 'name',
								'order'      => 'ASC',
								'hide_empty' => false,
								'exclude'    => $exclude,
								'parent'     => $cat->cat_ID,
								'taxonomy'   => $taxonomy,
							)
						);
						foreach ($children as $key => $cat) {
							$autocomplt_opt_arr[] = '"' .$cat->name . '"';
							if (isset($field['separate_value']) && $field['separate_value'] == '1') {
								$separate_value_lbl[$cat->name] =  $cat->name;
								$autocomplete_separate_value .= "{id: '" . $cat->name . "', name: '" . $cat->name . "'},";
							}

						}
						
						$separate_value_lbl = json_encode($separate_value_lbl);
						$autocomplt_data = implode(',', $autocomplt_opt_arr);
						
	                    $arf_data_provided = 'data-provide="typeahead"';
	                    $arf_autocomplete_id = 'field_' . $field['field_key'] . '_' . $arf_data_uniq_id;
                    	$arf_autocomplete_value_id = 'field_value_' . $field['field_key'] . '_' . $arf_data_uniq_id;

                    	if (isset($field['separate_value']) && $field['separate_value'] == '1') {
                    		$return_string .= '<input id="' . $arf_autocomplete_id . '" data-id="' . $field['id'] . '" type="text" name="arf_autocomplete_' . $field['id'] . '" data-field-id="' . $arf_autocomplete_value_id . '"  autocomplete="off" ';
	                        if (isset($field['required']) and $field['required']) {
	                            $return_string .= 'data-validation-required-message="' . esc_attr($field['blank']) . '" ';
	                        }
	                        
	                        $return_string .= $arf_on_change_function;

	                        $return_string .= ' autocomplete="off" />';
	                        $return_string .='<input id="' . $arf_autocomplete_value_id . '" type="hidden" name="' . $field_name . '" value="' . $field['default_value'] . '" ';

	                        $return_string .= ' data-sep-labels=\''. $separate_value_lbl .'\'';

	                    	$return_string .= $arf_on_change_function;
	                    
	                        
	                        $return_string .='/>';
	                        $arf_form_all_footer_js .='
	                            jQuery("#' . $arf_autocomplete_id . '").typeahead({
	                                source: [' . substr($autocomplete_separate_value, 0, -1) . '],
	                                onSelect: function (item) {
	                                    jQuery("#' . $arf_autocomplete_value_id . '").val(item.value);
	                                },
	                            });';
                    	}else{
                    		$return_string .= '<input type="text" data-type="arf_autocomplete" id="field_' . $field['field_key'] . '_' . $arf_data_uniq_id . '" name="' . $field_name . '" data-source=\'['.$autocomplt_data.']\' data-items="10" '.$arf_data_provided.' class="" value="' . $field['default_value'] . '" ';
                    	
                    		if (isset($field['required']) and $field['required']) {
	                            $return_string .=' data-validation-required-message="' . esc_attr($field['blank']) . '" ';
	                        }
							$return_string .= $arf_input_field_html;
							$return_string .= $arf_on_change_function;
							$return_string .=' autocomplete="off" />';
						}
						$return_string .= $field_tooltip;
					} else {
						$post_type  = $opt['custom_post'];
						$taxonomies = get_object_taxonomies( $post_type );

						foreach ( $taxonomies as $taxonomy ) {
							$args = array(
								'orderby'    => 'name',
								'order'      => 'ASC',
								'hide_empty' => false,
								'parent'     => 0,
								'exclude'    => 'all',
								'type'       => $post_type,
								'taxonomy'   => $taxonomy,
							);
							if ( $field_id == $opt['category_single'][ $taxonomy ][0] ) {
								$cats                      = get_categories( $args );
								$level                     = ( $opt_key ) ? 2 : 1;
								$inline_css_with_style_tag = '';
								$inline_css_without_style  = '';

								$arf_input_field_html  = '';
								$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
								$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
								$level                 = isset( $opt_key ) ? 2 : 1;
								$field['options']      = $arfieldhelper->changeoptionorder( $field );
								if( $inputStyle == 'material_outlined' ){
			                       $return_string .= '<div class="arf_material_outline_container">';
			                    }
			                    
			                    if( method_exists( $maincontroller, 'arf_selectpicker_dom' ) ){
			                    	$select_attrs = array();
					                $pattern = '/(onChange|onchange)\=(\'|\")(.*)(\'|\")/';
					                if( !empty( $arf_on_change_function ) ){
					                    preg_match( $pattern, $arf_on_change_function, $match );
					                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
					                        $select_attrs[ $match[1] ] = $match[3];
					                    }
					                }

					                $pattern = '/(onKeyup|onkeyup)\=(\'|\")(.*)(\'|\")/';
					                if( !empty( $arf_on_change_function ) ){
					                    preg_match( $pattern, $arf_on_change_function, $match );
					                    if( !empty( $match[1] ) && !empty( $match[3] ) ){
					                        $select_attrs[ $match[1] ] = $match[3];
					                    }
					                }

					                $custom_post_category_arr = array();
					                foreach ( $cats as $key => $cat ) {
			                    		$args = array(
											'orderby'    => 'name',
											'order'      => 'ASC',
											'hide_empty' => false,
											'parent'     => $cat->cat_ID,
											'exclude'    => $exclude,
											'type'       => $post_type,
											'taxonomy'   => $taxonomy,
										);
			                    		$custom_post_category_arr[ $cat->cat_name ] = $cat->cat_name;
			                    		$children       = get_categories( $args );
			                    		if ( $children ) {
			                    			$level++;
			                    			foreach ( $children as $key => $cat ) {
			                    				$custom_post_category_arr[ $cat->cat_name ] = $cat->cat_name;
			                    			}
			                    		}
			                    	}

				                	$input_class = "";
				                	if( 'material_outlined' == $inputStyle && !preg_match('/(arf_material_active)/', $arf_input_field_html) ){
					                    $input_class = ' arf_material_active ';
					                }
				                	$select_attrs['class']	=	$input_class;
				                	$return_string .= $maincontroller->arf_selectpicker_dom( $field_name.'[]', 'field_' . $field['field_key']. '_' . $arf_data_uniq_id , ' arf_form_field_picker multi-select', '', '', $select_attrs, $custom_post_category_arr );

			                    } else {
									$return_string        .= '<select multiple class="arf_multiselect_dropdown" name="' . $field_name . '[]"';
									if ( isset( $field['required'] ) and $field['required'] ) {
										$return_string .= ' data-validation-required-message="' . esc_attr( $field['blank'] ) . '"';
									}
									$return_string .= ' id="field_' . $field['field_key'] . '_' . $arf_data_uniq_id . '" ';
									$return_string .= $arf_input_field_html;
									if( 'material_outlined' == $inputStyle && !preg_match('/(arf_material_active)/', $arf_input_field_html) ){
			                            $return_string .= ' class="arf_material_active" ';
			                        }
									$return_string .= ' data-size="15"  ' . $arf_on_change_function . ' >';
									$return_string .= '<option value="">' . esc_html__( 'Please Select', 'ARForms-postcreator' ) . '</option>';
									$count_i        = 0;
									foreach ( $cats as $key => $cat ) {
										$return_string .= $arf_postcreator->arf_show_category_select_custom_post( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $taxonomy, $post_type );
									}
									$return_string .= '</select>';
			                    }
								if( $inputStyle == 'material_outlined' ){
		                            $return_string .= '<div class="arf_material_outliner arf_material_active">';
		                                $return_string .= '<div class="arf_material_outliner_prefix"></div>';
		                                $return_string .= '<div class="arf_material_outliner_notch">';
		                                    $return_string .= $arf_main_label;
		                                $return_string .= '</div>';
		                                $return_string .= '<div class="arf_material_outliner_suffix"></div>';
		                            $return_string .= '</div>';
		                        $return_string .= '</div>';
			                    }
								$return_string .= $field_tooltip;

							}
						}
					}
				}
			}
		}
		return $return_string;
	}

	function arf_show_group_checkbox_front($level, $field, $key, $arf_on_change_function, $group_name=''){
		
		global $arfieldcontroller, $arf_postcreator;

		$return_string = '';

		$arf_input_field_html  = '';
		$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
		$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );
		$field_id = $field['id'];
		$class = '';
		$field_name = 'item_meta[$field_id]';
		if ( $field['type'] == 'checkbox' ) {
			$return_string        .= '<div class="arf_checkbox_style" id="frm_checkbox_' . $field['id'] . '">';
			$_REQUEST['arfaction'] = ( isset( $_REQUEST['arfaction'] ) ) ? $_REQUEST['arfaction'] : '';
			$return_string        .= "<div class='arf_checkbox_input_wrapper'>";
			$return_string        .= '<input type="checkbox" name="' . $field_name . '[]" id="field_' . $field['id'] . '"_"'. $level .'" value="' . $group_name . '"';

			$return_string .= $arf_input_field_html;
			if ( isset( $field['required'] ) and $field['required'] ) {
				$return_string .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
			}
		

			if ( isset( $_REQUEST['arfaction'] ) && $_REQUEST['arfaction'] == 'preview' ) {
				$return_string .= $arf_on_change_function;
			}

			$return_string .= " {$arf_on_change_function} />";
			$return_string .= '<span>';
			/*if ( $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arfcheckradiostyle'] == 'custom' ) {
				$custom_checkbox = $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arf_checked_checkbox_icon'];
				$return_string  .= "<i class='arfa {$custom_checkbox}'></i>";
			}*/
			$return_string .= '</span>';
			$return_string .= '</div>';
			$return_string .= '<label for="field_' . $field['id'] . '"_"'. $level .'" >';
			$return_string .= $group_name;

			$return_string .= '</label>';

			$return_string .= '</div>';
		}

		if ( $field['type'] == 'radio' ) {
			$return_string        .= '<div class="arf_radiobutton">';
			$_REQUEST['arfaction'] = ( isset( $_REQUEST['arfaction'] ) ) ? $_REQUEST['arfaction'] : '';
			$return_string        .= "<div class='arf_radio_input_wrapper'>";
			$return_string        .= '<input type="radio" name="' . $field_name . '" id="field_'. $field['id'] . '"_"'. $level .'" value="' . esc_attr( $cat->cat_name ) . '"';

			$return_string .= $arf_input_field_html;
			if ( isset( $field['required'] ) and $field['required'] ) {
				$return_string .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
				
			}

			if ( isset( $_REQUEST['arfaction'] ) && $_REQUEST['arfaction'] == 'preview' ) {
				$return_string .= $arf_on_change_function;
			}

			$return_string .= " {$arf_on_change_function} />";
			$return_string .= '<span>';
			/*if ( $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arfcheckradiostyle'] == 'custom' ) {
				$custom_radio   = $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arf_checked_radio_icon'];
				$return_string .= "<i class='arfa {$custom_radio}'></i>";
			}*/
			$return_string .= '</span>';
			$return_string .= '</div>';
			$return_string .= '<label for="field_' . $field['id'] . '"_"'. $level .'" >';
			$return_string .= $group_name;

			$return_string .= '</label>';

			$return_string .= '</div>';
		}

		$vgroups = $groups = BP_Groups_Group::get(array('type'=>'alphabetical'));

		$arf_groups_list =  $vgroups['groups'];
		foreach ( $arf_groups_list as $key => $group ) {
			$group_name = $group->name;
			$return_string .= $arf_postcreator->arf_show_group_checkbox_front( $level, $field, $key, $arf_on_change_function, $group_name );	
		}
		return $return_string;
	}


	public function arf_postcreator_delete_form() {

		global $arf_postcreator;
		$id     = $_POST['id'];
		$action = $_POST['act'];
		if ( $action == 'delete' && $id ) {
			$res     = $arf_postcreator->delete_forms( $id );
			$message = esc_html__( 'Record is deleted successfully.', 'ARForms-postcreator' );
			$errors  = array();

			echo json_encode(
				array(
					'message'  => $message,
					'errors'   => $errors,
					'gridData' => $this->arf_get_postcreator_data(),
				)
			);
		}
		die();
	}

	public function delete_forms( $id = 0 ) {
		if ( $id == 0 ) {
			return;
		}
		if ( $id ) {
			global $wpdb,$arfform,$arf_version;

			if( version_compare( $arf_version, '4.3', '<' ) ){
				
				$form = $wpdb->get_results( $wpdb->prepare( 'SELECT form_id FROM ' . $wpdb->prefix . 'arf_postcreator_forms WHERE id = %d', $id ) );

			}else{
				
				$form = $arfform->arf_select_db_data( true, '', $wpdb->prefix . 'arf_postcreator_forms', 'form_id', 'WHERE id = %d', array($id));

			}	

			$form = $form[0];

			if ( isset( $form->form_id ) and $form->form_id != '' ) {
				$res = $wpdb->query( $wpdb->prepare( 'DELETE FROM ' . $wpdb->prefix . 'arf_postcreator_forms WHERE id = %d', $id ) );
			}

			return $res;
		}
	}

	public function arf_postcreator_form_bulk_act() {
		if ( ! isset( $_POST ) ) {
			return;
		}

		global $arfform, $armainhelper, $arf_postcreator;

		$bulkaction = $armainhelper->get_param( 'action1' );
		$message    = '';
		$errors     = array();

		if ( -1 == $bulkaction ) {
			$bulkaction = $armainhelper->get_param( 'action3' );
		}

		if ( ! empty( $bulkaction ) and strpos( $bulkaction, 'bulk_' ) === 0 ) {
			if ( isset( $_GET ) and isset( $_GET['action1'] ) ) {
				$_SERVER['REQUEST_URI'] = str_replace( '&action=' . $_GET['action1'], '', $_SERVER['REQUEST_URI'] );
			}
			if ( isset( $_GET ) and isset( $_GET['action3'] ) ) {
				$_SERVER['REQUEST_URI'] = str_replace( '&action=' . $_GET['action3'], '', $_SERVER['REQUEST_URI'] );
			}
			$bulkaction = str_replace( 'bulk_', '', $bulkaction );
		} else {
			$bulkaction = '-1';
			if ( isset( $_POST['bulkaction'] ) and $_POST['bulkaction1'] != '-1' ) {
				$bulkaction = $_POST['bulkaction1'];
			} elseif ( isset( $_POST['bulkaction3'] ) and $_POST['bulkaction3'] != '-1' ) {
				$bulkaction = $_POST['bulkaction3'];
			}
		}

		$ids = $armainhelper->get_param( 'item-action', '' );

		if ( empty( $ids ) ) {
			$errors[] = esc_html__( 'Please select one or more records.', 'ARForms-postcreator' );
		} else {
			if ( ! is_array( $ids ) ) {
				$ids = explode( ',', $ids );
			}
			if ( is_array( $ids ) ) {
				if ( $bulkaction == 'delete' ) {
					foreach ( $ids as $fid ) {
						$res_var = $arf_postcreator->delete_forms( $fid );
					}

					if ( $res_var ) {
						$message = esc_html__( 'Record is deleted successfully.', 'ARForms-postcreator' );
					}
				}
			}
		}

		$gridData = $this->arf_get_postcreator_data();

		echo json_encode(
			array(
				'message'  => $message,
				'errors'   => $errors,
				'gridData' => $gridData,
			)
		);

		die;

	}

	public function arf_get_postcreator_data() {
		global $wpdb, $db_record, $arfform, $arf_version;

		if( version_compare( $arf_version, '4.3', '<' ) ){

			$forms = $wpdb->get_results( 'SELECT * FROM ' . $wpdb->prefix . 'arf_postcreator_forms ORDER BY id DESC' );

		}else{

			$forms = $arfform->arf_select_db_data(true, '', $wpdb->prefix . 'arf_postcreator_forms', '*', '', array(), '', 'ORDER BY id DESC');
		}

		$row_data = array();

		if ( count( $forms ) > 0 ) {
			$n = 0;
			foreach ( $forms as $form ) {

				$options = maybe_unserialize( $form->options );

				if ( ! isset( $row_data[ $n ] ) ) {
					$row_data[ $n ] = array();
				}

				$row_data[ $n ][] = "<div class='arf_custom_checkbox_wrapper arfmarginl15'><input id='cb-item-action-" . esc_html( $form->id ) . "' type='checkbox' value='" . esc_html( $form->id ) . "' name='item-action[]' /><svg width='18px' height='18px'>" . ARF_CUSTOM_UNCHECKED_ICON . ARF_CUSTOM_CHECKED_ICON . "</svg><label for='cb-item-action-" . esc_html( $form->id ) . "'><span></span></label></div>";

				$row_data[ $n ][] = esc_html( $form->form_id );

				$row_data[ $n ][] = "<a class='row-title' href='" . esc_url( wp_nonce_url( '?page=ARForms-postcreator&arfaction=edit&id=' . $form->id ) ) . "'>" . esc_attr( $form->form_name ) . '</a>';

				$entries = $db_record->getRecordCount( $form->form_id );
				if ( current_user_can( 'arfviewentries' ) ) {
					$row_data[ $n ][] = "<a href='" . esc_url( admin_url( 'admin.php?page=ARForms-entries&form=' . $form->form_id ) ) . "'>" . $entries . '</a>';
				} else {
					$row_data[ $n ][] = $entries;
				}

				if ( 'custom' == $options['post_type'] ) {
					$row_data[ $n ][] = ucfirst( $options['post_type'] ) . ' (' . $options['custom_post'] . ') Post';
				} else if ($options['post_type'] == 'buddypress_grp') {
					$row_data[ $n ][] = 'BuddyPress Group Post';
				}else {
					$row_data[ $n ][] = ucfirst( $options['post_type'] ) . ' Post';
				}

				$row_data[ $n ][] = date( get_option( 'date_format' ), strtotime( $form->created_at ) );

				$action_cell = "<div class='arf-row-actions'>";

				$edit_link = "?page=ARForms-postcreator&arfaction=edit&id={$form->id}";

				$action_cell .= "<div class='arfformicondiv arfhelptip' title='" . esc_html__( 'Edit Configuration', 'ARForms-postcreator' ) . "'><a href='" . wp_nonce_url( $edit_link ) . "'><svg width='30px' height='30px' viewBox='-5 -4 30 30' class='arfsvgposition'><path fill='#ffffff' d='M17.469,7.115v10.484c0,1.25-1.014,2.264-2.264,2.264H3.75c-1.25,0-2.262-1.014-2.262-2.264V5.082  c0-1.25,1.012-2.264,2.262-2.264h9.518l-2.264,2.001H3.489v13.042h11.979V9.379L17.469,7.115z M15.532,2.451l-0.801,0.8l2.4,2.401  l0.801-0.8L15.532,2.451z M17.131,0.85l-0.799,0.801l2.4,2.4l0.801-0.801L17.131,0.85z M6.731,11.254l2.4,2.4l7.201-7.202  l-2.4-2.401L6.731,11.254z M5.952,14.431h2.264l-2.264-2.264V14.431z'></path></svg></a></div>";

				$action_cell .= "<div class='arfformicondiv arfhelptip arfdeleteform_div_" . $form->id . "' title='" . esc_html__( 'Delete', 'ARForms-postcreator' ) . "'><a class='arf_post_creator_delete' data-id='" . $form->id . "' ><svg width='30px' height='30px' viewBox='-5 -5 32 32' class='arfsvgposition'><path fill-rule='evenodd' clip-rule='evenodd' fill='#ffffff' d='M18.435,4.857L18.413,19.87L3.398,19.88L3.394,4.857H1.489V2.929  h1.601h3.394V0.85h8.921v2.079h3.336h1.601l0,0v1.928H18.435z M15.231,4.857H6.597H5.425l0.012,13.018h10.945l0.005-13.018H15.231z   M11.4,6.845h2.029v9.065H11.4V6.845z M8.399,6.845h2.03v9.065h-2.03V6.845z' /></svg></a></div>";

				$action_cell .= '</div>';

				$row_data[ $n ][] = $action_cell;
				$n++;
			}
		}

		return $row_data;

	}

	public function edit_form() {
		global $wpdb, $arfform, $is_version_compatible;

		require ARF_POSTCREATOR_DIR . '/core/edit_3.0.php';
	}

	public function field_dropdown( $form_id, $name , $class , $default_value , $id , $field_array ) {

		global $arffield, $MdlDb, $maincontroller;

		$field_list = array();
		$field_list = $field_array;
		$exclude    = array( 'divider', 'section', 'captcha', 'break', 'html', 'like','arf_repeater', 'matrix' );

		global $armainhelper;

		if ($name == 'arf_postcreator_bp_group') {
			$selected_list_id      = '';
			$selected_list_label   = esc_html__( 'Select Field', 'ARForms-postcreator' );
			$responder_list_option = '<li class="arf_selectbox_option" data-value="" data-label="Select Field">Select Field</li>';
			$responder_list_option_arr = array(
                                '' => addslashes(esc_html__("Select Field", "ARForms-postcreator"))
                            );
			$include = array('checkbox', 'radio', 'arf_multiselect', 'select', 'arf_autocomplete');
			if ( count( $field_list ) > 0 ) {
				$cntr = 0;
				foreach ( $field_list as $field ) {
					if ( ! in_array( $field->type, $include ) ) {
						continue;}

					if( isset($field->field_options['parent_field_type']) && 'arf_repeater' == $field->field_options['parent_field_type']){
	               		continue;
	            	}
					if ( $default_value == $field->id ) {
						$selected_list_id    = $field->id;
						$selected_list_label = $field->name; 
					}
					$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $field->id . '" data-label="' . $field->name . '">' . $armainhelper->truncate( $field->name, 33 ) . '</li>';
					$responder_list_option_arr[$field->id] = $field->name;
					$cntr++;
				}
			}
			$input_id = ( '' == $id ) ? $name : $id;
			if( method_exists( $maincontroller, 'arf_selectpicker_dom') ){
					$select_attrs = array(
						'onChange'	=>	'is_group_selected(this.value, jQuery(this).parent().parent().parent().parent().attr("id"))'
					);
                    echo $maincontroller->arf_selectpicker_dom( $name, $input_id, ' arf_pc_selectfield', '', $selected_list_id, $select_attrs, $responder_list_option_arr, false, array(), false, array(), false,  array(), false, $class);
            } else {
			?>

			<input id="<?php echo esc_html( $input_id ); ?>" name="<?php echo esc_html( $name ); ?>" value="<?php echo esc_html( $selected_list_id ); ?>" type="hidden" onchange="is_group_selected(this.value, jQuery(this).parent().parent().parent().attr('id'));" />
			<dl class="arf_selectbox arf_pc_selectfield" data-name="<?php echo esc_html( $name ); ?>" data-id="<?php echo esc_html( $input_id ); ?>">
				<dt>
					<span><?php echo $selected_list_label; ?></span>
					<input value="<?php echo esc_html( $selected_list_id ); ?>" class="arf_autocomplete" type="text" autocomplete="off" />
					<svg viewBox="0 0 2000 1000" width="15px" height="15px">
						<g fill="#000">
							<path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
						</g>
					</svg>
				</dt>
				<dd>
					<ul data-id="<?php echo esc_html( $input_id ); ?>" class="<?php echo esc_attr( $class ); ?>">
						<?php echo $responder_list_option; ?>
					</ul>
				</dd>
			</dl>
		
			<?php
		}
		}else{

			$selected_list_id      = '';
			$selected_list_label   = esc_html__( 'Select Field', 'ARForms-postcreator' );
			$responder_list_option_arr = array(
                                '' => addslashes(esc_html__("Select Field", "ARForms-postcreator"))
                            );
			$responder_list_option = '';
			if ( count( $field_list ) > 0 ) {
				$cntr = 0;
				foreach ( $field_list as $field ) {
					if ( in_array( $field->type, $exclude ) ) {
						continue;}

					if( isset($field->field_options['parent_field_type']) && 'arf_repeater' == $field->field_options['parent_field_type']){
	               		continue;
	            	}
					if ( $default_value == $field->id ) {
						$selected_list_id    = $field->id;
						$selected_list_label = $field->name; 
					}
					$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $field->id . '" data-label="' . $field->name . '">' . $armainhelper->truncate( $field->name, 33 ) . '</li>';
					$responder_list_option_arr[$field->id] = $field->name;
					$cntr++;
				}
			}
			$input_id = ( '' == $id ) ? $name : $id;
			if( method_exists( $maincontroller, 'arf_selectpicker_dom') ){
				$select_attrs = array(
					'onChange'	=>	'is_group_selected(this.value, jQuery(this).parent().parent().parent().parent().attr("id"))'
				);
                echo $maincontroller->arf_selectpicker_dom( $name, $input_id,  ' arf_pc_selectfield ', '', $selected_list_id, array(), $responder_list_option_arr,false, array(), false, array(), false,  array(), false, $class );
            } else {
			?>
			<input id="<?php echo esc_html( $input_id ); ?>" name="<?php echo esc_html( $name ); ?>" value="<?php echo esc_html( $selected_list_id ); ?>" type="hidden" />
			<dl class="arf_selectbox arf_pc_selectfield" data-name="<?php echo esc_html( $name ); ?>" data-id="<?php echo esc_html( $input_id ); ?>">
				<dt>
					<span><?php echo $selected_list_label; ?></span>
					<input value="<?php echo esc_html( $selected_list_id ); ?>" class="arf_autocomplete" type="text" autocomplete="off" />
					<svg viewBox="0 0 2000 1000" width="15px" height="15px">
						<g fill="#000">
							<path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
						</g>
					</svg>
				</dt>
				<dd>
					<ul data-id="<?php echo esc_html( $input_id ); ?>" class="<?php echo esc_attr( $class ); ?>">
						<?php echo $responder_list_option; ?>
					</ul>
				</dd>
			</dl>
			<?php
		}
		}
	}

	public function getwpversion() {
		global $arf_postcreator_version, $arf_postcreator;
		$bloginformation = array();
		$str             = $arf_postcreator->get_rand_alphanumeric( 10 );

		$bloginformation[] = get_bloginfo( 'name' );

		$bloginformation[] = get_bloginfo( 'description' );
		$bloginformation[] = home_url();
		$bloginformation[] = get_bloginfo( 'admin_email' );
		$bloginformation[] = get_bloginfo( 'version' );
		$bloginformation[] = get_bloginfo( 'language' );
		$bloginformation[] = $arf_postcreator_version;
		$bloginformation[] = $_SERVER['SERVER_ADDR'];
		$bloginformation[] = $str;

		update_option( 'wp_postcreator_get_version', $str );

		$valstring  = implode( '||', $bloginformation );
		$encodedval = base64_encode( $valstring );

		$urltopost = 'http://reputeinfosystems.net/arforms/wpinfo_postcreator.php';
		$response  = wp_remote_post(
			$urltopost,
			array(
				'method'      => 'POST',
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => array(),
				'body'        => array( 'wpversion' => $encodedval ),
				'cookies'     => array(),
			)
		);
	}

	public function assign_rand_value( $num ) {

		switch ( $num ) {
			case '1':
				$rand_value = 'a';
				break;
			case '2':
				$rand_value = 'b';
				break;
			case '3':
				$rand_value = 'c';
				break;
			case '4':
				$rand_value = 'd';
				break;
			case '5':
				$rand_value = 'e';
				break;
			case '6':
				$rand_value = 'f';
				break;
			case '7':
				$rand_value = 'g';
				break;
			case '8':
				$rand_value = 'h';
				break;
			case '9':
				$rand_value = 'i';
				break;
			case '10':
				$rand_value = 'j';
				break;
			case '11':
				$rand_value = 'k';
				break;
			case '12':
				$rand_value = 'l';
				break;
			case '13':
				$rand_value = 'm';
				break;
			case '14':
				$rand_value = 'n';
				break;
			case '15':
				$rand_value = 'o';
				break;
			case '16':
				$rand_value = 'p';
				break;
			case '17':
				$rand_value = 'q';
				break;
			case '18':
				$rand_value = 'r';
				break;
			case '19':
				$rand_value = 's';
				break;
			case '20':
				$rand_value = 't';
				break;
			case '21':
				$rand_value = 'u';
				break;
			case '22':
				$rand_value = 'v';
				break;
			case '23':
				$rand_value = 'w';
				break;
			case '24':
				$rand_value = 'x';
				break;
			case '25':
				$rand_value = 'y';
				break;
			case '26':
				$rand_value = 'z';
				break;
			case '27':
				$rand_value = '0';
				break;
			case '28':
				$rand_value = '1';
				break;
			case '29':
				$rand_value = '2';
				break;
			case '30':
				$rand_value = '3';
				break;
			case '31':
				$rand_value = '4';
				break;
			case '32':
				$rand_value = '5';
				break;
			case '33':
				$rand_value = '6';
				break;
			case '34':
				$rand_value = '7';
				break;
			case '35':
				$rand_value = '8';
				break;
			case '36':
				$rand_value = '9';
				break;
		}
		return $rand_value;
	}

	public function get_rand_alphanumeric( $length ) {
		global $arf_postcreator;
		if ( $length > 0 ) {
			$rand_id = '';
			for ( $i = 1; $i <= $length; $i++ ) {
				mt_srand( (float) microtime() * 1000000 );
				$num      = mt_rand( 1, 36 );
				$rand_id .= $arf_postcreator->assign_rand_value( $num );
			}
		}
		return $rand_id;
	}

	public function arfpostcreator_backup() {
		$databaseversion = get_option( 'arf_postcreator_version' );
		update_option( 'old_arf_postcreator_version', $databaseversion );
	}

	public function arf_postcreator_field_dropdown() {
		global $arffield, $MdlDb, $armainhelper;

		$form_id = $_REQUEST['form_id'];

		$field_list = array();
		$exclude   = array('arf_repeater','matrix');

		if ( is_numeric( $form_id ) ) {


            $exclude_string = "'arf_repeater','matrix'";
			$field_list = $arffield->getAll( 'fi.type not in (' . $exclude_string . ') and fi.form_id=' . (int) $form_id, "fi.id" );
		}

		?>
		<li class="arf_selectbox_option" data-value="" data-label="Select Field"><?php echo esc_html__( 'Select Field', 'ARForms-postcreator' ); ?></li>
		<?php
		if ( count( $field_list ) > 0 ) {
			foreach ( $field_list as $field ) {
				if( isset($field->field_options['parent_field_type']) && 'arf_repeater' == $field->field_options['parent_field_type']){
               		continue;
            	}
				?>
				<li class="arf_selectbox_option" data-value="<?php echo esc_html( $field->id ); ?>" data-label="<?php echo $field->name; ?>" data-type="<?php echo esc_html( $field->type ); ?>"><?php echo $armainhelper->truncate( $field->name, 33 ); ?></li>
				<?php
			}
		}

		die();
	}

	public function arf_postcreator_custom_field() {

		global $arffield, $MdlDb, $wpdb, $armainhelper, $arfform, $arf_version;

		$custom_field_count = ( isset( $_REQUEST['custom_field_count'] ) ) ? $_REQUEST['custom_field_count'] : 0;
		$field_no           = $_REQUEST['field_no'];
		$form_id            = $_REQUEST['form_id'];
		$action             = $_REQUEST['frm_action'];
		$is_blank_meta      = $_REQUEST['is_blank_meta'];
		$curr_post_type     = $_REQUEST['curr_post_type'];
		$custom_post_type   = $_REQUEST['custom_post_type'];

		$plus_icon  = ARF_PLUS_ICON;
		$minus_icon = ARF_MINUS_ICON;

		if ( $action == 'new' ) {
			$btn_id = "onclick='add_post_meta_row(1);'";
		} else {
			$btn_id = "onclick='edit_post_meta_row(1);'";
		}

		$field_list = array();
		if ( is_numeric( $form_id ) ) {
			$exclude    = "'divider','section','captcha','break','html','like','arf_repeater','matrix'";
			$field_list = $arffield->getAll( 'fi.type not in (' . $exclude . ') and fi.form_id=' . (int) $form_id, 'fi.id' );
		}
		if ( $form_id == '' ) {
			return '';
			die();
		}
		$html = '';
		if ( $is_blank_meta == 0 || $is_blank_meta == 3 ) {
			$html .= "<div id='meta_row_" . $field_no . "' class='meta_row' >";
		} else {
			$html .= "<div id='meta_row_" . $field_no . "' class='meta_row' >";
		}
		$html .= "<label class='lblsubtitle arf_pc_cf_label'>";
		$html .= esc_html__( 'Add Custom Field', 'ARForms-postcreator' );
		$html .= '</label>';
		if ( $is_blank_meta == 0 || $is_blank_meta == 3 ) {
			$html .= "<input class='txtstandardnew txtmodal1 arf_pc_cf_input' type='text' name='custom_field_name[]' />";
		} else {

			$custom_field_li = '';
			if ( is_plugin_active( 'advanced-custom-fields/acf.php' ) ) {

				$post_tbl     = $wpdb->prefix . 'posts';
				$postmeta_tbl = $wpdb->prefix . 'postmeta';

				if( version_compare( $arf_version, '4.3', '<' ) ){

					$posts = $wpdb->get_results( $wpdb->prepare( 'SELECT ID FROM ' . $post_tbl . ' WHERE post_type=%s ', 'acf' ) );

				} else {

					$posts = $arfform->arf_select_db_data( true, '',  $post_tbl, 'ID', 'WHERE post_type = %s', array('acf'));
				}

				if ( ! empty( $posts ) ) {
					foreach ( $posts as $post ) {

						if( version_compare( $arf_version, '4.3', '<' ) ){

							$post_meta = $wpdb->get_results( $wpdb->prepare( 'SELECT meta_value FROM ' . $postmeta_tbl . " WHERE meta_key LIKE 'field_%' AND post_id=%d", $post->ID ) );

						}else{

							$where_clause = "WHERE meta_key LIKE 'field_%' AND post_id = %d";
							$post_meta = $arfform->arf_select_db_data( true, '', $postmeta_tbl, 'meta_value', $where_clause, array($post->ID) );

						}

						if ( ! empty( $post_meta ) ) {
							foreach ( $post_meta as $meta ) {
								$custom_field = maybe_unserialize( $meta->meta_value );

								$custom_field_li .= '<li class="arf_selectbox_option" data-value="' . $custom_field['name'] . '" data-label="' . $custom_field['name'] . '" >' . $armainhelper->truncate( $custom_field['name'], 33 ) . '</li>';
							}
							unset( $custom_field );
						}
					}
				}
			} elseif ( is_plugin_active( 'advanced-custom-fields-pro/acf.php' ) ) {

				$post_tbl     = $wpdb->prefix . 'posts';
				$postmeta_tbl = $wpdb->prefix . 'postmeta';

				if( version_compare( $arf_version, '4.3', '<' ) ){

					$posts = $wpdb->get_results( $wpdb->prepare( 'SELECT ID,post_content,post_name,post_title,post_excerpt FROM `' . $post_tbl . '` WHERE post_type = %s ORDER BY ID', 'acf-field' ) );

				}else{

					$posts = $arfform->arf_select_db_data( true, '', $post_tbl , 'ID,post_content,post_name,post_title,post_excerpt', 'WHERE post_type = %s', array('acf-field'), '', 'ORDER BY ID');
				}
				if ( ! empty( $posts ) ) {
					foreach ( $posts as $post ) {
						$post_id          = $post->ID;
						$post_content     = maybe_unserialize( $post->post_content );
						$post_name        = $post->post_name;
						$post_title       = $post->post_title;
						$post_excerpt     = $post->post_excerpt;
						$custom_field_li .= '<li class="arf_selectbox_option" data-value="' . $post_name . '" data-label="' . $post_title . '" >' . $post_title . '</li>';

					}
				}
			}

			if ( $curr_post_type == 'basic' ) {
				$post_type = 'post';
			} elseif ( $curr_post_type == 'page' ) {
				$post_type = 'page';
			} else {
				$post_type = $custom_post_type;
			}

			$sql = 'SELECT meta_key FROM ' . $wpdb->postmeta . ' pm LEFT JOIN ' . $wpdb->prefix . "posts p ON pm.post_id=p.ID WHERE post_type='%s' GROUP BY pm.meta_key HAVING pm.meta_key NOT LIKE %s ORDER BY pm.meta_key";

			$keys = $wpdb->get_col( $wpdb->prepare( $sql, $post_type, '\_%' ) );

			$html .= "<div class='arf_form_dropdown arf_postcreator_custom_field_keys arf_pc_cf_input'>";
			$html .= "<div class='sltstandard'>";

			$selected_list_id    = $responder_list_option    = '';
			$selected_list_label = esc_html__( 'Select Field', 'ARForms-postcreator' );
			$responder_list_option_arr = array(
                                '' => addslashes(esc_html__("Select Field", "ARForms-postcreator"))
                            );

			foreach ( $keys as $key ) {
				$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $key . '" data-label="' . $key . '">' . $key . '</li>';
				$responder_list_option_arr[$key] = $key;
			}
			$responder_list_option .= $custom_field_li;

			if( method_exists( $maincontroller, 'arf_selectpicker_dom') ){
				echo $maincontroller->arf_selectpicker_dom( 'custom_field_value[]', 'custom_field_value_' . $custom_field_count, '', 'width:400px;', $selected_list_id, array(), $responder_list_option_arr );
			} else {
			$html .= '<input id="custom_field_name_' . $custom_field_count . '"  name="custom_field_name[]" value="' . $selected_list_id . '" type="hidden" ><dl class="arf_selectbox arf_pc_cf_dd_field" data-name="custom_field_name" data-id="custom_field_name_' . $custom_field_count . '" ><dt><span>' . $selected_list_label . '</span><input value="'.$selected_list_id.'" class="arf_autocomplete" autocomplete="off" type="text" ><svg viewBox="0 0 2000 1000" width="15px" height="15px"><g fill="#000"><path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path></g></svg></dt><dd><ul data-id="custom_field_name_' . $custom_field_count . '"><li class="arf_selectbox_option" data-value="" data-label="' . esc_html__( 'Select Field', 'ARForms-postcreator' ) . '">' . esc_html__( 'Select Field', 'ARForms-postcreator' ) . '</li>' . $responder_list_option . '</ul></dd></dl>';
			}

			$html .= '</div>';
			$html .= '</div>';
		}
		$html .= "<input type='hidden' name='is_blank_meta[]' value='" . $is_blank_meta . "'>";
		if ( $is_blank_meta == 0 || $is_blank_meta == 3 ) {
			$html .= "<label class='lblsubtitle arf_pc_cf_from_label'>";
		} else {
			$html .= "<label class='lblsubtitle arf_pc_cf_from_label'>";
		}
		$html .= esc_html__( 'From', 'ARForms-postcreator' );
		$html .= '</label>';

		if ( $is_blank_meta == 2 || $is_blank_meta == 3 ) {
			$html .= "<input class='txtmodal1 arf_pc_cf_input' type='text' name='custom_field_value[]' />";
			$html .= "<span class='bulk_add_remove arf_pc_cf_bulk_add_remove'>";
			$html .= "<span onClick='remove_meta_row(\"#meta_row_" . $field_no . '", ' . $field_no . ")' class=\"bulk_remove_mail\"><svg viewBox='0 -4 32 32'><g id='email'>' + " . $minus_icon . " + '</g></svg></span>";
			$html .= '</span>';
		} else {
			$html .= "<div class='arf_form_dropdown arf_postcreator_custom_fields arf_pc_float_left'>";
			$html .= "<div class='sltstandard'>";

			$selected_list_id    = $responder_list_option    = '';
			$selected_list_label = esc_html__( 'Select Field', 'ARForms-postcreator' );
			$responder_list_option_arr = array(
                                '' => addslashes(esc_html__("Select Field", "ARForms-postcreator"))
                            );

			foreach ( $field_list as $field ) {
				if(isset($field->field_options['parent_field_type']) && 'arf_repeater' == $field->field_options['parent_field_type'] ){
					continue;
				}
				$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $field->id . '" data-label="' . $field->name . '">' . $armainhelper->truncate( $field->name, 33 ) . '</li>';
				$responder_list_option_arr[$field->id] = $field->name;
			}

			if( method_exists( $maincontroller, 'arf_selectpicker_dom') ){
				echo $maincontroller->arf_selectpicker_dom( 'custom_field_value[]', 'custom_field_value_' . $custom_field_count, '', '', $selected_list_id, array(), $responder_list_option_arr );
			} else {

			$html .= '<input id="custom_field_value_' . $custom_field_count . '"  name="custom_field_value[]" value="' . $selected_list_id . '" type="hidden" /><dl class="arf_selectbox arf_pc_cf_dd_field" data-name="custom_field_value" data-id="custom_field_value_' . $custom_field_count . '" ><dt><span>' . $selected_list_label . '</span><input value="' . $selected_list_id . '" class="arf_autocomplete" type="text" autocomplete="off" /><svg viewBox="0 0 2000 1000" width="15px" height="15px"><g fill="#000"><path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path></g></svg></dt><dd><ul data-id="custom_field_value_' . $custom_field_count . '"><li class="arf_selectbox_option" data-value="" data-label="' . esc_html__( 'Select Field', 'ARForms-postcreator' ) . '">' . esc_html__( 'Select Field', 'ARForms-postcreator' ) . '</li>' . $responder_list_option . '</ul></dd></dl>';
				}

			$html .= '</div>';
			$html .= '</div>';
			$html .= "<span class='bulk_add_remove arf_pc_cf_bulk_add_remove'>";

			$html .= "<span onClick='remove_meta_row(\"#meta_row_" . $field_no . '", ' . $field_no . ")' class=\"bulk_remove_mail\"><svg viewBox='0 -4 32 32'><g id='email'>' + " . $minus_icon . " + '</g></svg></span>";
			$html .= '</span>';
		}

		$html .= "<div class='arferrmessage arf_pc_cf_bulk_add_remove_err_msg' id='arf_postcreator_custom_field_msg_" . $field_no . "'>";
		$html .= esc_html__( 'Please enter field name and form field', 'ARForms-postcreator' );
		$html .= '</div>';
		$html .= '</div>';

		echo $html;
		die();
	}

	public function custom_fields( $values, $field_name , $field_value , $total, $action, $field_array ) {

		global $arffield, $MdlDb, $wpdb, $armainhelper, $arfform, $MdlDb, $arf_version;


		if ( is_array( $values ) ) {
			$form_id = $values['form_id'];
		} else {
			$form_id = $values;
		}

		$curr_post_type = $values['post_type'];
		if ( $curr_post_type == 'basic' ) {
			$post_type = 'post';
		} elseif ( $curr_post_type == 'page' ) {
			$post_type = 'page';
		} else {
			$post_type = $values['custom_post'];
		}

		$sql = 'SELECT meta_key FROM ' . $wpdb->postmeta . ' pm LEFT JOIN ' . $wpdb->prefix . "posts p ON pm.post_id=p.ID WHERE post_type='%s' GROUP BY pm.meta_key HAVING pm.meta_key NOT LIKE %s ORDER BY pm.meta_key";

		$keys = $wpdb->get_col( $wpdb->prepare( $sql, $post_type, '\_%' ) );

		$field_list = array();

		if ( is_numeric( $form_id ) ) {

			$exclude    = array( 'divider', 'section', 'captcha', 'break', 'html', 'like','arf_repeater', 'matrix' );
			$field_list = $field_array;
		}

		if ( is_numeric( $form_id ) ) {

			if( version_compare( $arf_version, '4.3', '<' ) ){

				$res = $wpdb->get_results( 'SELECT * FROM ' . $wpdb->prefix . 'arf_postcreator_forms WHERE form_id=' . $form_id );

			}else{

				$tblnm = $wpdb->prefix . 'arf_postcreator_forms pst LEFT JOIN ' . $MdlDb->forms . ' frm ON pst.form_id = frm.id';
				$res = $arfform->arf_select_db_data( true, '', $tblnm , 'pst.*', 'WHERE pst.form_id = %d', array($form_id));
			}

			$custom_fields = maybe_unserialize( $res[0]->options );
		}

		if ( $action == 'new' ) {
			$btn_id = "onclick='add_post_meta_row(1);'";
		} else {
			$btn_id = "onclick='edit_post_meta_row(1);'";
		}
		if ( ! empty( $custom_fields['custom_fields'] ) ) {

			for ( $i = 0; $i < $total; $i++ ) {
				$is_blank_meta = isset( $values['is_blank_meta'][ $i ] ) ? $values['is_blank_meta'][ $i ] : '';

				$html = '';
				if ( $is_blank_meta == 0 || $is_blank_meta == 3 ) {
					$html .= "<div id='meta_row_" . $i . "' class='meta_row'>";
				} else {
					$html .= "<div id='meta_row_" . $i . "' class='meta_row'>";
				}
				$html .= "<label class='lblsubtitle arf_pc_cf_label'>";
				$html .= esc_html__( 'Add Custom Field', 'ARForms-postcreator' );
				$html .= '</label>';
				if ( $is_blank_meta == 0 || $is_blank_meta == 3 ) {
					$custom_field_value = isset( $custom_fields['custom_fields'][ $i ] ) ? $custom_fields['custom_fields'][ $i ] : '';
					$html              .= "<input class='txtstandardnew txtmodal1 arf_pc_cf_input' value='" . $custom_field_value . "' type='text' name='custom_field_name[]' />";
				} else {

					$custom_field_li = '';
					if ( ! function_exists( 'is_plugin_active' ) ) {
						if ( file_exists( ABSPATH . 'wp-admin/includes/plugin.php' ) ) {
							include_once ABSPATH . 'wp-admin/includes/plugin.php';
						}
					}
					$acf_field_keys   = array();
					$is_acf_installed = false;
					if ( is_plugin_active( 'advanced-custom-fields/acf.php' ) ) {

						$post_tbl     = $wpdb->prefix . 'posts';
						$postmeta_tbl = $wpdb->prefix . 'postmeta';

						if( version_compare( $arf_version, '4.3', '<' ) ){

							$posts = $wpdb->get_results( $wpdb->prepare( 'SELECT ID FROM ' . $post_tbl . ' WHERE post_type=%s', 'acf' ) );

						}else{

							$posts = $arfform->arf_select_db_data( true, '', $post_tbl, 'ID', 'WHERE post_type = %s', array('acf'));
						}

						if ( ! empty( $posts ) ) {
							foreach ( $posts as $post ) {

								if( version_compare( $arf_version, '4.3', '<' ) ){

									$post_meta = $wpdb->get_results( $wpdb->prepare( 'SELECT meta_value FROM ' . $postmeta_tbl . " WHERE meta_key LIKE 'field_%' AND post_id=%d", $post->ID ) );

								} else {

									$where_clause = "WHERE meta_key LIKE 'field_%' AND post_id= %d";
									$post_meta = $arfform->arf_select_db_data( true, '', $postmeta_tbl, 'meta_value', $where_clause, array($post->ID));

								}

								if ( ! empty( $post_meta ) ) {
									foreach ( $post_meta as $meta ) {
										$custom_field = maybe_unserialize( $meta->meta_value );

										$custom_field_li                        .= '<li class="arf_selectbox_option" data-value="' . $custom_field['name'] . '" data-label="' . $custom_field['name'] . '" >' . $armainhelper->truncate( $custom_field['name'], 33 ) . '</li>';
										$acf_field_keys[ $custom_field['name'] ] = $custom_field['name'];
									}
									unset( $custom_field );
								}
							}
						}
					} elseif ( is_plugin_active( 'advanced-custom-fields-pro/acf.php' ) ) {

						$post_tbl     = $wpdb->prefix . 'posts';
						$postmeta_tbl = $wpdb->prefix . 'postmeta';

						if( version_compare( $arf_version, '4.3', '<' ) ){

							$posts = $wpdb->get_results( $wpdb->prepare( 'SELECT ID,post_name,post_title FROM `' . $post_tbl . '` WHERE post_type = %s ORDER BY ID', 'acf-field' ) );

						}else{

							$posts = $arfform->arf_select_db_data( true, '', $post_tbl, 'ID,post_name,post_title', 'WHERE post_type = %s', array('acf-field'), '', 'ORDER BY ID');
						}

						if ( ! empty( $posts ) ) {
							foreach ( $posts as $post ) {
								$post_id                      = $post->ID;
								$post_name                    = $post->post_name;
								$post_title                   = $post->post_title;
								$acf_field_keys[ $post_name ] = $post_title;

							}
						}
						$is_acf_installed = true;
					}

					$keys = array_merge( $keys, $acf_field_keys );

					if ( $curr_post_type == 'basic' ) {
						$post_type = 'post';
					} elseif ( $curr_post_type == 'page' ) {
						$post_type = 'page';
					} else {
						$post_type = 'custompost';
					}

					$html                 .= "<div class='arf_form_dropdown arf_postcreator_custom_field_keys arf_pc_cf_input'>";
					$html                 .= "<div class='sltstandard'>";
					$selected_list_id      = '';
					$selected_list_label   = esc_html__( 'Select Field', 'ARForms-postcreator' );
					$responder_list_option = '<li class="arf_selectbox_option" data-value="" data-name="' . $selected_list_label . '">' . $selected_list_label . '</li>';
					$cntr                  = 0;

					foreach ( $keys as $k => $key ) {
						if ( $key == $custom_fields['custom_fields'][ $i ] && ! array_key_exists( $k, $acf_field_keys ) ) {
							$selected_list_id    = $key;
							$selected_list_label = $key;
						}

						if ( $is_acf_installed && array_key_exists( $k, $acf_field_keys ) ) {

							if ( $k == $custom_fields['custom_fields'][ $i ] ) {
								$selected_list_id    = $k;
								$selected_list_label = $key;
							}

							$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $k . '" data-name="' . $key . '">' . $key . '</li>';
						} else {
							$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $key . '" data-name="' . $key . '">' . $key . '</li>';
						}
						$cntr++;
					}
					$responder_list_option .= $custom_field_li;
					$html                  .= "<input id='custom_field_name_" . $i . "'  name='custom_field_name[]' value='" . $selected_list_id . "' type='hidden' >";
					$html                  .= "<dl class='arf_selectbox arf_pc_cf_dd_field' data-name='custom_field_name[]' data-id='custom_field_name_" . $i . "'>";
					$html                  .= '<dt><span>' . $selected_list_label . '</span>';
					$html                  .= "<input value='" . $selected_list_id . "' class='arf_autocomplete' type='text' autocomplete='off' />";
					$html                  .= '<svg viewBox="0 0 2000 1000" width="15px" height="15px">
                            <g fill="#000">
                            <path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
                            </g>
                            </svg>';
					$html                  .= '</dt>';
					$html                  .= '<dd>';
					$html                  .= '<ul data-id="custom_field_name_' . $i . '">';
					$html                  .= $responder_list_option;
					$html                  .= '</ul>';
					$html                  .= '</div>';
					$html                  .= '</div>';
				}

				$html .= "<input type='hidden' name='is_blank_meta[]' value='" . $is_blank_meta . "'>";
				if ( $is_blank_meta == 0 || $is_blank_meta == 3 ) {
					$html .= "<label class='lblsubtitle arf_pc_cf_from_label'>";
				} else {
					$html .= "<label class='lblsubtitle arf_pc_cf_from_label'>";
				}
				$html .= esc_html__( 'From', 'ARForms-postcreator' );
				$html .= '</label>';

				if ( $is_blank_meta == 2 || $is_blank_meta == 3 ) {
					$html .= "<input class='txtstandardnew txtmodal1 arf_pc_cf_input' type='text' value='" . $custom_fields['custom_field_value'][ $i ] . "' name='custom_field_value[]' />";
					$html .= "<span class='bulk_add_remove arf_pc_cf_bulk_add_remove'>";

					$html .= "<span onClick='remove_meta_row(\"#meta_row_" . $i . '", ' . $i . ")' class='bulk_remove_mail'><svg viewBox='0 -4 32 32'><g id='email'>" . ARF_MINUS_ICON . '</g></svg></span>';
					$html .= '</span>';
				} else {
					$html                 .= "<div class='arf_form_dropdown arf_postcreator_custom_fields arf_pc_float_left'>";
					$html                 .= "<div class='sltstandard'>";
					$selected_list_id      = '';
					$selected_list_label   = esc_html__( 'Select Field', 'ARForms-postcreator' );
					$responder_list_option = '<li class="arf_selectbox_option" data-value="" data-label="' . $selected_list_label . '">' . $selected_list_label . '</li>';
					$cntr                  = 0;

					if ( count( $field_list ) > 0 ) {
						
						foreach ( $field_list as $field ) {

							if ( in_array( $field->type, $exclude ) ) {
								continue;
							}
							if( isset($field->field_options['parent_field_type']) && 'arf_repeater' == $field->field_options['parent_field_type']){
								continue;
							}
							
							if ( $custom_fields['custom_field_value'][ $i ] == $field->id ) {
								$selected_list_id    = $field->id;
								$selected_list_label = $field->name;
							}
							$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $field->id . '" data-label="' . $field->name . '">' . $armainhelper->truncate( $field->name, 33 ) . '</li>';
							$cntr++;
						}
					}

					$html .= "<input id='custom_field_value_" . $i . "'  name='custom_field_value[]' value='" . $selected_list_id . "' type='hidden' >";
					$html .= "<dl class='arf_selectbox arf_pc_cf_dd_field' data-name='custom_field_value[]' data-id='custom_field_value_" . $i . "' >";
					$html .= '<dt><span>' . $selected_list_label . '</span>';
					$html .= "<input value='" . $selected_list_id . "' class='arf_autocomplete' autocomplete='off' type='text' />";
					$html .= '<svg viewBox="0 0 2000 1000" width="15px" height="15px">
                            <g fill="#000">
                            <path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
                            </g>
                            </svg>';
					$html .= '</dt>';
					$html .= '<dd>';
					$html .= '<ul  data-id="custom_field_value_' . $i . '">';
					$html .= $responder_list_option;
					$html .= '</ul>';
					$html .= '</dd>';
					$html .= '</dl>';
					$html .= '</div>';
					$html .= '</div>';
					$html .= "<span class='bulk_add_remove arf_pc_cf_bulk_add_remove'>";
					$html .= "<span onClick='remove_meta_row(\"#meta_row_" . $i . '", ' . $i . ")' class='bulk_remove_mail'><svg viewBox='0 -4 32 32'><g id='email'>" . ARF_MINUS_ICON . '</g></svg></span>';
					$html .= '</span>';

				}
				
				$html .= "<div class='arferrmessage arf_pc_cf_bulk_add_remove_err_msg' id='arf_postcreator_custom_field_msg_" . $i . "' >";
				$html .= esc_html__( 'Please enter field name and form field', 'ARForms-postcreator' );
				$html .= '</div>';
				$html .= '</div>';
				echo $html;
			}
		}
	}

	public function after_submit_form( $entry_id, $form_id ) {
		
		global $arf_postcreator, $wpdb, $arf_version, $arfform, $MdlDb;
		if ( version_compare( $arf_version, '3.0', '>=' ) ) {

			global $arfrecordmeta, $wpdb, $arfsettings;
			if ( $arfsettings->form_submit_type == 1 ) {
				if ( ! function_exists( 'wp_generate_attachment_metadata' ) ) {
					require ABSPATH . 'wp-admin/includes/image.php';
				}
			}

			$entry_ids = array( $entry_id );
			$values    = $arfrecordmeta->getAll( 'it.field_id != 0 and it.entry_id in (' . implode( ',', $entry_ids ) . ')', ' ORDER BY fi.id' );

			if( version_compare( $arf_version, '4.3', '<' ) ){
				
				$get_mapped_form = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM ' . $wpdb->prefix . 'arf_postcreator_forms WHERE form_id=%d', $form_id ) );
			
			} else{

				$tblnm = $wpdb->prefix . 'arf_postcreator_forms pst LEFT JOIN ' . $MdlDb->forms . ' frm ON pst.form_id = frm.id';
				$get_mapped_form = $arfform->arf_select_db_data(true, '', $tblnm , 'pst.*' , 'WHERE pst.form_id = %d', array($form_id));

			}

			$result          = count( $get_mapped_form );
			if ( $result > 0 ) {
				$options       = maybe_unserialize( $get_mapped_form[0]->options );

				$posted_values = $values;
				$post_type     = $options['post_type'];
				if ( $post_type == 'custom' ) {
					$type = $options['custom_post'];
				} elseif ( $post_type == 'page' ) {
					$type = 'page';
				} elseif ( $post_type == 'buddypress_grp' ) {
					$type = 'buddypress_grp';
				} else {
					$type = 'post';
				}
				foreach ( $values as $value ) {
					$entry_value_val = maybe_unserialize( $value->entry_value );
					if (isset( $options['bp_group_name'] ) && $options['bp_group_name'] != '' && $options['bp_group_name'] == $value->field_id) {
						$group_list = $entry_value_val;
					} else if(isset($options['bp_group_name_array']) && !empty($options['bp_group_name_array'])){
						$group_list = $options['bp_group_name_array'];
					}
					if ( is_array( $entry_value_val ) ) {
						$entry_value_val = implode( ',', $entry_value_val );
					}

					if ( isset( $options['title'] ) && $options['title'] == $value->field_id ) {
						$post_title = $entry_value_val;
					}
					if ( isset( $options['description'] ) && $options['description'] == $value->field_id ) {
						$post_content = $entry_value_val;
					}


					if ( isset( $options['excerpt'] ) && $options['excerpt'] == $value->field_id && $type != 'page' ) {
						$post_excerpt = $entry_value_val;
					}
					if ( isset( $options['tag'] ) && $options['tag'] == $value->field_id && $type != 'page' ) {

						$post_tag = $entry_value_val;
					}
					if ( isset( $options['author'] ) && $options['author'] == 'default' ) {

						if( version_compare( $arf_version, '4.3', '<' ) ){
							
							$author = $wpdb->get_row( $wpdb->prepare( 'SELECT * FROM ' . $wpdb->prefix . 'arf_entries WHERE id =%d', $value->entry_id ) );

						} else{

							$author = $arfform->arf_select_db_data(true, '', $wpdb->prefix .'arf_entries', '*', 'WHERE id = %d', array($value->entry_id), '', '', '', false, true);
						}


						$post_author = $author->user_id;
					} else {
						$post_author = $options['author'];
					}

					if ( $options['date'] == 'default' ) {

						if( version_compare( $arf_version, '4.3', '<' ) ){

							$date = $wpdb->get_row( $wpdb->prepare( 'SELECT * FROM ' . $wpdb->prefix . 'arf_entries WHERE id =%d ', $value->entry_id ) );

						} else{

							$date = $arfform->arf_select_db_data(true, '', $wpdb->prefix . 'arf_entries', '*', 'WHERE id = %d', array($value->entry_id), '', '', '', false, true);
						}

						$post_date = $date->created_date;
					} else {
						if ( $options['date'] == $value->field_id ) {
							$date = $entry_value_val;
							$dt   = date( 'Y-m-d h:i:s', strtotime( $date ) );
							if ( $date ) {
								$post_date = $dt;
							} else {

								if( version_compare( $arf_version, '4.3', '<' ) ){

									$date      = $wpdb->get_row( $wpdb->prepare( 'SELECT * FROM ' . $wpdb->prefix . 'arf_entries WHERE id =%d', $value->entry_id ) );

								} else{
									
									$date = $arfform->arf_select_db_data(true, '', $wpdb->prefix . 'arf_entries', '*', 'WHERE id = %d', array($value->entry_id), '', '', '', false, true);

								}

								$post_date = $date->created_date;
							}
						}
					}
					if ( $options['image'] == $value->field_id ) {
						$attachment_id = $entry_value_val;
					}
					if ( isset( $form_options['post_format'] ) && $options['post_format'] == $value->field_id && $options['post_format_fixed'] == 0 && $options['post_format'] != '' ) {
						$format = $entry_value_val;
					}
				}

				$comment_status = ( isset( $options['arf_allow_comment'] ) && $options['arf_allow_comment'] == '1' ) ? 'open' : 'closed';

				$post_status = $options['status'];
				$args        = array(
					'post_title'     => ( isset( $post_title ) ? $post_title : '' ),
					'post_content'   => ( isset( $post_content ) ? $post_content : '' ),
					'post_excerpt'   => ( isset( $post_excerpt ) ? $post_excerpt : '' ),
					'post_status'    => ( isset( $post_status ) ? $post_status : '' ),
					'post_author'    => ( isset( $post_author ) ? $post_author : '' ),
					'post_date'      => ( isset( $post_date ) ? $post_date : '' ),
					'post_type'      => ( isset( $type ) ? $type : '' ),
					'comment_status' => ( isset( $comment_status ) ? $comment_status : '' ),
				);
				$wp_error    = false;
				$post_id     = wp_insert_post( $args, $wp_error );
				add_post_meta($post_id, 'arf_form_id', $form_id);
				add_post_meta($post_id, 'arf_form_entry_id', $entry_id);
				if ( $type == 'post' ) {
					
					if ( $options['category_single'][0] != '' ) {
						foreach ( $values as $value ) {
							if ( $options['category_single'][0] == $value->field_id ) {
								$category = maybe_unserialize( $value->entry_value );
								if( $value->field_type == 'arf_multiselect' && !is_array( $category ) ){
									$category = explode( ',', $category );
								}
								if ( is_array( $category ) ) {
									foreach ( $category as $cat ) {
										if( is_array( $cat ) ){
											$cat_ids[] = get_cat_ID( $cat[0] );
										} else {
											$cat_ids[] = get_cat_ID( $cat );
										}
									}
									wp_set_post_categories( $post_id, $cat_ids );
								} else {	
									$cat_ids[] = get_cat_ID( $category );
									wp_set_post_categories( $post_id, $cat_ids );
								}
							}
						}
					} else {
						wp_set_post_categories( $post_id, $options['categories'] );
					}
				} elseif ( $type != 'page' && $type != 'buddypress_grp' ) {
					$custom_cat_type = $options['custom_categories'];

					if ( is_array($custom_cat_type) && count( $custom_cat_type ) > 0 ) {
						$cat_ids = array();
						if ( ! empty( $options['category_single'] ) ) {
							$cat_ids = array();
							foreach ( $custom_cat_type as $cat_type ) {
								$cat_ids[]   = $options['category_single'][ $cat_type ][0];
								
								$cat_types[] = $cat_type;
								$cat_ids     = array_map( 'intval', $cat_ids );
								$term_id     = array();
								$term_ids    = array();
								foreach ( $cat_ids as $cat_id ) {
									foreach ( $values as $value ) {
										if ( $cat_id == $value->field_id ) {
											$term_name = maybe_unserialize( $value->entry_value );
											if( $value->field_type == 'arf_multiselect' && !is_array( $term_name ) ){
												$term_name = explode( ',', $term_name );
											}
											if ( is_array( $term_name ) ) {
												foreach ( $term_name as $t_name ) {
													$t_name    =  htmlentities($t_name);

													$term      = get_term_by( 'name', $t_name, $cat_type );
													$term_id[] = $term->term_id;
												}
												$term_ids = array_map( 'intval', $term_id );
												wp_set_object_terms( $post_id, $term_ids, $cat_type, true );
												unset( $value->entry_value );
											} else {
												$term_name = htmlentities( $term_name );
												$term      = get_term_by( 'name', $term_name, $cat_type );
												$term_id[] = $term->term_id;
												$term_ids  = array_map( 'intval', $term_id );
												wp_set_object_terms( $post_id, $term_ids, $cat_type, true );
												unset( $value->entry_value );
											}
										}
									}
								}
							}
						}
						
						if ( is_array( $custom_cat_type ) && count( $custom_cat_type ) > 0 ) {
							foreach ( $custom_cat_type as $cat_type ) {
								if ( is_array( $options['categories'][ $cat_type ] ) ) {
									foreach ( $options['categories'][ $cat_type ] as $cats ) {
										$ids[] = $cats;
									}
									$t_ids = array_map( 'intval', $ids );
									wp_set_object_terms( $post_id, $t_ids, $cat_type );
								}
							}
						}
					}
				} elseif ( $arf_postcreator->is_buddypress_active() && bp_is_active('groups') && $type == 'buddypress_grp' ) {
					$arf_current_userid = get_current_user_id();
					$membersingrp = BP_Groups_Member::get_group_ids($arf_current_userid);
					if (is_array($group_list)) {
						foreach ($group_list as $key => $group_id) {
							$args  = array(
								'content' 	=> (isset($post_content)?$post_content: ''),
								'component' => 'groups',
								'type' 		=> 'activity_update',
								'user_id' 	=> (isset($arf_current_userid) ? $arf_current_userid : ''),
								'item_id'   => (isset($group_id)) ? $group_id : ''
							);

							if (in_array($group_id, $membersingrp['groups'])) {
								$activity = bp_activity_add($args);
							}		
						}
					}else{
						$group_id = $group_list;
						
						$args  = array(
							'content' 	=> (isset($post_content)?$post_content: ''),
							'component' => 'groups',
							'type' 		=> 'activity_update',
							'user_id' 	=> (isset($arf_current_userid) ? $arf_current_userid : ''),
							'item_id'   => $group_id
						);
							
						if (in_array($group_id, $membersingrp['groups'])) {
							$activity = bp_activity_add($args);
						}
					}		
				}
				if ( $type == 'post' ) {
					$post_tag = isset( $post_tag ) ? $post_tag : '';
					$tag      = $post_tag;
					wp_set_post_tags( $post_id, $tag );
				}

				if ( isset( $options['post_format_fixed'] ) && $options['post_format_fixed'] == 1 ) {
					$format = $options['post_format'];
				}

				if ( ! empty( $format ) && $type != 'page' ) {
					wp_set_post_terms( $post_id, $format, 'post_format' );
				}

				if ( ! empty( $attachment_id ) ) {

					$img       = get_post( $attachment_id );
					$mime_type = $img->post_mime_type;
					if ( $mime_type == 'image/jpeg' || $mime_type == 'image/bmp' || $mime_type == 'image/png' || $mime_type == 'image/gif' || $mime_type == 'image/tiff' ) {
						if( version_compare( $arf_version, '4.3', '<') ){
							global $arformhelper;

							$imageupload_dir     = $arformhelper->get_file_upload_path();
							$imageupload_dir     = $arformhelper->replace_file_upload_path_shrtcd( $imageupload_dir, $form_id );
							$imageupload_dir_sub = ABSPATH . $imageupload_dir;
							$file                = $imageupload_dir_sub . $img->post_title;

							$file_post_path = $imageupload_dir . $img->post_title;

							$attached_data = wp_generate_attachment_metadata( $attachment_id, $file );

							add_post_meta( $post_id, '_thumbnail_id', $attachment_id );
							$attachment_metadata = wp_get_attachment_metadata( $attachment_id );
							if ( $attachment_metadata == '' ) {
								add_post_meta( $attachment_id, '_wp_attachment_metadata', $attached_data );
								update_post_meta( $attachment_id, '_wp_attached_file', $file_post_path );

							} else {
								wp_update_attachment_metadata( $attachment_id, $attached_data );
								update_attached_file( $attachment_id, $file_post_path );

							}

							if ( isset( $options['image'] ) && ! empty( $options['image'] ) ) {
								$movable = $arformhelper->manage_uploaded_file_path( $form_id, true );
								if ( $movable['status'] ) {
									copy( $file, $movable['path'] . $img->post_title );
								}
							}
						} else {
							set_post_thumbnail( $post_id, $attachment_id );
						}
					}
				}
				if ( is_array( $options['custom_fields'] ) && count( $options['custom_fields'] ) > 0 ) {
					if ( array_filter( is_array( $options['custom_fields'] ) ? $options['custom_fields'] : array() ) != '' ) {

						if ( count( $options['custom_fields'] ) > 0 ) {

							foreach ( $options['custom_fields'] as $i => $cs_fields ) {
								$meta_key      = $options['custom_fields'][ $i ];
								$is_blank_meta = $options['is_blank_meta'][ $i ];

								$flag        = false;
								$meta_key2   = '';
								$meta_value2 = '';

								if ( is_plugin_active( 'advanced-custom-fields/acf.php' ) ) {
									$post_tbl     = $wpdb->prefix . 'posts';
									$postmeta_tbl = $wpdb->prefix . 'postmeta';

									if( version_compare( $arf_version, '4.3', '<' ) ){

										$posts = $wpdb->get_results( 'SELECT ID FROM ' . $post_tbl . " WHERE post_type='acf'" );

									}else{

										$posts = $arfform->arf_select_db_data(true, '', $post_tbl, 'ID', 'WHERE post_type = %s', array('acf'));
									}
									if ( ! empty( $posts ) ) {
										foreach ( $posts as $post ) {

											if( version_compare( $arf_version, '4.3', '<' ) ){

												$post_meta = $wpdb->get_results( $wpdb->prepare( 'SELECT meta_value FROM ' . $postmeta_tbl . " WHERE meta_key LIKE 'field_%' AND post_id=%d", $post->ID ) );

											}else{

												$where_clause = "WHERE meta_key LIKE 'field_%' AND post_id = %d";
												$post_meta = $arfform->arf_select_db_data(true, '', $postmeta_tbl, 'meta_value', $where_clause, array($post->ID));
											}

											if ( ! empty( $post_meta ) ) {
												foreach ( $post_meta as $meta ) {
													$custom_field = maybe_unserialize( $meta->meta_value );

													if ( $custom_field['name'] == $meta_key ) {
														$meta_key2   = '_' . $custom_field['name'];
														$meta_value2 = $custom_field['key'];
														if ( $custom_field['type'] == 'checkbox' ) {
															$flag = true;
														}
													}
												}
												unset( $custom_field );
											}
										}
									}
								} elseif ( is_plugin_active( 'advanced-custom-fields-pro/acf.php' ) ) {
									$post_tbl     = $wpdb->prefix . 'posts';
									$postmeta_tbl = $wpdb->prefix . 'postmeta';

									if( version_compare( $arf_version, '4.3', '<' ) ){

										$posts = $wpdb->get_row( $wpdb->prepare( 'SELECT post_content,post_excerpt FROM ' . $post_tbl . ' WHERE post_type=%s AND post_name = %s', 'acf-field', $meta_key ) );

									}else{
										
										$posts = $arfform->arf_select_db_data(true, '', $post_tbl, 'post_content,post_excerpt', 'WHERE post_type = %s AND post_name = %s', array('acf-field', $meta_key), '', '', '', false, true);

									}

									$meta_value2 = $meta_key;

									$content = maybe_unserialize( $posts->post_content );

									if ( ! empty( $posts ) ) {
										$meta_key = $posts->post_excerpt;
									}

									if ( $content['type'] == 'checkbox' ) {
										$flag = true;
									}

									$meta_key2 = '_' . $meta_key;

								}

								foreach ( $values as $value ) {
									$meta_value = '';
									if ( $is_blank_meta == 2 || $is_blank_meta == 3 ) {

										$meta_value = $options['custom_field_value'][ $i ];
										break;
									} elseif ( $options['custom_field_value'][ $i ] == $value->field_id ) {

										$value_entry_value = maybe_unserialize( $value->entry_value );
										if ( is_array( $value_entry_value ) ) {
											if ( $flag == true ) {
												$meta_value = $value->entry_value;
											} else {
												$meta_value = implode( ',', $value_entry_value );
											}
										} else {
											$meta_value = $value_entry_value;
										}
										break;
									}
								}

								update_post_meta( $post_id, $meta_key, $meta_value );
								if ( $meta_key2 != '' ) {
									update_post_meta( $post_id, $meta_key2, $meta_value2 );
								}
							}
						}
					}
				} else {
					return;
				}
			} else {
				return;
			}
		}
	}

	public function after_paypal_submit_form( $form_id, $entry_id, $txn_id ) {
		global $arf_postcreator;
		$arf_postcreator->after_submit_form( $entry_id, $form_id );
	}

	public function arf_postcreator_file_field_dropdown() {
		global $arffield, $MdlDb;

		$form_id = $_REQUEST['form_id'];

		$field_list = array();

		if ( is_numeric( $form_id ) ) {

			$include = "'file'";

			$field_list = $arffield->getAll( 'fi.type in (' . $include . ') and fi.form_id=' . (int) $form_id, 'fi.id' );
		}
		?>
		<li class="arf_selectbox_option" data-value="" data-label=""><?php echo esc_html__( 'Please select field', 'ARForms-postcreator' ); ?></li>
		<?php
		if ( count( $field_list ) > 0 ) {
			foreach ( $field_list as $field ) {
				?>
				<li class="arf_selectbox_option" data-value="<?php echo esc_html( $field->id ); ?>" data-label="<?php echo $field->name; ?>"><?php echo armainhelper::truncate( $field->name, 33 ); ?></li>
				<?php
			}
		}
		die();
	}

	public function file_field_dropdown( $form_id, $name , $class , $default_value , $id , $field_array ) {

		global $arffield, $MdlDb, $maincontroller;

		$field_list = array();
		$field_list = $field_array;
		$include    = 'file';

		global $armainhelper;
		$selected_list_id      = '';
		$selected_list_label   = esc_html__( 'Select Field', 'ARForms-postcreator' );
		$responder_list_option_arr = array(
                                '' => addslashes(esc_html__("Select Field", "ARForms-postcreator"))
                            );
		$responder_list_option = '';
		if ( count( $field_list ) > 0 ) {
			$cntr = 0;

			foreach ( $field_list as $field ) {
				if ( $field->type != $include ) {
					continue;}
				if ( $default_value == $field->id ) {
					$selected_list_id    = $field->id;
					$selected_list_label = $field->name;
				}
				$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $field->id . '" data-label="' . $field->name . '">' . $armainhelper->truncate( $field->name, 33 ) . '</li>';
				/*$responder_list_option_arr[ $list['id'] ] = $list['name'];*/
				$responder_list_option_arr[ $field->id ] = $field->name;
				$cntr++;
			}
		}

		$input_id = ( '' == $id ) ? $name : $id;
		if( method_exists( $maincontroller, 'arf_selectpicker_dom') ){
            echo $maincontroller->arf_selectpicker_dom( $name, $input_id, ' arf_pc_file_field_dd ', '', $selected_list_id, array(), $responder_list_option_arr, false, array(), false, array(), false,  array(), false, $class );
        } else {
		?>
			<input id="<?php echo esc_html( $input_id ); ?>" name="<?php echo esc_html( $name ); ?>" value="<?php echo esc_html( $selected_list_id ); ?>" type="hidden" />
			<dl class="arf_selectbox arf_pc_file_field_dd" data-name="<?php echo esc_html( $name ); ?>" data-id="<?php echo esc_html( $input_id ); ?>">
				<dt>
					<span><?php echo $selected_list_label; ?></span>
					<input value="<?php echo esc_html( $selected_list_id ); ?>" class="arf_autocomplete" type="text" autocomplete="off" />
					<svg viewBox="0 0 2000 1000" width="15px" height="15px">
						<g fill="#000">
							<path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
						</g>
					</svg>
				</dt>
				<dd>
					<ul data-id="<?php echo esc_html( $input_id ); ?>" class="<?php echo esc_attr( $class ); ?>">
						<?php echo $responder_list_option; ?>
					</ul>
				</dd>
			</dl>
		<?php
	}
	}

	public function field_custom_post( $form_id, $name = '', $class = '', $default_value = '', $id = '' ) {
		global $is_version_compatible, $maincontroller;

		$args             = array(
			'_builtin' => false,
			'public'   => true,
		);
		$output           = 'object';
		$custom_post_type = get_post_types( $args, $output );

		global $armainhelper;
		$selected_list_id      = '';
		$selected_list_label   = esc_html__( 'Select Custom Post', 'ARForms-postcreator' );
		$responder_list_option_arr = array(
                                '' => addslashes(esc_html__("Select Custom Post", "ARForms-postcreator"))
                            );
		$responder_list_option = '';
		if ( count( $custom_post_type ) > 0 ) {
			$cntr = 0;
			foreach ( $custom_post_type as $field ) {
				if ( $default_value == $field->name ) {
					$selected_list_id    = $field->name;
					$selected_list_label = $field->label;
				}
				$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $field->name . '" data-label="' . $field->label . '">' . $armainhelper->truncate( $field->label, 33 ) . '</li>';
				$responder_list_option_arr[$field->name] = $field->label;
				$cntr++;
			}
		}
		if( method_exists( $maincontroller, 'arf_selectpicker_dom') ){
			$select_attrs = array(
				'onchange'	=>	'get_custom_post_categories(new Array(this.value))',
				'class'		=>	$class
			);
			echo $maincontroller->arf_selectpicker_dom( $name, ( $id == '' ) ? $name : $id , ' arf_pc_cf_post_dd_field ', '', $selected_list_id, array(), $responder_list_option_arr );
		} else {
		?>
			<input id="<?php echo ( $id == '' ) ? $name : $id ; ?>" name="<?php echo esc_html( $name ); ?>" value="<?php echo esc_html( $selected_list_id ); ?>" type="hidden" class="<?php echo esc_attr( $class ); ?>" onchange="get_custom_post_categories(new Array(this.value))" />
			<dl class="arf_selectbox arf_pc_cf_post_dd_field" data-name="<?php echo esc_html( $name ); ?>" data-id="<?php if ( $id == '' ) { echo esc_html( $name ); } else { echo esc_html( $id ); } ?>">
				<dt>
					<span><?php echo $selected_list_label; ?></span>
					<svg viewBox="0 0 2000 1000" width="15px" height="15px">
						<g fill="#000">
							<path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
						</g>
					</svg>
				</dt>
				<dd>
					<ul data-id="<?php if ( $id == '' ) { echo esc_html( $name ); } else { echo esc_html( $id ); } ?>">
						<?php echo $responder_list_option; ?>
					</ul>
				</dd>
			</dl>
		<?php
	}
	}

	public function get_buddypress_group_list( $form_id, $name = '', $class = '', $default_value = '', $id = ''){
		global $arf_postcreator, $armainhelper;
		if($arf_postcreator->is_buddypress_active() && bp_is_active('groups')){
			$vgroups = $groups = BP_Groups_Group::get(array(
				'type'=>'alphabetical',
			));

			$arf_groups_list =  $vgroups['groups'];
			
			?>
			
			<div class="arf_pc_category_field_wrapper">
				<?php
				if ( count( $arf_groups_list ) > 0 ) {
					$cntr = 0;
					$checked_opts = '';

					foreach ( $arf_groups_list as $group_key => $field  ) {
						if ($field->status != 'hidden') {
							?>
							<div class="frm_grp_lbl_<?php echo $cntr; ?>">
								<div class="radiobutton">
									<label for="<?php echo ( $id == '' ) ? $name. '_' . $cntr : $id . '_' . $cntr ; ?>">
										<div class="arf_custom_checkbox_div">
											<div class="arf_custom_checkbox_wrapper">
											
												<input type="checkbox" name="<?php echo $name; ?>[]" class="" <?php echo (is_array($default_value) && (in_array($field->id, $default_value))) ? 'checked' : '' ; ?> id="<?php echo ( $id == '' ) ? $name . '_' . $cntr : $id . '_' . $cntr ; ?>" value="<?php echo esc_html( $field->id ); ?>" />
												<svg width="18px" height="18px">
													<?php echo ARF_CUSTOM_UNCHECKED_ICON; ?>
													<?php echo ARF_CUSTOM_CHECKED_ICON; ?>
												</svg>
											</div>
										</div>
										<label for="<?php echo ( $id == '' ) ? $name. '_' . $cntr : $id. '_' . $cntr ; ?>" title="arf_postcreator_category" ><?php echo $field->name; ?></label>
									</label>
								</div>
							</div>
							
							<?php
						}
						$cntr++;
					}
				}?>
			</div>
			<?php
		}
	}

	public function arf_postcreator_custom_post_field_dropdown() {
		global $armainhelper;
		$args             = array(
			'_builtin' => false,
			'public'   => true,
		);
		$output           = 'object';
		$custom_post_type = get_post_types( $args, $output );
		?>
		<option value=""><?php echo esc_html__( 'Select Post Type', 'ARForms-postcreator' ); ?></option>
		<?php
		if ( count( $custom_post_type ) > 0 ) {
			foreach ( $custom_post_type as $field ) {
				?>
				<option value="<?php echo esc_html( $field->name ); ?>"><?php echo $armainhelper->truncate( $field->label, 33 ); ?></option>
				<?php
			}
		}

		die();
	}

	public function basic_categories( $values = array() ) {
		$args     = array();
		$defaults = array(
			'field'      => array(
				'id'	 => '',
				'type'   => '',
				'field_options' => array()
			),
			'field_name' => false,
			'opt_key'    => 0,
			'opt'        => '',
			'type'       => 'checkbox',
			'value'      => false,
			'exclude'    => 0,
			'hide_id'    => false,
		);
		extract( wp_parse_args( $args, $defaults ) );
		global $arffield, $arf_postcreator;

		if ( ! $field_name ) {
			$field_name = "item_meta[$field[id]]";
		}

		if ( $type == 'checkbox' || $type == 'arf_multiselect' ) {
			$onchange    = '';
		} else {
			$onchange = '';
		}
		$post_type  = 'post';
		$taxonomy   = 'category';
		$args       = array(
			'orderby'    => 'name',
			'order'      => 'ASC',
			'hide_empty' => false,
			'parent'     => 0,
			'exclude'    => 'all',
			'type'       => $post_type,
		);
		$categories = get_categories( $args );
		$level      = ( $opt_key ) ? 2 : 1;

		
		$field_array = array();
		if ( !empty( $values['form_id'] ) ) {
			$field_array = $arffield->getAll( 'fi.form_id=' . (int) $values['form_id'], 'fi.id' );
		}

		?>

		<tr class="tdclass">
			<td valign="top" colspan="2" class="lbltitle arf_pc_category_label"><?php esc_html_e( 'Post Categories', 'ARForms-postcreator' ); ?></td>
		</tr>
		<tr>
			<td width="18%" valign="top" class="tdclass" colspan="2">
				<div class="arf_pc_category_data_wrapper">
					<label class="lblsubtitle arf_pc_category_user_label"><?php esc_html_e( 'Let user can select Categories', 'ARForms-postcreator' ); ?>&nbsp;&nbsp;<span class="arfglobalrequiredfield arf_pc_valign_middle">&nbsp;&nbsp;</span></label>
					<div id="basic_categories">
						<div class="arf_pc_clear_both">
							<?php
								$default_val = isset( $values['category_single'][0] ) ? $values['category_single'][0] : '';
								$arf_postcreator->arf_postcreator_custom_category_fields( $values['form_id'], 'arf_postcreator_category_single[]', 'frm-dropdown arf_postcreator_user_filled_fields', $default_val, 'arf_postcreator_user_filled_categories', $field_array );
							?>
							<label class="lblsubtitle arf_pc_from_category_label"> <?php echo sprintf( esc_html__( 'From %s Categories %s', 'ARForms-postcreator' ), '<b>', '</b>' ); ?> </label>
						</div>
						<div class="arf_pc_from_category_separator">
							<label class="arfpost_orclass"><?php echo esc_html__( 'OR', 'ARForms-postcreator' ); ?></label>
						</div>

						<label class="lblsubtitle arf_pc_category_manual"><?php esc_html_e( 'Select Categories Manually', 'ARForms-postcreator' ); ?>&nbsp;&nbsp;<span class="arfglobalrequiredfield arf_pc_valign_middle">&nbsp;&nbsp;</span></label>
						<div class="arf_pc_category_field_wrapper">
						<?php foreach ( $categories as $key => $cat ) { ?>
							<div class="frm_catlevel_<?php echo esc_html( $level ); ?>"><?php $this->arf_show_category( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $values ); ?></div>
						<?php } ?>
						</div>
						<div class="arferrmessage" id="arf_postcreator_category_msg"><?php esc_html_e( 'Please Select at least one category.', 'ARForms-postcreator' ); ?></div>
					</div>
				</div>
			</td>
		</tr>
		<?php
	}

	public function arf_postcreator_get_custom_categories( $cat = array() ) {
		global $arf_postcreator, $arffield;
		if ( is_array( $cat ) ) {
			if ( $cat['custom_post'] == '' ) {
				$var     = $_POST['query_var'];
				$form_id = $_POST['form_id'];
				if ( $var == 'basic' ) {
					$arf_postcreator->basic_categories( array( 'form_id' => $form_id ) );
					die();
				}
			} else {
				$var     = $_REQUEST['query_var'];
				$form_id = $_REQUEST['form_id'];
			}
		} else {
			$var     = $_REQUEST['query_var'];
			$form_id = $_REQUEST['form_id'];
			if ( $var == 'basic' ) {
				$arf_postcreator->basic_categories( array( 'form_id' => $form_id ) );
				die();
			}
		}
		$field_array = $arffield->getAll( 'fi.form_id=' . (int) $form_id, 'fi.id' );

		$custom_cats = get_object_taxonomies( $var );
		$args        = array( 'hide_empty' => 0 );
		if ( count( $custom_cats ) != 0 && count( $custom_cats ) > 0 ) {
			?>
			<tr class="tdclass">
				<td valign="top" colspan="2" class="lbltitle arf_pc_category_label"><?php esc_html_e( 'Post Categories', 'ARForms-postcreator' ); ?></td>
			</tr>
			<?php
			$i = 0;
			foreach ( $custom_cats as $custom_cat ) {
				$categories    = get_terms( $custom_cat, $args );
				$taxonomy_data = get_taxonomy( $custom_cat );
				?>
				<tr class="tdclass" >
					<td width="18%" id="tdclass_<?php echo esc_html( $i ); ?>" valign="top" class="tdclass" colspan="2">
						<div class="arf_pc_category_data_wrapper" class="inner_white_category <?php echo ( ( count( $custom_cats ) - 1 ) == $i ) ? 'inner_white_category_last' : ''; ?>">
							<label class="lblsubtitle arf_pc_category_user_label">
								<?php esc_html_e( 'Let user can select', 'ARForms-postcreator' ); ?> <?php echo esc_html( $taxonomy_data->labels->menu_name ); ?>&nbsp;&nbsp;<span class="arfglobalrequiredfield arf_pc_valign_middle">&nbsp;&nbsp;</span></label>
							<input type="hidden" name="custom_query_var[]" title="title" value="<?php echo esc_html( $taxonomy_data->query_var ); ?>" />
							<input type="hidden" name="custom_query_var_flag" id="custom_query_var_flag" title="title" value="" />
							<?php
							if ( count( $categories ) > 0 ) {
								?>
								<div id="categories_<?php echo esc_html( $i ); ?>" class="arf_pc_cc_wrapper">
									<div class="sltstandard">
									<?php 
										$default_val = isset($values['category_single'][0]) ? $values['category_single'][0] : '';
										$arf_postcreator->arf_postcreator_custom_category_fields( $form_id, 'arf_postcreator_category_single[' . $taxonomy_data->query_var . '][]', 'frm-dropdown arf_postcreator_user_filled_fields', $default_val , 'arf_postcreator_user_filled_categories', $field_array ); ?>
									<label class="lblsubtitle arf_pc_cc_from_label"> <?php echo esc_html__( 'From', 'ARForms-postcreator' ); ?> <b><?php echo esc_html( $taxonomy_data->labels->menu_name ); ?></b> </label>
									</div>
									<div class="arf_pc_cc_or_wrapper">
										<label class="arfpost_orclass"><?php echo esc_html__( 'OR', 'ARForms-postcreator' ); ?></label>
									</div>
									<label class="lblsubtitle arf_pc_cc_select_label">
										<?php esc_html_e( 'Select', 'ARForms-postcreator' ); ?> <?php echo esc_html( $taxonomy_data->labels->menu_name ); ?><?php esc_html_e( ' Manually', 'ARForms-postcreator' ); ?>&nbsp;&nbsp;<span class="arfglobalrequiredfield arf_pc_valign_middle">&nbsp;&nbsp;</span></label>
								   <?php
										$arf_postcreator->get_child_checkboxes_backend( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $cat, $var, $taxonomy_data->name );
									?>
								</div>
									<?php
							} else {
								echo "<label class='lblsubtitle arf_pc_nc_label'><b>" . esc_html__( 'No Category Found', 'ARForms-postcreator' ) . '</b></label>';
							}
							?>
				</div>
				</td>
				</tr>
				<?php
				$i++;
			}
		}
		die();
	}
	public function categories( $cat = array() ) {
		global $arf_postcreator;
		if ( $cat['post_type'] == 'basic' ) {
			$this->basic_categories( $cat );
		} elseif ( $cat['post_type'] == '' ) {
			echo '';
		} else {
			$this->arf_postcreator_get_custom_category_list( $cat );
		}
	}

	public function arf_postcreator_get_custom_category_list( $cat = array() ) {
		$var         = $cat['custom_post'];
		$custom_cats = get_object_taxonomies( $var );
		$args        = array( 'hide_empty' => 0 );
		$form_id     = $cat['form_id'];

		global $arffield, $arf_postcreator;

		if( !empty($form_id)){
			$field_array = $arffield->getAll( 'fi.form_id=' . (int) $form_id, 'fi.id' );
		}

		if ( count( $custom_cats ) != 0 && count( $custom_cats ) > 0 ) {
			?>
			<tr class="tdclass">
				<td valign="top" colspan="2" class="lbltitle arf_pc_category_label"><?php esc_html_e( 'Post Categories', 'ARForms-postcreator' ); ?></td>
			</tr>
			<?php
			$i = 0;
			foreach ( $custom_cats as $custom_cat ) {
				$categories    = get_terms( $custom_cat, $args );
				$taxonomy_data = get_taxonomy( $custom_cat );
				?>
				<tr class="tdclass">
					<td valign="top" class="tdclass arf_pc_width_18per" colspan="2">
						<div class="rounded_corner inner_white_category <?php echo ( ( count( $custom_cats ) - 1 ) == $i ) ? 'inner_white_category_last' : ''; ?>">

							<label class="lblsubtitle arf_pc_category_user_label"><?php esc_html_e( 'Let user can select', 'ARForms-postcreator' ); ?> <?php echo esc_html( $taxonomy_data->labels->menu_name ); ?>&nbsp;&nbsp;<span class="arfglobalrequiredfield arf_pc_valign_middle">&nbsp;&nbsp;</span></label>

							<input type="hidden" name="custom_query_var[]" value="<?php echo esc_html( $taxonomy_data->name ); ?>" />
							<?php
							if ( count( $categories ) > 0 ) {
								$cat_category_single_custom_cat = '';
								if ( isset( $cat['category_single'][ $custom_cat ][0] ) ) {
									$cat_category_single_custom_cat = $cat['category_single'][ $custom_cat ][0];
								}
								?>
								<div id="categories_<?php echo esc_html( $i ); ?>" class="arf_pc_cc_wrapper">
									<div class="sltstandard">
										<?php $this->arf_postcreator_custom_category_fields( $form_id, 'arf_postcreator_category_single[' . $taxonomy_data->name . '][]', 'frm-dropdown arf_postcreator_user_filled_fields', $cat_category_single_custom_cat, 'arf_postcreator_user_filled_categories' . $taxonomy_data->query_var, $field_array ); ?>
										<label class="lblsubtitle arf_pc_cc_from_label"> <?php echo esc_html__( 'From', 'ARForms-postcreator' ); ?> <b><?php echo esc_html($taxonomy_data->labels->menu_name ); ?></b> </label>
									</div>
									<div class="arf_pc_cc_or_wrapper">
										<label class="arfpost_orclass"><?php echo esc_html__( 'OR', 'ARForms-postcreator' ); ?></label>
									</div>

									<label class="lblsubtitle arf_pc_cc_select_label"><?php esc_html_e( 'Select', 'ARForms-postcreator' ) . ' '; ?> <?php echo esc_html( $taxonomy_data->labels->menu_name ); ?><?php esc_html_e( ' Manually', 'ARForms-postcreator' ); ?> &nbsp;&nbsp;<span class="arfglobalrequiredfield arf_pc_valign_middle">&nbsp;&nbsp;</span></label>
									<?php 
									$this->get_child_checkboxes_backend( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $cat, $var, $taxonomy_data->name ); ?>
								</div>

								<?php

							} else {
								echo "<label class='arf_pc_nc_label'><b>" . esc_html__( 'No Category Found', 'ARForms-postcreator' ) . '</b></label>';
							}
							?>
						</div>
					</td>
				</tr>
								<?php
								$i++;
			}
		}
	}

	public function arf_postcreator_custom_category_fields( $form_id, $name , $class , $default_value , $id , $field_array ) {

		global $arffield, $MdlDb, $armainhelper, $maincontroller;

		$field_list = array();
		$field_list = $field_array;
		$include    = array( 'radio', 'checkbox', 'select', 'arf_autocomplete', 'arf_multiselect' );

		$selected_list_id      = '';
		$selected_list_label   = esc_html__( 'Select Field', 'ARForms-postcreator' );
		$responder_list_option_arr = array(
                                '' => addslashes(esc_html__("Select Field", "ARForms-postcreator"))
                            );
		$responder_list_option = '';
		if ( count( $field_list ) > 0 ) {
			$cntr = 0;
			foreach ( $field_list as $field ) {
				if( isset($field->field_options['parent_field_type']) && 'arf_repeater' == $field->field_options['parent_field_type']){
	               		continue;
	            }
				if ( in_array( $field->type, $include ) ) {
					if ( $default_value == $field->id ) {
						$selected_list_id    = $field->id;
						$selected_list_label = $field->name;
					}
					$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $field->id . '" data-label="' . $field->name . '">' . $armainhelper->truncate( $field->name, 33 ) . '</li>';
					$responder_list_option_arr[$field->id] = $field->name;
				}
				$cntr++;
			}
		}
		$input_id = ( '' == $id ) ? $name : $id;
		?>
			<div class="sltstandard" id="sltstandard">
			<?php
				if( method_exists( $maincontroller, 'arf_selectpicker_dom') ){
					$select_attrs = array(
						'onchange'	=>	'is_category_selected(this.value, jQuery(this).parent().parent().parent().parent().attr("id"))'
					);
					echo $maincontroller->arf_selectpicker_dom( $name, $input_id, ' arf_pc_cc_field_dd ', '', $selected_list_id, $select_attrs, $responder_list_option_arr,  false, array(), false, array(), false,  array(), false, $class );
				} else { ?>
				<input id="<?php echo esc_html( $input_id ); ?>" name="<?php echo esc_html( $name ); ?>" value="<?php echo esc_html( $selected_list_id ); ?>" type="hidden"  onchange="is_category_selected(this.value, jQuery(this).parent().parent().parent().attr('id'));" />
				<dl class="arf_selectbox arf_pc_cc_field_dd" data-name="<?php echo esc_html( $name ); ?>" data-id="<?php echo esc_html( $input_id ); ?>">
					<dt>
						<span><?php echo $selected_list_label; ?></span>
						<input value="<?php echo esc_html( $selected_list_id ); ?>" class="arf_autocomplete" type="text" autocomplete="off" />
						<svg viewBox="0 0 2000 1000" width="15px" height="15px">
							<g fill="#000">
								<path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
							</g>
						</svg>
					</dt>
					<dd>
						<ul data-id="<?php echo esc_html( $input_id ); ?>" class="<?php echo esc_attr( $class ); ?>">
							<li class="arf_selectbox_option" data-value="" data-label="<?php echo esc_html__( 'Select Field', 'ARForms-postcreator' ); ?>"><?php echo esc_html__( 'Select Field', 'ARForms-postcreator' ); ?></li>
							<?php echo $responder_list_option; ?>
						</ul>
					</dd>
				</dl>
			<?php } ?>
			</div>
		<?php
	}

	public function arf_postcreator_user_fill_fields() {
		global $arffield, $MdlDb;

		$form_id = $_REQUEST['form_id'];

		$field_list = array();

		if ( is_numeric( $form_id ) ) {

			$include = "'radio','checkbox','select', 'arf_multiselect'";

			$field_list = $arffield->getAll( 'fi.type in (' . $include . ') and fi.form_id=' . (int) $form_id, 'fi.id' );
		}
		?>
		<li class="arf_selectbox_option" data-value="" data-label=""><?php echo esc_html__( 'Please select field', 'ARForms-postcreator' ); ?></li>
		<?php
		if ( count( $field_list ) > 0 ) {
			foreach ( $field_list as $field ) {
				?>
				<li class="arf_selectbox_option" data-value="<?php echo esc_html( $field->id ); ?>" data-label="<?php echo $field->name; ?>"><?php echo armainhelper::truncate( $field->name, 33 ); ?></li>
				<?php
			}
		}
		die();
	}

	public function arf_postcreator_get_custom_categories_new() {
		global $arf_postcreator, $arfrecordmeta;
		$form_id = $_REQUEST['form_id'];
		$var = $_REQUEST['query_var'];

		if ( $var != '' ) {
			if ( $var == 'basic' ) {
				$arf_postcreator->basic_categories( array( 'form_id' => $form_id ) );
				die();
			} else {
				$custom_cats = get_object_taxonomies( $var );
				
				$args        = array( 'hide_empty' => 0 );
				if ( count( $custom_cats ) != 0 && count( $custom_cats ) > 0 ) {
					?>
					<tr class="tdclass">
						<td valign="top" colspan="2" class="lbltitle arf_pc_category_label"><?php esc_html_e( 'Post Categories', 'ARForms-postcreator' ); ?></td>
					</tr>
					<?php
					global $arffield;
					$field_array = $arffield->getAll( 'fi.form_id=' . (int) $form_id, 'fi.id' );

					$i = 0;
					foreach ( $custom_cats as $custom_cat ) {
						$categories    = get_terms( $custom_cat, $args );
						$taxonomy_data = get_taxonomy( $custom_cat );
						
						?>
						<tr class="tdclass">
							<td valign="top" class="tdclass arf_pc_width_18per" colspan="2">
								<div class="arf_pc_cc_field_user_label">
									<label class="lblsubtitle arf_pc_category_user_label">
										<?php esc_html_e( 'Let user can select', 'ARForms-postcreator' ); ?> <?php echo esc_html( $taxonomy_data->labels->menu_name ); ?>&nbsp;&nbsp;
										<span class="arfglobalrequiredfield arf_pc_valign_middle">&nbsp;&nbsp;</span>
									</label>
									<?php
									if ( count( $categories ) > 0 ) {
										?>
											<div id="categories_<?php echo esc_html( $i ); ?>" class="arf_pc_cc_wrapper">
												<div class="sltstandard">
												<?php 
												$default_val = isset($values['category_single'][0]) ? $values['category_single'][0] : '';
												$arf_postcreator->arf_postcreator_custom_category_fields( $form_id, 'arf_postcreator_category_single[' . $taxonomy_data->query_var . '][]', 'frm-dropdown arf_postcreator_user_filled_fields', $default_val , 'arf_postcreator_user_filled_categories', $field_array ); ?>
													<label class="lblsubtitle arf_pc_cc_from_label"> <?php echo esc_html__( 'From', 'ARForms-postcreator' ); ?> <b><?php echo esc_html( $taxonomy_data->labels->menu_name ); ?></b> </label>
												</div>
												<div class="arf_pc_cc_or_wrapper">
													<label class="arfpost_orclass"><?php echo esc_html__( 'OR', 'ARForms-postcreator' ); ?></label>
												</div>

												<label class="lblsubtitle arf_pc_cc_select_label"><?php esc_html_e( 'Select', 'ARForms-postcreator' ) . ' '; ?><?php echo esc_html( $taxonomy_data->labels->menu_name ); ?><?php esc_html_e( '  Manually', 'ARForms-postcreator' ); ?>&nbsp;&nbsp;<span class="arfglobalrequiredfield arf_pc_valign_middle">&nbsp;&nbsp;</span></label>
											<?php
												$arf_postcreator->get_child_checkboxes_backend( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $cat, $var, $taxonomy_data->name );
											?>
											</div>
										<?php
									} else {
										echo "<label class='lblsubtitle arf_pc_nc_label'><b>" . esc_html__( 'No Category Found', 'ARForms-postcreator' ) . '</b></label>';
									}
									?>
								</div>
							</td>
						</tr>
						<?php
						$i++;
					}
				}
			}
		}
		die();
	}

	public function arf_show_category( $atts, $field, $values = array() ) {
		extract( $atts );
		$disabled = '';
		if ( isset( $values['category_single'][0] ) && $values['category_single'][0] != '' ) {
			$disabled = "disabled='disabled'";
		} else {
			$disabled = '';
		}

		if ( ! is_object( $cat ) ) {
			return;
		}
		$checked = '';
		if ( is_array( $value ) ) {
			$checked = ( in_array( $cat->cat_ID, $value ) ) ? 'checked="checked" ' : '';
		} elseif ( $cat->cat_ID == $value ) {
			$checked = 'checked="checked" ';
		} else {
			$checked = '';
		}
		$class = '';

		$sanitized_name = ( ( isset( $field['id'] ) ) ? $field['id'] : $field['field_options']['taxonomy'] ) . '-' . $cat->cat_ID;

		if ( $field['type'] == 'checkbox' ) {
			?>
			<div class="checkbox_style" id="frm_checkbox_<?php echo esc_html( $sanitized_name ); ?>">
			<?php
		} else {
			?>
			<div class="radiobutton">
			<?php
		}

		$checked_opts = '';

		if ( isset( $values['categories'] ) && is_array( $values['categories'] ) && count( $values['categories'] ) > 1 ) {
			foreach ( $values['categories'] as $cats ) {
				$checked_opts = checked( $cats, $cat->name, false );
			}
		}

		if ( ( isset( $values['categories'] ) && is_array( $values['categories'] ) && count( $values['categories'] ) > 0 ) && ( isset( $category ) && count( $category ) ) > 0 ) {
			$checked_opts = checked( ( isset( $values['categories'][0] ) ? $values['categories'][0] : '' ), $category->term_id, false );
		}

		if ( isset( $values['categories'] ) && is_array( $values['categories'] ) ) {
			foreach ( $values['categories'] as $cats ) {
				$checked_opts = checked( $cat->cat_ID, $cats, false );
			}
		}

		$checked_atts = '';

		if ( isset( $k ) && $k == 0 ) {
			if ( isset( $field['required'] ) and $field['required'] ) {
				$checked_atts .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
			}
		}

		global $arfieldhelper;
		$checked_atts .= ' ' . $arfieldhelper->get_onchage_func( $field ) . ' ';

		?>

			<label for="field_<?php echo esc_html( $sanitized_name ); ?>">
				<div class="arf_custom_checkbox_div">
					<div class="arf_custom_checkbox_wrapper">
						<input type="checkbox" <?php echo esc_html( $checked_opts ); ?> name="arf_postcreator_category[]" id="field_<?php echo esc_html( $sanitized_name ); ?>" value="<?php echo esc_html( $cat->cat_ID ); ?>"  <?php do_action( 'arffieldinputhtml', $field ); echo esc_attr( $checked_atts ); ?> class="" <?php echo esc_attr( $disabled ); ?> />
						<svg width="18px" height="18px">
							<?php echo ARF_CUSTOM_UNCHECKED_ICON; ?>
							<?php echo ARF_CUSTOM_CHECKED_ICON; ?>
						</svg>
					</div>
				</div>
				<label for="field_<?php echo esc_html( $sanitized_name ); ?>" title="arf_postcreator_category" >
					<?php echo isset( $category->name ) ? $category->name : ''; ?>
				</label>
				<?php echo isset( $cat->cat_name ) ? $cat->cat_name : ''; ?>
			</label>
			<?php
			$children = get_categories(
				array(
					'type'       => $post_type,
					'orderby'    => 'name',
					'order'      => 'ASC',
					'hide_empty' => false,
					'exclude'    => $exclude,
					'parent'     => $cat->cat_ID,
					'taxonomy'   => $taxonomy,
				)
			);
			if ( $children ) {
				$level++;
				foreach ( $children as $key => $cat ) {
					?>
					<div class="frm_catlevel_<?php echo esc_html( $level ); ?>"><?php $this->arf_show_category( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $values ); ?></div>
					<?php
				}
			}
			echo '</div>';
	}

	public function arf_show_category_custom_post( $atts, $field, $taxonomy ) {
		global $arfieldhelper, $arf_postcreator;
		$k      = 0;
		$values = $field;
		extract( $atts );
		if ( ! is_object( $cat ) ) {
			return;
		}
		$checked = '';
		if ( is_array( $value ) ) {
			$checked = ( in_array( $cat->cat_ID, $value ) ) ? 'checked="checked" ' : '';
		} elseif ( $cat->cat_ID == $value ) {
			$checked = 'checked="checked" ';
		} else {
			$checked = '';
		}
		$class    = '';
		$disabled = '';
		if ( isset( $values['category_single'] ) && is_array( $values['category_single'] ) ) {
			if ( isset($values['category_single'][ $taxonomy ][0]) && $values['category_single'][ $taxonomy ][0] != 0 ) {
				$disabled = "disabled='disable'";
			} else {
				$disabled = '';
			}
		}
		$sanitized_name = ( ( isset( $field['id'] ) ) ? $field['id'] : $field['field_options']['taxonomy'] ) . '-' . $cat->cat_ID;

		if ( $field['type'] == 'checkbox' ) {
			?>
			 <div class="checkbox_style" id="frm_checkbox_<?php echo esc_html( $sanitized_name ); ?>">
			<?php
		} else {
			?>
			<div class="radiobutton">
			<?php
		}
		?>
			<label for="field_<?php echo esc_html( $sanitized_name ); ?>">
				<div class="arf_custom_checkbox_div">
					<div class="arf_custom_checkbox_wrapper">
					<?php
						$checked_opt = '';
					
						$categories_array = (!empty($values['categories'][ $taxonomy ])) ? $values['categories'][ $taxonomy ] : array() ;
					?>
					<input type="checkbox" name="arf_postcreator_category[<?php echo esc_html( $taxonomy ); ?>][]" class="" <?php echo (is_array($categories_array) && (in_array($cat->cat_ID, $categories_array))) ? 'checked' : '' ; ?> id="field_<?php echo esc_html( $sanitized_name ); ?>" value="<?php echo esc_html( $cat->cat_ID ); ?>" <?php do_action( 'arffieldinputhtml', $field ); ?> <?php
					if ( $k == 0 ) {
						if ( isset( $field['required'] ) and $field['required'] ) {
							echo 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"'; }
					}
					?>
					 <?php echo $arfieldhelper->get_onchage_func( $field ); ?> <?php echo $disabled; ?> />
						<svg width="18px" height="18px">
							<?php echo ARF_CUSTOM_UNCHECKED_ICON; ?>
							<?php echo ARF_CUSTOM_CHECKED_ICON; ?>
						</svg>
					</div>
				</div>

				<label for="field_<?php echo esc_html( $sanitized_name ); ?>" title="arf_postcreator_category" ></label><?php echo esc_html( $cat->cat_name ); ?>
			</label>

			<?php
			$children = get_categories(
				array(
					'type'       => $post_type,
					'orderby'    => 'name',
					'order'      => 'ASC',
					'hide_empty' => false,
					'exclude'    => $exclude,
					'parent'     => $cat->cat_ID,
					'taxonomy'   => $taxonomy,
				)
			);
			if ( $children ) {
				$level++;
				foreach ( $children as $key => $cat ) {
					?>
					<div class="frm_catlevel_<?php echo esc_html( $level ); ?>"><?php $arf_postcreator->arf_show_category_custom_post( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $values, $taxonomy ); ?></div>
					<?php
				}
			}
			echo '</div>';
	}

	public function arf_retrieve_category_select( $atts, $field, $select_field_opts, &$opts_cls_arr, &$options_attrs ){
		global $arf_postcreator;
		extract( $atts );
		$args = array(
			'orderby'    => 'name',
			'order'      => 'ASC',
			'hide_empty' => false,
			'parent'     => $cat->cat_ID,
			'exclude'    => $exclude,
			'type'       => $post_type,
			'taxonomy'   => $taxonomy,
		);

		if( !is_object( $cat ) ){
			return $select_field_opts;
		}

		$sanitized_name = ( ( isset( $field['id'] ) ) ? $field['id'] : $field['field_options']['taxonomy'] ) . '-' . $cat->cat_ID;
		$select_field_opts[ $cat->cat_name ] = $cat->cat_name;
		$opts_cls_arr[ $cat->cat_name ] = 'frm_catlevel_' . $level;

		if( $level > 1 ){
			$def_padding = 20;
			if( $level > 2 ){
				$current_padding = ( $def_padding * (int) $level );
			} else {
				$current_padding = 40;
			}
			$options_attrs['style'][$cat->cat_name] = 'padding-left:' . $current_padding .'px;';
		}

		$children = get_categories(
			array(
				'type'       => $post_type,
				'orderby'    => 'name',
				'order'      => 'ASC',
				'hide_empty' => false,
				'exclude'    => $exclude,
				'parent'     => $cat->cat_ID,
				'taxonomy'   => $taxonomy,
			)
		);

		if ( !empty( $children ) ) {
			$level++;
			foreach ( $children as $key => $cat ) {
				$attrs = compact( 'cat', 'field', 'field_id', 'field_name', 'exclude', 'value', 'level', 'onchange', 'post_type', 'taxonomy' );
				
				$select_field_opts = $this->arf_retrieve_category_select( $attrs, $field, $select_field_opts, $opts_cls_arr, $options_attrs );
			}
		}

		return $select_field_opts;
	}

	public function arf_show_category_select( $atts, $field ) {
		global $arf_postcreator;
		$return_string = '';
		extract( $atts );
		$args = array(
			'orderby'    => 'name',
			'order'      => 'ASC',
			'hide_empty' => false,
			'parent'     => $cat->cat_ID,
			'exclude'    => $exclude,
			'type'       => $post_type,
			'taxonomy'   => $taxonomy,
		);

		if ( ! is_object( $cat ) ) {
			return;
		}
		$selected = '';

		if ( is_array( $value ) ) {
			$selected = ( in_array( $cat->cat_ID, $value ) ) ? 'selected="selected" ' : '';
		} elseif ( $cat->cat_ID == $value ) {
			$selected = 'selected="selected" ';
		} else {
			$selected = '';
		}

		$class = '';

		$sanitized_name = ( ( isset( $field['id'] ) ) ? $field['id'] : $field['field_options']['taxonomy'] ) . '-' . $cat->cat_ID;
		$return_string .= '<option class="frm_catlevel_' . $level . '" value="' . $cat->cat_name . '" ' . $selected . ' data-content="' . esc_attr( $cat->cat_name ) . '">' . $cat->cat_name . '</option>';
		$children       = get_categories(
			array(
				'type'       => $post_type,
				'orderby'    => 'name',
				'order'      => 'ASC',
				'hide_empty' => false,
				'exclude'    => $exclude,
				'parent'     => $cat->cat_ID,
				'taxonomy'   => $taxonomy,
			)
		);

		if ( $children ) {
			$level++;
			foreach ( $children as $key => $cat ) {
				?>
				<?php $return_string .= $arf_postcreator->arf_show_category_select( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field ); ?>
								<?php
			}
		}
		
		return $return_string;
	}

	public function arf_show_category_select_custom_post( $atts, $field, $taxonomy = '', $post_type = '' ) {
		$return_string = '';
		extract( $atts );

		$args = array(
			'orderby'    => 'name',
			'order'      => 'ASC',
			'hide_empty' => false,
			'parent'     => $cat->cat_ID,
			'exclude'    => $exclude,
			'type'       => $post_type,
			'taxonomy'   => $taxonomy,
		);

		if ( ! is_object( $cat ) ) {
			return;
		}
		$selected = '';

		if ( is_array( $value ) ) {
			$selected = ( in_array( $cat->cat_ID, $value ) ) ? 'selected="selected" ' : '';
		} elseif ( $cat->cat_ID == $value ) {
			$selected = 'selected="selected" ';
		} else {
			$selected = '';
		}

		$class = '';

		$sanitized_name = ( ( isset( $field['id'] ) ) ? $field['id'] : $field['field_options']['taxonomy'] ) . '-' . $cat->cat_ID;

		$return_string .= '<option class="frm_catlevel_' . $level . '" value="' . $cat->cat_name . '" >'
		. $cat->cat_name . '</option>';
		$children       = get_categories( $args );
		if ( $children ) {
			$level++;
			foreach ( $children as $key => $cat ) {
				$return_string .= $this->arf_show_category_select_custom_post( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $taxonomy, $post_type )
				?>
								<?php
			}
		}
		return $return_string;
	}

	public static function get_child_checkboxes( $args, $field, $post_type, $taxonomy, $mapped_field_id, $arf_on_change_function ) {
		global $arf_postcreator;
		$return_string = '';
		$defaults      = array(
			'field'      => 0,
			'field_name' => false,
			'opt_key'    => 0,
			'opt'        => '',
			'type'       => $field['type'],
			'value'      => false,
			'exclude'    => 0,
			'hide_id'    => false,
		);
		extract( wp_parse_args( $args, $defaults ) );

		if ( ! $field_name ) {
			$field_name = "item_meta[$field[id]]";
		}
		if ( $field['type'] == 'checkbox' || $field['type'] == 'arf_multiselect' ) {
			$onchange    = '';
		} else {
			$onchange = '';
		}

		$args = array(
			'orderby'    => 'name',
			'order'      => 'ASC',
			'hide_empty' => false,
			'parent'     => 0,
			'exclude'    => 'all',
			'type'       => $post_type,
			'taxonomy'   => $taxonomy,
		);

		$children = get_categories( $args );

		$level = ( $opt_key ) ? 2 : 1;
		if ( $field['id'] == $mapped_field_id ) {
			foreach ( $children as $key => $cat ) {
				$return_string .= '<div class="frm_catlevel_' . $level . '">';
				$return_string .= $arf_postcreator->_show_category( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $arf_on_change_function, $key );
				$return_string .= '</div>';
			}
		}
		return $return_string;
	}

	public static function get_child_checkboxes_backend( $args, $field, $post_type, $taxonomy ) {
		global $arf_postcreator;
		$values   = $field;
		$defaults = array(
			'field'      => 0,
			'field_name' => false,
			'opt_key'    => 0,
			'opt'        => '',
			'type'       => $post_type,
			'value'      => false,
			'exclude'    => 0,
			'hide_id'    => false,
		);
		extract( wp_parse_args( $args, $defaults ) );

		if ( ! isset( $field_name ) ) {
			$field_name = "item_meta[$field[id]]";
		}
		$onchange = '';

		$args = array(
			'orderby'    => 'name',
			'order'      => 'ASC',
			'hide_empty' => false,
			'parent'     => 0,
			'exclude'    => 'all',
			'type'       => $post_type,
			'taxonomy'   => $taxonomy,
		);

		$children = get_categories( $args );

		$level = ( $opt_key ) ? 2 : 1;
		foreach ( $children as $key => $cat ) {
			?>
			<div class="frm_catlevel_<?php echo esc_html( $level ); ?>"><?php $arf_postcreator->arf_show_category_custom_post( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $values, $taxonomy ); ?></div>
			<?php
		}
	}

	public static function get_custom_taxonomy( $post_type, $field ) {
		$taxonomies = get_object_taxonomies( $post_type );
		if ( ! $taxonomies ) {
			return false;
		} else {
			$field = (array) $field;
			if ( ! isset( $field['taxonomy'] ) ) {
				$field['field_options'] = maybe_unserialize( $field['field_options'] );
				$field['taxonomy']      = $field['field_options']['taxonomy'];
			}

			if ( isset( $field['taxonomy'] ) and in_array( $field['taxonomy'], $taxonomies ) ) {
				return $field['taxonomy'];
			} elseif ( $post_type == 'post' ) {
				return 'category';
			} else {
				return reset( $taxonomies );
			}
		}
	}

	public static function _show_category( $atts, $arf_on_change_function, $key ) {
		global $arfieldcontroller, $arfieldhelper, $arf_postcreator;
		$return_string = '';
		extract( $atts );
		if ( ! is_object( $cat ) ) {
			return;
		}

		$checked = '';
		if ( is_array( $value ) ) {
			$checked = ( in_array( $cat->cat_ID, $value ) ) ? 'checked="checked" ' : '';
		} elseif ( $cat->cat_ID == $value ) {
			$checked = 'checked="checked" ';
		} else {
			$checked = '';
		}
		$class = '';

		$sanitized_name = ( ( isset( $field['id'] ) ) ? $field['id'] : $field['field_options']['taxonomy'] ) . '-' . $cat->cat_ID;
		$field_tooltip  = '';
		if ( isset( $field['tooltip_text'] ) and $field['tooltip_text'] != '' ) {
			$field_tooltip = $arfieldhelper->arf_tooltip_display( $field['tooltip_text'] );
		}
		$inline_css_with_style_tag = '';
		$inline_css_without_style  = '';
		$arf_input_field_html      = '';
		$arf_input_field_html     .= $arfieldcontroller->input_fieldhtml( $field, false );
		$arf_input_field_html     .= $arfieldcontroller->input_html( $field, false );
		if ( $type == 'checkbox' ) {
			$return_string        .= '<div class="arf_checkbox_style frm_' . $type . '" id="frm_checkbox_' . $field['id'] . '">';
			$_REQUEST['arfaction'] = ( isset( $_REQUEST['arfaction'] ) ) ? $_REQUEST['arfaction'] : '';
			$return_string        .= "<div class='arf_checkbox_input_wrapper'>";
			$return_string        .= '<input type="checkbox" name="' . $field_name . '[]" id="field_' . $sanitized_name . '" value="' . esc_attr( $cat->cat_name ) . '"';

			$return_string .= $arf_input_field_html;
			if ( $key == 0 ) {
				if ( isset( $field['required'] ) and $field['required'] ) {
					$return_string .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
				}
			}

			if ( isset( $_REQUEST['arfaction'] ) && $_REQUEST['arfaction'] == 'preview' ) {
				$return_string .= $arf_on_change_function;
			}

			$return_string .= " {$arf_on_change_function} />";
			$return_string .= '<span>';
			/*if ( $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arfcheckradiostyle'] == 'custom' ) {
				$custom_checkbox = $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arf_checked_checkbox_icon'];
				$return_string  .= "<i class='arfa {$custom_checkbox}'></i>";
			}*/
			$return_string .= '</span>';
			$return_string .= '</div>';
			$return_string .= '<label for="field_' . $sanitized_name . '" >';
			$return_string .= $cat->cat_name;

			$return_string .= '</label>';

			$return_string .= '</div>';
		}

		if ( $type == 'radio' ) {
			$return_string        .= '<div class="arf_radiobutton">';
			$_REQUEST['arfaction'] = ( isset( $_REQUEST['arfaction'] ) ) ? $_REQUEST['arfaction'] : '';
			$return_string        .= "<div class='arf_radio_input_wrapper'>";
			$return_string        .= '<input type="radio" name="' . $field_name . '[]" id="field_' . $sanitized_name . '" value="' . esc_attr( $cat->cat_name ) . '"';

			$return_string .= $arf_input_field_html;
			if ( $key == 0 ) {
				if ( isset( $field['required'] ) and $field['required'] ) {
					$return_string .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
				}
			}

			if ( isset( $_REQUEST['arfaction'] ) && $_REQUEST['arfaction'] == 'preview' ) {
				$return_string .= $arf_on_change_function;
			}

			$return_string .= " {$arf_on_change_function} />";
			$return_string .= '<span>';
			/*if ( $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arfcheckradiostyle'] == 'custom' ) {
				$custom_radio   = $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arf_checked_radio_icon'];
				$return_string .= "<i class='arfa {$custom_radio}'></i>";
			}*/
			$return_string .= '</span>';
			$return_string .= '</div>';
			$return_string .= '<label for="field_' . $sanitized_name . '" >';
			$return_string .= $cat->cat_name;

			$return_string .= '</label>';

			$return_string .= '</div>';
		}
		$children = get_categories(
			array(
				'type'       => $post_type,
				'orderby'    => 'name',
				'order'      => 'ASC',
				'hide_empty' => false,
				'exclude'    => $exclude,
				'parent'     => $cat->cat_ID,
				'taxonomy'   => $taxonomy,
			)
		);
		if ( $children ) {
			$level++;
			foreach ( $children as $key => $cat ) {
				$return_string .= '<div class="frm_catlevel_' . $level . '">';
				$return_string .= $arf_postcreator->_show_category( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $arf_on_change_function, $key );
				$return_string .= '</div>';
			}
		}
		return $return_string;

	}

	public function arf_show_category_front( $atts, $field, $key, $arf_on_change_function ) {
		global $arf_postcreator, $arf_data_uniq_id, $arfieldcontroller;
		$return_string = '';
		extract( $atts );

		if ( ! is_object( $cat ) ) {
			return;
		}
		$checked = '';

		$arf_input_field_html  = '';
		$arf_input_field_html .= $arfieldcontroller->input_fieldhtml( $field, false );
		$arf_input_field_html .= $arfieldcontroller->input_html( $field, false );

		$class = '';

		$sanitized_name = ( ( isset( $field['id'] ) ) ? $field['id'] : $field['field_options']['taxonomy'] ) . '-' . $cat->cat_ID;

		if ( $field['type'] == 'checkbox' ) {
			$return_string        .= '<div class="arf_checkbox_style" id="frm_checkbox_' . $field['id'] . '">';
			$_REQUEST['arfaction'] = ( isset( $_REQUEST['arfaction'] ) ) ? $_REQUEST['arfaction'] : '';
			$return_string        .= "<div class='arf_checkbox_input_wrapper'>";
			$return_string        .= '<input type="checkbox" name="' . $field_name . '[]" id="field_' . $sanitized_name . '" value="' . esc_attr( $cat->cat_name ) . '"';

			$return_string .= $arf_input_field_html;
			if ( $key == 0 ) {
				if ( isset( $field['required'] ) and $field['required'] ) {
					$return_string .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
				}
			}

			if ( isset( $_REQUEST['arfaction'] ) && $_REQUEST['arfaction'] == 'preview' ) {
				$return_string .= $arf_on_change_function;
			}

			$return_string .= " {$arf_on_change_function} />";
			$return_string .= '<span>';
			/*if ( $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arfcheckradiostyle'] == 'custom' ) {
				$custom_checkbox = $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arf_checked_checkbox_icon'];
				$return_string  .= "<i class='arfa {$custom_checkbox}'></i>";
			}*/
			$return_string .= '</span>';
			$return_string .= '</div>';
			$return_string .= '<label for="field_' . $sanitized_name . '" >';
			$return_string .= $cat->cat_name;

			$return_string .= '</label>';

			$return_string .= '</div>';
		}

		if ( $field['type'] == 'radio' ) {
			$return_string        .= '<div class="arf_radiobutton">';
			$_REQUEST['arfaction'] = ( isset( $_REQUEST['arfaction'] ) ) ? $_REQUEST['arfaction'] : '';
			$return_string        .= "<div class='arf_radio_input_wrapper'>";
			$return_string        .= '<input type="radio" name="' . $field_name . '[]" id="field_' . $sanitized_name . '" value="' . esc_attr( $cat->cat_name ) . '"';

			$return_string .= $arf_input_field_html;
			if ( $key == 0 ) {
				if ( isset( $field['required'] ) and $field['required'] ) {
					$return_string .= 'data-validation-minchecked-minchecked="1" data-validation-minchecked-message="' . esc_attr( $field['blank'] ) . '"';
				}
			}

			if ( isset( $_REQUEST['arfaction'] ) && $_REQUEST['arfaction'] == 'preview' ) {
				$return_string .= $arf_on_change_function;
			}

			$return_string .= " {$arf_on_change_function} />";
			$return_string .= '<span>';
			/*if ( $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arfcheckradiostyle'] == 'custom' ) {
				$custom_radio   = $GLOBALS['arf_form_data'][ $field['form_id'] ]->form_css['arf_checked_radio_icon'];
				$return_string .= "<i class='arfa {$custom_radio}'></i>";
			}*/
			$return_string .= '</span>';
			$return_string .= '</div>';
			$return_string .= '<label for="field_' . $sanitized_name . '" >';
			$return_string .= $cat->cat_name;

			$return_string .= '</label>';

			$return_string .= '</div>';
		}

		$children = get_categories(
			array(
				'type'       => $post_type,
				'orderby'    => 'name',
				'order'      => 'ASC',
				'hide_empty' => false,
				'exclude'    => 'all',
				'parent'     => $cat->cat_ID,
				'taxonomy'   => $taxonomy,
			)
		);
		if ( $children ) {
			$level++;
			foreach ( $children as $key => $cat ) {
				$return_string .= $arf_postcreator->arf_show_category_front( compact( 'cat', 'field', 'field_name', 'exclude', 'type', 'value', 'exclude', 'level', 'onchange', 'post_type', 'taxonomy', 'hide_id' ), $field, $key, $arf_on_change_function );
			}
		}
		return $return_string;
	}

	public function arf_postcreator_post_format_list( $form_id, $name , $class , $default_value , $id , $selected_field , $field_array ) {
		global $arffield, $MdlDb, $armainhelper, $maincontroller;

		if ( $default_value == '' ) {
			$default_value = 0;
		}

		$select_attrs = array();

		if ( $selected_field == 0 ) {
			$selectfield = $default_value;
			$radiofield  = '';
		} else {
			$selectfield = '';
			$radiofield  = $default_value;
		}

		$disabled = '';
		if ( $selectfield != '' ) {
			$disabled = "disabled='disabled'";
		} else {
			$disabled = '';
		}

		$field_list = array();
		$field_list = $field_array;
		$include    = array( 'radio', 'select' );

		$is_format = '';

		if ( current_theme_supports( 'post-formats' ) ) {
			$post_formats = get_theme_support( 'post-formats' );

			if ( is_array( $post_formats[0] ) ) {

				$post_formats_single = $post_formats[0];
				$is_format           = 1;
			}
		}

		?>
		<div class="arf_pc_clear_both">

			<div class="sltstandard" id="sltstandard">
				<?php
				$selected_list_id      = '';
				$selected_list_label   = esc_html__( 'Select Field', 'ARForms-postcreator' );
				$responder_list_option_arr = array(
                                '' => addslashes(esc_html__("Select Field", "ARForms-postcreator"))
                            );
				$responder_list_option = '';
				if ( count( $field_list ) > 0 ) {
					$cntr = 0;
					foreach ( $field_list as $field ) {
						if( isset($field->field_options['parent_field_type']) && 'arf_repeater' == $field->field_options['parent_field_type']){
		               		continue;
		            	}
						if ( in_array( $field->type, $include ) ) {
							if ( $default_value == $field->id ) {
								$selected_list_id    = $field->id;
								$selected_list_label = $field->name;
							}
							
							$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $field->id . '" data-label="' . $field->name . '">' . $armainhelper->truncate( $field->name, 33 ) . '</li>';
							$responder_list_option_arr[$field->id] = $field->name;
						}
						$cntr++;
					}

				}
				$input_id = ( '' == $id ) ? $name : $id;
				if( method_exists( $maincontroller, 'arf_selectpicker_dom') ){
					$select_attrs = array(
						'onChange'	=>	'is_format_selected(this.value, jQuery(this).parent().parent().parent().parent().attr("id"))'
					);					
					echo $maincontroller->arf_selectpicker_dom( $name, $input_id, ' arf_pc_cc_field_dd ', '', $selected_list_id, $select_attrs, $responder_list_option_arr, false, array(), false, array(), false,  array(), false, $class );
				} else {
				?>
				<input id="<?php echo esc_html( $input_id ); ?>"  name="<?php echo esc_html( $name ); ?>" value="<?php echo esc_html( $selected_list_id ); ?>" type="hidden" onchange="is_format_selected(this.value, jQuery(this).parent().parent().parent().attr('id'));" />
				<dl class="arf_selectbox arf_pc_cc_field_dd" data-name="<?php echo esc_html( $name ); ?>" data-id="<?php echo esc_html( $input_id ); ?>">
					<dt>
						<span><?php echo $selected_list_label; ?></span>
						<input value="<?php echo esc_html( $selected_list_id ); ?>"  class="arf_autocomplete" type="text" autocomplete="off" />
						<svg viewBox="0 0 2000 1000" width="15px" height="15px">
							<g fill="#000">
								<path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
							</g>
						</svg>
					</dt>
					<dd>
						<ul data-id="<?php echo esc_html( $input_id ); ?>" class="<?php echo esc_attr( $class ); ?>">
							<li class="arf_selectbox_option" data-value="" data-label="<?php echo esc_html__( 'Select Field', 'ARForms-postcreator' ); ?>"><?php echo esc_html__( 'Select Field', 'ARForms-postcreator' ); ?></li>
						   <?php echo $responder_list_option; ?>
						</ul>
					</dd>
				</dl>
			<?php } ?>
			</div>
			<label class="lblsubtitle arf_pc_from_category_label"> <?php echo sprintf( esc_html__( 'From %s Formats %s', 'ARForms-postcreator' ), '<b>', '</b>' ); ?> </label>
		</div>


		<div class="arf_pc_from_category_separator">
			<label class="arfpost_orclass"><?php echo esc_html__( 'OR', 'ARForms-postcreator' ); ?></label>
		</div>


		<label class="lblsubtitle arf_pc_cc_select_label">
			<?php esc_html_e( 'Select Format Manually', 'ARForms-postcreator' ); ?>&nbsp;&nbsp;<span class="arfglobalrequiredfield arf_pc_valign_middle">&nbsp;&nbsp;</span>
		</label>

		<div class="sltstandard arf_format_type_wrapper" id="sltstandard">
			<?php
				global $armainhelper, $maincontroller;
				$selected_list_id      = 0;
				$selected_list_label   = esc_html__( 'Standard', 'ARForms-postcreator' );
				$responder_list_option_arr = array(
                                '' => addslashes(esc_html__("Standard", "ARForms-postcreator"))
                            );
				$responder_list_option = "<li class='arf_selectbox_option' data-value=" . esc_html__( 'standard', 'ARForms-postcreator' ) . ' data-label=' . esc_html__( 'Standard', 'ARForms-postcreator' ) . '>' . esc_html__( 'Standard', 'ARForms-postcreator' ) . '</li>';
			if ( $is_format == 1 ) {
				$cntr = 0;
				foreach ( $post_formats_single as $key => $format ) {
					if ( $default_value == $format ) {
						$selected_list_id    = $format;
						$selected_list_label = $format;
					}
					$responder_list_option .= '<li class="arf_selectbox_option" data-value="' . $format . '" data-label="' . ucwords( $format ) . '">' . $armainhelper->truncate( ucwords( $format ), 33 ) . '</li>';
					$responder_list_option_arr[$format] = $format;
					$cntr++;
				}
			}
			if( method_exists( $maincontroller, 'arf_selectpicker_dom') ){
				if( !empty( $disabled ) ){				
					$select_attrs['disabled'] = 'disabled';
				}
				echo $maincontroller->arf_selectpicker_dom( 'arf_format_type', 'arf_format_type', ' arf_pc_cc_field_dd ', '', $selected_list_id, $select_attrs, $responder_list_option_arr );
			} else {
			?>
			<input id="arf_format_type"  name="arf_format_type" value="<?php echo esc_html( $selected_list_id ); ?>" type="hidden" <?php echo esc_attr( $disabled ); ?> />
			<dl class="arf_selectbox arf_pc_cc_field_dd" data-name="arf_format_type" data-id="arf_format_type">
				<dt>
					<span><?php echo ucwords( $selected_list_label ); ?></span>
					<svg viewBox="0 0 2000 1000" width="15px" height="15px">
						<g fill="#000">
							<path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
						</g>
					</svg>
				</dt>
				<dd>
					<ul data-id="arf_format_type">
					   <?php echo $responder_list_option; ?>
					</ul>
				</dd>
			</dl>
			<?php 
		}
		?>
		</div>

		<div class="arferrmessage" id="arf_postcreator_format_msg"><?php esc_html_e( 'Please Select at least one format.', 'ARForms-postcreator' ); ?></div>
		<?php
	}

	public function arf_postcreator_user_fill_format_fields() {
		global $arffield, $MdlDb;

		$form_id = $_REQUEST['form_id'];

		$field_list = array();

		if ( is_numeric( $form_id ) ) {

			$include = "'radio','select'";

			$field_list = $arffield->getAll( 'fi.type in (' . $include . ') and fi.form_id=' . (int) $form_id, 'fi.id' );
		}
		?>
									<li class="arf_selectbox_option" data-value="" data-label=""><?php echo esc_html__( 'Please select field', 'ARForms-postcreator' ); ?></li>
									<?php
									if ( count( $field_list ) > 0 ) {
										foreach ( $field_list as $field ) {
											?>
											<li class="arf_selectbox_option" data-value="<?php echo esc_html( $field->id ); ?>" data-label="<?php echo esc_html( $field->name ); ?>"><?php echo armainhelper::truncate( $field->name, 33 ); ?></li>
											<?php
										}
									}
									die();
	}

	public function arfpostcreator_validate_process( $flag, $form ) {
		global $wpdb,$arfform,$MdlDb,$arf_version;

		$form_id     = $form->id;
		$form_mapped = isset( $form->arf_mapped_addon ) ? maybe_unserialize( $form->arf_mapped_addon ) : array();
		if ( isset( $form_mapped ) && ! empty( $form_mapped ) ) {
			if ( ! in_array( 'postcreator', $form_mapped ) ) {
				return $flag;
			}
		} elseif ( empty( $form_mapped ) ) {
			return $flag;
		}

		$form_data = array();

		if( version_compare( $arf_version, '4.3', '<' ) ){

			$form_data = $wpdb->get_row( $wpdb->prepare( 'SELECT * FROM ' . $wpdb->prefix . 'arf_postcreator_forms WHERE form_id = %d', $form_id ) );

		}else{
			
			$tblnm = $wpdb->prefix . 'arf_postcreator_forms pst LEFT JOIN ' . $MdlDb->forms . ' frm ON pst.form_id = frm.id';
			$form_data = $arfform->arf_select_db_data( true, '', $tblnm , 'pst.*', 'WHERE pst.form_id = %d', array($form_id), '','','', false, true);

		}

		if ( ! $form_data ) {
			return $flag;
		}

		$form_options = maybe_unserialize( $form_data->options );

		if ( ! isset( $form_options['post_type'] ) or empty( $form_options['post_type'] ) ) {
			return $flag;
		}

		if ( ! isset( $form_options['title'] ) or empty( $form_options['title'] ) ) {
			return $flag;
		}

		if ( ! isset( $form_options['description'] ) or empty( $form_options['description'] ) ) {
			return $flag;
		}

		if ( $form_options['post_type'] && $form_options['title'] && $form_options['description'] ) {
			return true;
		}

		return $flag;
	}

	public function arf_prevalidate_fields( $arf_errors, $form_id, $values, $arf_form_data = array() ) {
		global $wpdb, $arfrecordmeta, $arfsettings, $current_user, $arffield, $arfform, $MdlDb, $arf_version;

		if( version_compare( $arf_version, '4.3', '<' ) ){

			$form_data = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM  ' . $wpdb->prefix . 'arf_postcreator_forms WHERE form_id = %d', $form_id ) );

		}else{

			$tblnm = $wpdb->prefix . 'arf_postcreator_forms pst LEFT JOIN ' . $MdlDb->forms . ' frm ON pst.form_id = frm.id';
			$form_data = $arfform->arf_select_db_data( true, '', $tblnm , 'pst.*', 'WHERE pst.form_id = %d', array($form_id));

		}

		if ( count( $form_data ) < 1 ) {
			return $arf_errors;
		}

		$form_data = $form_data[0];

		$form_options = maybe_unserialize( $form_data->options );

		if ( ! isset( $form_options['post_type'] ) or empty( $form_options['post_type'] ) ) {
			return $arf_errors;
		}

		if ( ! isset( $form_options['title'] ) or empty( $form_options['title'] ) ) {
			return $arf_errors;
		}

		$title       = '';
		$description = '';

		if ( isset( $values['item_meta'] ) && $values['item_meta'] ) {
			foreach ( $values['item_meta'] as $field_id => $field_value ) {
				if ( $form_options['title'] == $field_id && $field_value != '' ) {
					$title = $field_value;
				}

				if ( $form_options['description'] == $field_id && $field_value != '' ) {
					$description = $field_value;
				}
			}
		}

		if ( $title == '' ) {
			$title_field_option = $arffield->getOne( $form_options['title'] );

			$arf_errors[ $form_options['title'] ] = ( isset( $title_field_option->field_options['blank'] ) && ! empty( $title_field_option->field_options['blank'] ) ) ? esc_attr( $title_field_option->field_options['blank'] ) : esc_html__( 'This field cannot be blank.', 'ARForms-postcreator' );
		}

		if ( $description == '' ) {
			$description_field_option = $arffield->getOne( $form_options['description'] );
			if ( isset( $description_field_option->required ) and $description_field_option->required ) {
				$arf_errors[ $form_options['description'] ] = esc_attr( $description_field_option->field_options['blank'] );
			}
		}

		return $arf_errors;
	}

	function arf_check_update_post( $values ){

		if( !empty( $values['arf_viewer_entry_id'] ) && !empty( $values['form_id'] ) ){

			global $MdlDb, $wpdb, $arfform, $arf_view;

			$form_id = $values['form_id'];

			$form_data = $arfform->arf_select_db_data( true, '', $arf_view->db_arfview_forms, 'options', 'WHERE form_id = %d', array( $form_id), '','','', false, true );

			if( empty( $form_data ) ){
				return $values;
			}

			$entry_id = $values['arf_viewer_entry_id'];

			$item_metas = $values['item_meta'];

			$check_post_creator = $arfform->arf_select_db_data( true, '', $wpdb->prefix.'arf_postcreator_forms', 'options', 'WHERE form_id = %d', array( $form_id ), '', '', '', false, true );

			if( !empty( $check_post_creator ) ){

				$view_options = maybe_unserialize( $form_data->options );

				$post_creator_opts = maybe_unserialize( $check_post_creator->options );

				if( isset( $post_creator_opts['allow_update_post'] ) && 1 == $post_creator_opts['allow_update_post'] ){
					if ( $post_creator_opts['post_type'] == 'page' || $post_creator_opts['post_type'] == 'basic') { 
						$check_post_type = ( $post_creator_opts['post_type'] != 'page') ? 'post' : 'page';
					} else {
						$check_post_type =  $post_creator_opts['custom_post'];
					}

					$post_ids = $arfform->arf_select_db_data( true, '', $wpdb->postmeta, 'post_id', 'WHERE meta_key = %d AND meta_value = %d', array( 'arf_form_entry_id', $entry_id), '', '', '', true );

					$tag_update = false;

					if (!empty( $post_ids )) {

						$get_post_data = get_post($post_ids);

						if( isset($item_metas) ){
							$type_data = ( $post_creator_opts['post_type'] ) ? $post_creator_opts['post_type']: $get_post_data->post_type;

							$title_data = $get_post_data->post_title;
							$content_data = $get_post_data->post_content;
							$excerpt_data = ($type_data == 'page') ? '' : $get_post_data->post_excerpt;
							$status_data = ( $post_creator_opts['status'] ) ? $post_creator_opts['status'] : $get_post_data->post_status;
							$author_data = ( $post_creator_opts['author'] ) ? $post_creator_opts['author'] : $get_post_data->post_author;
							if ( $type_data != 'page' ) {
								$post_format_data = ( $post_creator_opts['post_format'] ) ? $post_creator_opts['post_format'] : get_post_format($post_ids);
							}
							$comment_status = ( $post_creator_opts['arf_allow_comment'] ) ? 
								$post_creator_opts['arf_allow_comment'] :
										$get_post_data->comment_status;

						}
						
						foreach( $item_metas as $post_field_id => $post_field_value ){
							if ( $post_field_id == $post_creator_opts['title']) {
								$title_data = $post_field_value;
							}
							if ( $post_field_id == $post_creator_opts['description']) {
								$content_data = $post_field_value;
							}
							if ( $post_field_id == $post_creator_opts['date']) {
								$date_data = $post_field_value;
							}
							if ( $type_data != 'page' && $post_field_id == $post_creator_opts['excerpt']) {
								$excerpt_data = $post_field_value;
							}
							if ( $type_data != 'page' && $post_field_id == $post_creator_opts['post_format']) {
								$post_format_data = ( $post_field_value ) ? $post_field_value : get_post_format($post_ids);
							}
							if ( $type_data != 'page' &&  $post_field_id == $post_creator_opts['tag']) {
								$tag_data = $post_field_value;
								$tag_update = true;
							}
							if ( is_array($post_creator_opts['category_single']) && 
								$post_field_id == $post_creator_opts['category_single'][0]) {
								$category_data = $post_field_value;
							}
						}
						
						if ( $type_data == 'page' || $type_data == 'basic') { 
							$type_data = ( $type_data == 'basic') ?  'post' : $type_data;
						} else {
							$type_data =  $post_creator_opts['custom_post'];
						}

						$args        = array(
							'ID'				=> $post_ids,
							'post_title'		=> $title_data,
							'post_content'		=> $content_data,
							'post_excerpt'  	=> $excerpt_data,
							'post_status'    	=> $status_data,
							'post_type'      	=> $type_data ,
							'comment_status' 	=> $comment_status,
						);
						
						if ( isset($category_data) && $category_data != null) {
							$cat_ids = get_cat_ID( $category_data );
							wp_set_post_categories( $post_ids, $cat_ids );
						}
						if ( $tag_update ) {
							$tag_data = isset( $tag_data ) ? $tag_data : '';
							$tag      = $tag_data;
							wp_set_post_tags( $post_ids, $tag, false );
						}
						
						if ( $type_data != 'page' ) { 
							wp_set_post_terms( $post_ids, $post_format_data, 'post_format' );	
						}

						if ( is_array( $post_creator_opts['custom_fields'] ) && count( $post_creator_opts['custom_fields'] ) > 0 ) {
							if ( array_filter( is_array( $post_creator_opts['custom_fields'] ) ? $post_creator_opts['custom_fields'] : array() ) != '' ) {

								if ( count( $post_creator_opts['custom_fields'] ) > 0 ) {

									foreach ( $post_creator_opts['custom_fields'] as $i => $cs_fields ) {
										$meta_key      = $post_creator_opts['custom_fields'][ $i ];
										$is_blank_meta = $post_creator_opts['is_blank_meta'][ $i ];

										$flag        = false;
										$meta_key2   = '';
										$meta_value2 = '';

										if ( is_plugin_active( 'advanced-custom-fields/acf.php' ) ) {
											$post_tbl     = $wpdb->prefix . 'posts';
											$postmeta_tbl = $wpdb->prefix . 'postmeta';

											if( version_compare( $arf_version, '4.3', '<' ) ){

												$posts = $wpdb->get_results( 'SELECT ID FROM ' . $post_tbl . " WHERE post_type='acf'" );

											}else{

												$posts = $arfform->arf_select_db_data(true, '', $post_tbl, 'ID', 'WHERE post_type = %s', array('acf'));
											}
											if ( ! empty( $posts ) ) {
												foreach ( $posts as $post ) {

													if( version_compare( $arf_version, '4.3', '<' ) ){

														$post_meta = $wpdb->get_results( $wpdb->prepare( 'SELECT meta_value FROM ' . $postmeta_tbl . " WHERE meta_key LIKE 'field_%' AND post_id=%d", $post->ID ) );

													}else{

														$where_clause = "WHERE meta_key LIKE 'field_%' AND post_id = %d";
														$post_meta = $arfform->arf_select_db_data(true, '', $postmeta_tbl, 'meta_value', $where_clause, array($post->ID));
													}

													if ( ! empty( $post_meta ) ) {
														foreach ( $post_meta as $meta ) {
															$custom_field = maybe_unserialize( $meta->meta_value );

															if ( $custom_field['name'] == $meta_key ) {
																$meta_key2   = '_' . $custom_field['name'];
																$meta_value2 = $custom_field['key'];
																if ( $custom_field['type'] == 'checkbox' ) {
																	$flag = true;
																}
															}
														}
														unset( $custom_field );
													}
												}
											}
										} elseif ( is_plugin_active( 'advanced-custom-fields-pro/acf.php' ) ) {
											$post_tbl     = $wpdb->prefix . 'posts';
											$postmeta_tbl = $wpdb->prefix . 'postmeta';

											if( version_compare( $arf_version, '4.3', '<' ) ){

												$posts = $wpdb->get_row( $wpdb->prepare( 'SELECT post_content,post_excerpt FROM ' . $post_tbl . ' WHERE post_type=%s AND post_name = %s', 'acf-field', $meta_key ) );

											}else{
												
												$posts = $arfform->arf_select_db_data(true, '', $post_tbl, 'post_content,post_excerpt', 'WHERE post_type = %s AND post_name = %s', array('acf-field', $meta_key), '', '', '', false, true);

											}

											$meta_value2 = $meta_key;

											$content = maybe_unserialize( $posts->post_content );

											if ( ! empty( $posts ) ) {
												$meta_key = $posts->post_excerpt;
											}

											if ( $content['type'] == 'checkbox' ) {
												$flag = true;
											}

											$meta_key2 = '_' . $meta_key;

										}
										
										
										foreach ( $values['item_meta'] as $key=>$value ) {
											$meta_value = '';
											if ( $is_blank_meta == 2 || $is_blank_meta == 3 ) {

												$meta_value = $post_creator_opts['custom_field_value'][ $i ];
												break;
											} elseif ( $post_creator_opts['custom_field_value'][ $i ] == $key ) {

												$value_entry_value = $value ;
												if ( is_array( $value_entry_value ) ) {
													if ( $flag == true ) {
														$meta_value = $value;
													} else {
														$meta_value = implode( ',', $value_entry_value );
													}
												} else {
													$meta_value = $value_entry_value;
												}
												break;
											}
										}

										update_post_meta( $post_ids, $meta_key, $meta_value );
										if ( $meta_key2 != '' ) {
											update_post_meta( $post_ids, $meta_key2, $meta_value2 );
										}
									}
								}
							}
						}
						
						$custom_cat_type = $post_creator_opts['custom_post'];

						if ( is_array($custom_cat_type) && count( $custom_cat_type ) > 0 ) {
							$cat_ids = array();
							if ( ! empty( $post_creator_opts['category_single'] ) ) {
								$cat_ids = array();
								foreach ( $custom_cat_type as $cat_type ) {
									$cat_ids[]   = $post_creator_opts['category_single'][ $cat_type ][0];
									
									$cat_types[] = $cat_type;
									$cat_ids     = array_map( 'intval', $cat_ids );
									$term_id     = array();
									$term_ids    = array();
									foreach ( $cat_ids as $cat_id ) {
										foreach ( $item_metas as $value ) {
											if ( $cat_id == $field_id ) {
												$term_name = maybe_unserialize( $field_value );
												
												
												if ( is_array( $term_name ) ) {
													foreach ( $term_name as $t_name ) {
														$t_name    =  htmlentities($t_name);

														$term      = get_term_by( 'name', $t_name, $cat_type );
														$term_id[] = $term->term_id;
													}
													$term_ids = array_map( 'intval', $term_id );
													wp_set_object_terms( $post_ids, $term_ids, $cat_type, true );
													unset( $field_value );
												} else {
													$term_name = htmlentities( $term_name );
													$term      = get_term_by( 'name', $term_name, $cat_type );
													$term_id[] = $term->term_id;
													$term_ids  = array_map( 'intval', $term_id );
													wp_set_object_terms( $post_ids, $term_ids, $cat_type, true );
													unset( $field_value );
												}
											}
										}
									}
								}
							}
							if ( is_array( $custom_cat_type ) && count( $custom_cat_type ) > 0 ) {
								foreach ( $custom_cat_type as $cat_type ) {
									if ( is_array( $post_creator_opts['categories'][ $cat_type ] ) ) {
										foreach ( $post_creator_opts['categories'][ $cat_type ] as $cats ) {
											$ids[] = $cats;
										}
										$t_ids = array_map( 'intval', $ids );
										wp_set_object_terms( $post_ids, $t_ids, $cat_type );
									}
								}
							}
						}
						wp_update_post( $args );
					}
				}
			}
		}
	}

	function arf_save_postcreator_data_callback() {

		global $wpdb, $arfform, $arf_version;

		$check_cap = $this->arf_check_user_cap( 'arfpostcreator', true );

		if ( 'success' != $check_cap ) {
			$errors = json_decode( $check_cap, true );
			echo json_encode(
				array(
					'success' => false,
					'message' => $errors[0],
				)
			);
			die;
		}

		$id = $_REQUEST['id'];
		if ( isset( $id ) and $id != '' and $_POST['arfaction'] == 'edit' ) {

			if( version_compare( $arf_version, '4.3', '<' ) ){

				$arf_form_chk = $wpdb->get_results( $wpdb->prepare( 'SELECT id FROM ' . $wpdb->prefix . 'arf_forms WHERE id = %d', $_REQUEST['form_id'] ) );

				$form_chk     = $wpdb->get_results( $wpdb->prepare( 'SELECT id FROM ' . $wpdb->prefix . 'arf_postcreator_forms WHERE id = %d', $id ) );

			} else{

				$arf_form_chk = $arfform->arf_select_db_data( true, '', $wpdb->prefix . 'arf_forms', 'id', 'WHERE id = %d', array($_REQUEST['form_id']));

				$form_chk = $arfform->arf_select_db_data( true, '', $wpdb->prefix . 'arf_postcreator_forms', 'id', 'WHERE id = %d', array($id));

			}

			if ( count( $arf_form_chk ) == 0 || count( $form_chk ) == 0 ) {
				echo json_encode(
					array(
						'success' => false,
						'message' => 'redirect',
						'loation' => admin_url( 'admin.php?page=ARForms-postcreator&err=true' ),
					)
				);
			}

			$form_data = $arfform->getOne( $_REQUEST['form_id'] );

			$new_values['form_name'] = sanitize_text_field( $form_data->name );

			$options['post_type'] = esc_attr( isset( $_REQUEST['arf_postcreator_post_type'] ) ? sanitize_text_field( $_REQUEST['arf_postcreator_post_type'] ) : '' );

			$options['custom_post'] = esc_attr( isset( $_REQUEST['arf_postcreator_custom_post'] ) ? sanitize_text_field( $_REQUEST['arf_postcreator_custom_post'] ) : '' );

			$options['buddypress_grpid'] = esc_attr(isset( $_REQUEST['arf_postcreator_buddypress_grp']) ? sanitize_text_field( $_REQUEST['arf_postcreator_buddypress_grp']) : '');

			if ( $options['custom_post'] != '' ) {
				$options['custom_categories'] = isset( $_REQUEST['custom_query_var'] ) ? $_REQUEST['custom_query_var'] : '';
			}

			$options['title'] = esc_attr( isset( $_REQUEST['arf_postcreator_title'] ) ? $_REQUEST['arf_postcreator_title'] : '' );

			$options['description'] = esc_attr( isset( $_REQUEST['arf_postcreator_description'] ) ? $_REQUEST['arf_postcreator_description'] : '' );

			$options['bp_group_name'] = isset($_REQUEST['arf_postcreator_bp_group']) ? $_REQUEST['arf_postcreator_bp_group']  : '';

			if (isset($option['bp_group_name']) && $option['bp_group_name'] != '') {
				unset($options['bp_group_name_array']);
			} else{
				$options['bp_group_name_array'] = isset($_REQUEST['arf_postcreator_buddypress_grp']) ? $_REQUEST['arf_postcreator_buddypress_grp'] : '';
			}

			$options['content_editor'] = esc_attr( isset( $_REQUEST['arf_postcreator_content_editor'] ) ? $_REQUEST['arf_postcreator_content_editor'] : '' );

			$options['content_media_upload'] = esc_attr( isset( $_REQUEST['arf_postcreator_content_media_upload'] ) ? $_REQUEST['arf_postcreator_content_media_upload'] : '' );

			$options['status'] = esc_attr( isset( $_REQUEST['arf_postcreator_status'] ) ? $_REQUEST['arf_postcreator_status'] : '' );

			$options['image'] = esc_attr( isset( $_REQUEST['arf_postcreator_featured_img'] ) ? $_REQUEST['arf_postcreator_featured_img'] : '' );

			$options['author'] = esc_attr( isset( $_REQUEST['arf_postcreator_author'] ) ? $_REQUEST['arf_postcreator_author'] : '' );
			if ( empty( $options['author'] ) ) {
				$options['author'] = esc_attr( isset( $_REQUEST['arf_postcreator_author_value'] ) ? $_REQUEST['arf_postcreator_author_value'] : '' );
			}

			$options['date'] = esc_attr( isset( $_REQUEST['arf_postcreator_date'] ) ? $_REQUEST['arf_postcreator_date'] : '' );

			$options['arf_allow_comment'] = esc_attr( isset( $_REQUEST['arf_allow_comment'] ) ? $_REQUEST['arf_allow_comment'] : '' );

			if ( $options['post_type'] != 'page' ) {
				$options['excerpt'] = esc_attr( isset( $_REQUEST['arf_postcreator_excerpt'] ) ? $_REQUEST['arf_postcreator_excerpt'] : '' );

				$options['tag'] = esc_attr( isset( $_REQUEST['arf_postcreator_tag'] ) ? $_REQUEST['arf_postcreator_tag'] : '' );

				if ( $_REQUEST['arf_post_format'] != '' ) {
					$options['post_format']       = esc_attr( isset( $_REQUEST['arf_post_format'] ) ? $_REQUEST['arf_post_format'] : '' );
					$options['post_format_fixed'] = 0;
				} else {
					$options['post_format']       = esc_attr( isset( $_REQUEST['arf_format_type'] ) ? $_REQUEST['arf_format_type'] : '' );
					$options['post_format_fixed'] = 1;
				}
			}

			if ( $options['post_type'] == 'custom' && $options['custom_categories'][0] != '' ) {
				$custom_categories = $options['custom_categories'];
				foreach ( $custom_categories as $cats ) {
					if ( ! empty( $_REQUEST['arf_postcreator_category_single'][ $cats ][0] ) ) {
						foreach ( $_REQUEST['arf_postcreator_category_single'][ $cats ] as $cs_cats ) {
							$options['category_single'][ $cats ] = array( $cs_cats );
							unset( $options['categories'][ $cats ] );
						}
					} else {
						$options['categories'][ $cats ] = isset( $_REQUEST['arf_postcreator_category'][ $cats ] ) ? $_REQUEST['arf_postcreator_category'][ $cats ] : '';
					}
				}
			} else {
				$options['category_single'] = isset( $_REQUEST['arf_postcreator_category_single'] ) ? $_REQUEST['arf_postcreator_category_single'] : '';

				if ( ( isset( $options['category_single'][0] ) ? $options['category_single'][0] : '' ) != '' ) {
					unset( $options['categories'] );
				} else {
					$options['categories'] = isset( $_REQUEST['arf_postcreator_category'] ) ? $_REQUEST['arf_postcreator_category'] : '';
				}
			}
			if ( $options['post_type'] == 'custom' ) {
				$custom_categories = $options['custom_categories'];
				if ( is_array( $custom_categories ) ) {
					foreach ( $custom_categories as $cats ) {
						if ( isset( $options['category_single'][ $cats ][0] ) && $options['category_single'][ $cats ][0] ) {
							unset( $options['categories'][ $cats ] );
						}
					}
				}
			}
			
			$options['custom_fields'] = isset( $_REQUEST['custom_field_name'] ) ? $_REQUEST['custom_field_name'] : '';

			$options['custom_field_value'] = isset( $_REQUEST['custom_field_value'] ) ? $_REQUEST['custom_field_value'] : '';

			$options['is_blank_meta'] = isset( $_REQUEST['is_blank_meta'] ) ? $_REQUEST['is_blank_meta'] : '';

			$options = apply_filters('arf_postcreator_modify_settings_outside',$options, $_REQUEST);
			
			$form_options     = maybe_unserialize( $form_data->options );
			$new_form_options = maybe_serialize( $form_options );

			$form_arf_mapped_addon = maybe_unserialize( $form_data->arf_mapped_addon );
			if ( isset( $form_arf_mapped_addon['arf_mapped_addon'] ) && ! empty( $form_arf_mapped_addon['arf_mapped_addon'] ) ) {
				if ( ! in_array( 'postcreator', $form_arf_mapped_addon['arf_mapped_addon'] ) ) {
					array_push( $form_arf_mapped_addon['arf_mapped_addon'], 'postcreator' );
				}
			} else {
				$form_arf_mapped_addon['arf_mapped_addon'] = array( 'postcreator' );
			}
			$new_form_arf_mapped_addon = maybe_serialize( $form_arf_mapped_addon );
			$wpdb->update(
				$wpdb->prefix . 'arf_forms',
				array(
					'options'          => $new_form_options,
					'arf_mapped_addon' => $new_form_arf_mapped_addon,
				),
				array( 'id' => $form_data->id )
			);

			$new_values['options'] = maybe_serialize( $options );

			$res = $wpdb->update( $wpdb->prefix . 'arf_postcreator_forms', $new_values, array( 'id' => $id ) );

			$values = array();

			$values = $new_values;

			$values['form_id'] = esc_attr( $_REQUEST['form_id'] );

			$values['form_name'] = esc_attr( $_REQUEST['form_name'] );

			$values['id'] = $id;

			unset( $values['options'] );

			foreach ( $options as $option_key => $option_val ) {
				$values[ $option_key ] = $option_val;
			}

			$arfaction = 'edit';

			$message = esc_html__( 'Configuration saved successfully', 'ARForms-postcreator' );
			
			echo json_encode(
				array(
					'success'   => true,
					'message'   => $message,
					'arfaction' => 'edit',
				)
			);

		} else {

			$new_form_id = $_REQUEST['arf_postcreator_form'];
			if ( isset( $new_form_id ) and $new_form_id != '' ) {
				$form_data = $arfform->getOne( $new_form_id );

				$new_values['form_id'] = $new_form_id;

				$new_values['form_name'] = $form_data->name;

				$options['post_type'] = esc_attr( $_REQUEST['arf_postcreator_post_type'] );

				$options['custom_post'] = esc_attr( $_REQUEST['arf_postcreator_custom_post'] );

				$options['buddypress_grpid'] = isset($_REQUEST['arf_postcreator_buddypress_grp']) ? esc_attr( $_REQUEST['arf_postcreator_buddypress_grp']): '';

				if ( $options['custom_post'] != '' ) {
					$options['custom_categories'] = isset( $_REQUEST['custom_query_var'] ) ? $_REQUEST['custom_query_var'] : '';
				}

				$options['title'] = esc_attr( isset( $_REQUEST['arf_postcreator_title'] ) ? $_REQUEST['arf_postcreator_title'] : '' );

				$options['description'] = esc_attr( isset( $_REQUEST['arf_postcreator_description'] ) ? $_REQUEST['arf_postcreator_description'] : '' );
				$options['bp_group_name'] = isset($_REQUEST['arf_postcreator_bp_group']) ? $_REQUEST['arf_postcreator_bp_group'] : ''; 
				$options['bp_group_name_array'] = isset($_REQUEST['arf_postcreator_buddypress_grp']) ? $_REQUEST['arf_postcreator_buddypress_grp'] : '';
				$options['content_editor'] = esc_attr( isset( $_REQUEST['arf_postcreator_content_editor'] ) ? $_REQUEST['arf_postcreator_content_editor'] : '' );

				$options['content_media_upload'] = esc_attr( isset( $_REQUEST['arf_postcreator_content_media_upload'] ) ? $_REQUEST['arf_postcreator_content_media_upload'] : '' );

				$options['status'] = esc_attr( isset( $_REQUEST['arf_postcreator_status'] ) ? $_REQUEST['arf_postcreator_status'] : '' );

				$options['image'] = esc_attr( isset( $_REQUEST['arf_postcreator_featured_img'] ) ? $_REQUEST['arf_postcreator_featured_img'] : '' );

				$options['author'] = esc_attr( isset( $_REQUEST['arf_postcreator_author'] ) ? $_REQUEST['arf_postcreator_author'] : '' );
				if ( empty( $options['author'] ) ) {
					$options['author'] = esc_attr( isset( $_REQUEST['arf_postcreator_author_value'] ) ? $_REQUEST['arf_postcreator_author_value'] : '' );
				}

				$options['date'] = esc_attr( isset( $_REQUEST['arf_postcreator_date'] ) ? $_REQUEST['arf_postcreator_date'] : '' );

				$options['arf_allow_comment'] = esc_attr( isset( $_REQUEST['arf_allow_comment'] ) ? $_REQUEST['arf_allow_comment'] : '' );

				if ( $options['post_type'] != 'page' ) {
					$options['excerpt'] = esc_attr( isset( $_REQUEST['arf_postcreator_excerpt'] ) ? $_REQUEST['arf_postcreator_excerpt'] : '' );

					$options['tag'] = esc_attr( isset( $_REQUEST['arf_postcreator_tag'] ) ? $_REQUEST['arf_postcreator_tag'] : '' );

					if ( $_REQUEST['arf_post_format'] != '' ) {
						$options['post_format']       = esc_attr( isset( $_REQUEST['arf_post_format'] ) ? $_REQUEST['arf_post_format'] : '' );
						$options['post_format_fixed'] = 0;
					} else {
						$options['post_format']       = esc_attr( isset( $_REQUEST['arf_format_type'] ) ? $_REQUEST['arf_format_type'] : '' );
						$options['post_format_fixed'] = 1;
					}
				}

				if ( isset( $_POST['arf_postcreator_category_single'] ) && $_POST['arf_postcreator_category_single'] != '' ) {
					$options['category_single'] = array_filter( $_POST['arf_postcreator_category_single'] );
				}

				if ( $options['post_type'] == 'custom' && isset( $options['custom_category'] ) && $options['custom_category'][0] != '' ) {
					$custom_categories = $options['custom_categories'];
					foreach ( $custom_categories as $cats ) {
						if ( $_REQUEST['arf_postcreator_category_single'][ $cats ][0] != '' ) {
							foreach ( $_REQUEST['arf_postcreator_category_single'][ $cats ] as $cs_cats ) {
								$options['category_single'][ $cats ] = array( $cs_cats );
								empty( $options['categories'][ $cats ] );
							}
						} else {
							$options['categories'] = isset( $_REQUEST['arf_postcreator_category'] ) ? $_REQUEST['arf_postcreator_category'] : '';
						}
					}
				} else {
					$options['category_single'] = isset( $_REQUEST['arf_postcreator_category_single'] ) ? $_REQUEST['arf_postcreator_category_single'] : '';

					if ( isset( $options['category_single'] ) && isset( $options['category_single'][0] ) && $options['category_single'][0] != '' ) {
						unset( $options['categories'] );
					} else {
						$options['categories'] = isset( $_REQUEST['arf_postcreator_category'] ) ? $_REQUEST['arf_postcreator_category'] : '';
					}
				}
				if ( $options['post_type'] == 'custom' ) {
					$custom_categories = $options['custom_categories'];
					if ( is_array( $custom_categories ) ) {
						foreach ( $custom_categories as $cats ) {
							if ( $options['category_single'][ $cats ][0] ) {
								unset( $options['categories'][ $cats ] );
							}
						}
					}
				}

				$options['custom_fields'] = isset( $_REQUEST['custom_field_name'] ) ? $_REQUEST['custom_field_name'] : '';

				$options['custom_field_value'] = isset( $_REQUEST['custom_field_value'] ) ? $_REQUEST['custom_field_value'] : '';

				$options['is_blank_meta'] = isset( $_REQUEST['is_blank_meta'] ) ? $_REQUEST['is_blank_meta'] : '';

				$options = apply_filters('arf_postcreator_modify_settings_outside',$options, $_REQUEST);
				
				$form_options = maybe_unserialize( $form_data->options );

				$new_form_options = maybe_serialize( $form_options );

				$form_arf_mapped_addon = maybe_unserialize( $form_data->arf_mapped_addon );
				if ( isset( $form_arf_mapped_addon['arf_mapped_addon'] ) && ! empty( $form_arf_mapped_addon['arf_mapped_addon'] ) ) {
					if ( ! in_array( 'postcreator', $form_arf_mapped_addon['arf_mapped_addon'] ) ) {
						array_push( $form_arf_mapped_addon['arf_mapped_addon'], 'postcreator' );
					}
				} else {
					$form_arf_mapped_addon['arf_mapped_addon'] = array( 'postcreator' );
				}
				$new_form_arf_mapped_addon = maybe_serialize( $form_arf_mapped_addon );

				$wpdb->update(
					$wpdb->prefix . 'arf_forms',
					array(
						'options'          => $new_form_options,
						'arf_mapped_addon' => $new_form_arf_mapped_addon,
					),
					array( 'id' => $form_data->id )
				);

				$new_values['options'] = maybe_serialize( $options );

				$new_values['created_at'] = current_time( 'mysql' );

				$id = $wpdb->insert( $wpdb->prefix . 'arf_postcreator_forms', $new_values );

				$id = $wpdb->insert_id;

				$values = array();

				$values = $new_values;

				$values['id'] = $id;

				unset( $values['options'] );

				foreach ( $options as $option_key => $option_val ) {
					$values[ $option_key ] = $option_val;
				}

				$arfaction = 'edit';

				$message = esc_html__( 'Configuration saved successfully.', 'ARForms-postcreator' );

				echo json_encode(
					array(
						'success'   => true,
						'message'   => $message,
						'arfaction' => 'new',
						'id'        => $id,
					)
				);
			}
		}
		die;

	}

	function arf_retrieve_postcreator_config_data(){

		global $wpdb, $MdlDb, $arf_postcreator, $arfform, $arformcontroller, $arf_version;

		$requested_data = arf_json_decode( stripslashes_deep( $_REQUEST['data'] ), true );

		$filtered_aoData  = $requested_data['aoData'];

		$return_data = array();

		$order_by = !empty( $filtered_aoData['iSortCol_0'] ) ? $filtered_aoData['iSortCol_0'] : 1;

		$order_by_str = 'ORDER BY';

		if( 1 == $order_by ){
            $order_by_str .= ' pc.form_id';
        } else if( 2 == $order_by ){
            $order_by_str .= ' pc.form_name';
        } else if( 3 == $order_by ){
        	$order_by_str .= ' counter';
        } else if( 5 == $order_by ){
            $order_by_str .= ' pc.created_at';
        } else {
            $order_by_str .= ' pc.id';
        }

        $order_by_str .=  ' ' . ( !empty( $filtered_aoData['sSortDir_0'] ) ? strtoupper($filtered_aoData['sSortDir_0']) : 'DESC' );

        $postcreator_form_params = 'pc.*,count(ent.id) AS counter';
        $group_by_param = 'GROUP BY pc.form_id';

        $offset = isset($filtered_aoData['iDisplayStart']) ? $filtered_aoData['iDisplayStart'] : 0;
        $limit = isset($filtered_aoData['iDisplayLength']) ? $filtered_aoData['iDisplayLength'] : 10;

        $limit_param = 'LIMIT '.$offset.', '.$limit;

        $where_clause = 'WHERE 1=1';
        $where_params = array();

        if( !empty( $filtered_aoData['sSearch'] ) ){
            $wild = '%';
            $find = $filtered_aoData['sSearch'];
            $like = $wild . $wpdb->esc_like( $find ) . $wild;
            $where_clause .= ' AND ( pc.form_id LIKE %s OR pc.form_name LIKE %s OR pc.created_at LIKE %s )';
            $where_params[] = $like;
            $where_params[] = $like;
            $where_params[] = $like;
        }

        if( version_compare( $arf_version, '4.3', '<' ) ){

        	$tblnm = $wpdb->prefix . 'arf_postcreator_forms pc LEFT OUTER JOIN ' . $MdlDb->entries . ' ent ON ent.form_id = pc.form_id';

        }else{

        	$tblnm = $wpdb->prefix . 'arf_postcreator_forms pc LEFT OUTER JOIN ' . $MdlDb->entries . ' ent ON ent.form_id = pc.form_id LEFT JOIN ' . $MdlDb->forms . ' frm ON pc.form_id = frm.id';

        }

        $forms = $arfform->arf_select_db_data(true, '', $tblnm , $postcreator_form_params, $where_clause, $where_params, $group_by_param, $order_by_str, $limit_param);

        $total_records = $arfform->arf_select_db_data( true, '', $tblnm, 'COUNT(pc.id)', $where_clause, $where_params, '', '', '', true );        

        $data = array();
        if( count( $forms ) > 0 ){

        	$ai = 0;
            foreach( $forms as $form_data ){
            	$options = maybe_unserialize( $form_data->options );

            	$data[$ai][0] = "<div class='arf_custom_checkbox_div arfmarginl15'><div class='arf_custom_checkbox_wrapper'>
					<input id='cb-item-action-{$form_data->id}' class='' type='checkbox' value='{$form_data->id}' name='item-action[]'>
							<svg width='18px' height='18px'>
								" . ARF_CUSTOM_UNCHECKED_ICON . "
								" . ARF_CUSTOM_CHECKED_ICON . "
							</svg>
						</div>
					</div>	
					<label for='cb-item-action-{$form_data->id}'><span></span></label>";

				$data[$ai][1] = $form_data->form_id;

				$edit_link = "?page=ARForms-postcreator&arfaction=edit&id={$form_data->id}";
				if( current_user_can('arfpostcreator')){
                    $data[$ai][2] = "<a class='row-title' href='{$edit_link}'>" . html_entity_decode(stripslashes($form_data->form_name)) . "</a>";
                } else {
                    $data[$ai][2] = html_entity_decode( stripslashes_deep( $form_data->form_name ) );
                }

                $data[$ai][3] =  ( current_user_can('arfviewentries') ? '<a href="' . esc_url( admin_url( 'admin.php' ) . '?page=ARForms-entries&form=' . $form_data->form_id ) . '">' . $form_data->counter . '</a>' : $form_data->counter );

            	if ($options['post_type'] == 'custom') {
					$data[$ai][4] = ucfirst( $options['post_type'] ) . ' (' . $options['custom_post'] . ') Post';
				}else if ($options['post_type'] == 'buddypress_grp') {
					$data[$ai][4] = 'BuddyPress Group Post';
				}else{
					$data[$ai][4] = ucfirst( $options['post_type'] ) . ' Post';
				}

                $data[$ai][5] = date( get_option( 'date_format' ), strtotime( $form_data->created_at ) );

                $action_row_data = "<div class='arf-row-actions arf_pc_no_padding_top'>";
                if( current_user_can('arfpostcreator') ){
                	$edit_link = "?page=ARForms-postcreator&arfaction=edit&id={$form_data->id}";

                	$action_row_data .= "<div class='arfformicondiv arfhelptip' title='" . esc_html__( 'Edit Configuration', 'ARForms-postcreator' ) . "'><a href='" . wp_nonce_url( $edit_link ) . "'><svg width='30px' height='30px' viewBox='-5 -4 30 30' class='arfsvgposition'><path fill='#ffffff' d='M17.469,7.115v10.484c0,1.25-1.014,2.264-2.264,2.264H3.75c-1.25,0-2.262-1.014-2.262-2.264V5.082  c0-1.25,1.012-2.264,2.262-2.264h9.518l-2.264,2.001H3.489v13.042h11.979V9.379L17.469,7.115z M15.532,2.451l-0.801,0.8l2.4,2.401  l0.801-0.8L15.532,2.451z M17.131,0.85l-0.799,0.801l2.4,2.4l0.801-0.801L17.131,0.85z M6.731,11.254l2.4,2.4l7.201-7.202  l-2.4-2.401L6.731,11.254z M5.952,14.431h2.264l-2.264-2.264V14.431z'></path></svg></a></div>";

                	$action_row_data .= "<div class='arfformicondiv arfhelptip arfdeleteform_div_" . $form_data->id . "' title='" . esc_html__( 'Delete', 'ARForms-postcreator' ) . "'><a class='arf_post_creator_delete' data-id='" . $form_data->id . "' ><svg width='30px' height='30px' viewBox='-5 -5 32 32' class='arfsvgposition'><path fill-rule='evenodd' clip-rule='evenodd' fill='#ffffff' d='M18.435,4.857L18.413,19.87L3.398,19.88L3.394,4.857H1.489V2.929  h1.601h3.394V0.85h8.921v2.079h3.336h1.601l0,0v1.928H18.435z M15.231,4.857H6.597H5.425l0.012,13.018h10.945l0.005-13.018H15.231z   M11.4,6.845h2.029v9.065H11.4V6.845z M8.399,6.845h2.03v9.065h-2.03V6.845z' /></svg></a></div>";

                }

                $action_row_data .= "</div>";

                $data[$ai][6] = $action_row_data;

            	$ai++;
            }

            $sEcho = isset($filtered_aoData['sEcho']) ? intval($filtered_aoData['sEcho']) : intval(10);

            $return_data = array(
                'sEcho' => $sEcho,
                'iTotalRecords' => (int)$total_records,
                'iTotalDisplayRecords' => (int)$total_records,
                'aaData' => $data,
            );

        } else {
            $sEcho = isset($filtered_aoData['sEcho']) ? intval($filtered_aoData['sEcho']) : intval(10);
            $return_data = array(
                'sEcho' => $sEcho,
                'iTotalRecords' => (int)$total_records,
                'iTotalDisplayRecords' => (int)$total_records,
                'aaData' => $data,
            );
        }

        echo json_encode( $return_data );

        die;

	}

	function arf_check_user_cap( $capibility = '', $is_ajax_call = false ) {

		if ( true == $is_ajax_call ) {
			if ( ! current_user_can( $capibility ) ) {
				return json_encode(
					array(
						esc_html__( 'Sorry, You do not have enough permission to perform this action', 'ARForms-postcreator' ),
					)
				);
				die;
			}
		}

		$nonce = isset( $_POST['_wpnonce_postcreator'] ) ? $_POST['_wpnonce_postcreator'] : '';
		if ( '' == $nonce ) {
			$nonce = isset( $_REQUEST['_wpnonce_postcreator'] ) ? $_REQUEST['_wpnonce_postcreator'] : '';
		}

		$postcreator_nonce_flag = false;

		$postcreator_nonce_flag = wp_verify_nonce( $nonce, 'arf_postcreator' );

		if ( ! $postcreator_nonce_flag ) {
			return json_encode(
				array(
					esc_html__( 'Sorry, Your request cannot be processed due to security reason', 'ARForms-postcreator' ),
				)
			);
			die;
		}

		return 'success';
		die;
	}

}

global $arfpostcreator_api_url, $arfpostcreator_plugin_slug;

$arfpostcreator_api_url     = $arf_postcreator->arfpostcreator_getapiurl();
$arfpostcreator_plugin_slug = basename( dirname( __FILE__ ) );

add_filter( 'pre_set_site_transient_update_plugins', 'arfpostcreator_check_for_plugin_update' );

function arfpostcreator_check_for_plugin_update( $checked_data ) {
	global $arfpostcreator_api_url, $arfpostcreator_plugin_slug, $wp_version, $arf_postcreator, $arf_postcreator_version,$arf_version;

	if ( empty( $checked_data->checked ) ) {
		return $checked_data;
	}

	$args = array(
		'slug'            => $arfpostcreator_plugin_slug,
		'version'         => $arf_postcreator_version,
		'arf_version' => $arf_version,
		'other_variables' => $arf_postcreator->arfpostcreator_get_remote_post_params(),
	);

	$request_string = array(
		'body'       => array(
			'action'  => 'basic_check',
			'request' => serialize( $args ),
			'api-key' => md5( home_url() ),
		),
		'user-agent' => 'ARFPSTCRETR-WordPress/' . $wp_version . '; ' . home_url(),
	);

	$raw_response = wp_remote_post( $arfpostcreator_api_url, $request_string );

	if ( ! is_wp_error( $raw_response ) && ( $raw_response['response']['code'] == 200 ) ) {
		$response = ( isset( $raw_response['body'] ) ) ? maybe_unserialize( $raw_response['body'] ) : '';
	}

	if ( isset( $response ) && ! empty( $response ) && isset( $response->token ) && $response->token != '' ) {
		update_option( 'arfpstcretr_update_token', $response->token );
	}

	if ( isset( $response ) && is_object( $response ) && is_object( $checked_data ) && ! empty( $response ) ) {
		$checked_data->response[ $arfpostcreator_plugin_slug . '/' . $arfpostcreator_plugin_slug . '.php' ] = $response;
	}

	return $checked_data;
}

add_filter( 'plugins_api', 'arfpostcreator_plugin_api_call', 11, 3 );

function arfpostcreator_plugin_api_call( $def, $action, $args ) {
	global $arfpostcreator_plugin_slug, $arfpostcreator_api_url, $wp_version,$arf_version;

	if ( ! isset( $args->slug ) || ( $args->slug != $arfpostcreator_plugin_slug ) ) {
		return false;
	}

	$plugin_info     = get_site_transient( 'update_plugins' );
	$current_version = $plugin_info->checked[ $arfpostcreator_plugin_slug . '/' . $arfpostcreator_plugin_slug . '.php' ];
	$args->version   = $current_version;

	$request_string = array(
		'body'       => array(
			'action'       => $action,
			'update_token' => get_site_option( 'arfpstcretr_update_token' ),
			'request'      => serialize( $args ),
			'arf_version' => $arf_version,
			'api-key'      => md5( home_url() ),
		),
		'user-agent' => 'ARFPSTCRETR-WordPress/' . $wp_version . '; ' . home_url(),
	);

	$request = wp_remote_post( $arfpostcreator_api_url, $request_string );

	if ( is_wp_error( $request ) ) {
		$res = new WP_Error( 'plugins_api_failed', 'An Unexpected HTTP Error occurred during the API request.</p> <p><a href="?" onclick="document.location.reload(); return false;">Try again</a>', $request->get_error_message() );
	} else {
		$res = maybe_unserialize( $request['body'] );

		if ( $res === false ) {
			$res = new WP_Error( 'plugins_api_failed', 'An unknown error occurred', $request['body'] );
		}
	}
	return $res;
}
?>